import React, { createContext, useContext, useState, useEffect } from 'react';

export type Language = {
  code: string;
  name: string;
  flag: string;
};

export const SUPPORTED_LANGUAGES: Language[] = [
  { code: 'en', name: 'English', flag: '🇺🇸' },
  { code: 'es', name: 'Español', flag: '🇪🇸' },
  { code: 'fr', name: 'Français', flag: '🇫🇷' },
  { code: 'de', name: 'Deutsch', flag: '🇩🇪' },
  { code: 'it', name: 'Italiano', flag: '🇮🇹' },
  { code: 'pt', name: 'Português', flag: '🇵🇹' },
  { code: 'ru', name: 'Русский', flag: '🇷🇺' },
  { code: 'zh', name: '中文', flag: '🇨🇳' },
  { code: 'ja', name: '日本語', flag: '🇯🇵' },
  { code: 'ko', name: '한국어', flag: '🇰🇷' },
  { code: 'ar', name: 'العربية', flag: '🇸🇦' },
  { code: 'hi', name: 'हिन्दी', flag: '🇮🇳' },
];

type LanguageContextType = {
  currentLanguage: Language;
  setLanguage: (language: Language) => void;
  t: (key: string) => string;
};

const LanguageContext = createContext<LanguageContextType | undefined>(undefined);

export function useLanguage() {
  const context = useContext(LanguageContext);
  if (!context) {
    throw new Error('useLanguage must be used within a LanguageProvider');
  }
  return context;
}

// Auto-detect user's language based on browser preference
function detectLanguage(): Language {
  const browserLang = navigator.language.split('-')[0];
  return SUPPORTED_LANGUAGES.find(lang => lang.code === browserLang) || SUPPORTED_LANGUAGES[0];
}

export function LanguageProvider({ children }: { children: React.ReactNode }) {
  const [currentLanguage, setCurrentLanguage] = useState<Language>(() => {
    const saved = localStorage.getItem('compresshub-language');
    if (saved) {
      const parsed = JSON.parse(saved);
      return SUPPORTED_LANGUAGES.find(lang => lang.code === parsed.code) || detectLanguage();
    }
    return detectLanguage();
  });

  // Save language to localStorage whenever it changes
  useEffect(() => {
    localStorage.setItem('compresshub-language', JSON.stringify(currentLanguage));
  }, [currentLanguage]);

  const setLanguage = (language: Language) => {
    setCurrentLanguage(language);
    
    // Also save language preference to server for logged-in users
    fetch('/api/auth/language-preference', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      credentials: 'include',
      body: JSON.stringify({ languageCode: language.code })
    }).catch(() => {
      // Silent fail if user not authenticated - preference still saved to localStorage
    });
  };

  const t = (key: string): string => {
    return translations[currentLanguage.code]?.[key] || translations.en[key] || key;
  };

  return (
    <LanguageContext.Provider value={{ currentLanguage, setLanguage, t }}>
      {children}
    </LanguageContext.Provider>
  );
}

// Comprehensive translations object
const translations: Record<string, Record<string, string>> = {
  en: {
    // Navigation
    'nav.home': 'Home',
    'nav.compress': 'Compress',
    'nav.history': 'History',
    'nav.login': 'Log In',
    'nav.signup': 'Sign Up',
    'nav.logout': 'Log Out',
    'nav.pricing': 'Pricing',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Free Plan',
    'nav.proActive': 'Pro Active',
    
    // Login Page
    'login.title': 'Welcome Back',
    'login.subtitle': 'Sign in to your account to continue',
    'login.formTitle': 'Sign In',
    'login.email': 'Email',
    'login.emailPlaceholder': 'Enter your email',
    'login.password': 'Password',
    'login.passwordPlaceholder': 'Enter your password',
    'login.signingIn': 'Signing in...',
    'login.signIn': 'Sign In',
    'login.noAccount': "Don't have an account?",
    'login.signUp': 'Sign up',
    'login.backToHome': '← Back to home',
    'login.errors.failed': 'Login Failed',
    'login.errors.invalid': 'Invalid email or password',
    'login.errors.generic': 'An error occurred. Please try again.',
    
    // Signup Page
    'signup.title': 'Create Account',
    'signup.subtitle': 'Join CompressHub and start optimizing your images',
    'signup.formTitle': 'Sign Up',
    'signup.firstName': 'First Name',
    'signup.firstNamePlaceholder': 'John',
    'signup.lastName': 'Last Name',
    'signup.lastNamePlaceholder': 'Doe',
    'signup.email': 'Email',
    'signup.emailPlaceholder': 'john@example.com',
    'signup.password': 'Password',
    'signup.passwordPlaceholder': 'At least 6 characters',
    'signup.confirmPassword': 'Confirm Password',
    'signup.confirmPasswordPlaceholder': 'Confirm your password',
    'signup.creatingAccount': 'Creating account...',
    'signup.createAccount': 'Create Account',
    'signup.haveAccount': 'Already have an account?',
    'signup.signIn': 'Sign in',
    'signup.backToHome': '← Back to home',
    'signup.success.title': 'Account Created',
    'signup.success.message': 'Welcome to CompressHub! You can now start compressing images.',
    'signup.errors.failed': 'Signup Failed',
    'signup.errors.createFailed': 'Failed to create account',
    'signup.errors.generic': 'An error occurred. Please try again.',
    'signup.errors.firstNameShort': 'First name must be at least 2 characters',
    'signup.errors.lastNameShort': 'Last name must be at least 2 characters',
    'signup.errors.emailInvalid': 'Please enter a valid email address',
    'signup.errors.passwordShort': 'Password must be at least 6 characters',
    'signup.errors.passwordMismatch': "Passwords don't match",
    
    // History Page
    'history.title': 'Compression History',
    'history.subtitle': 'View and download all your previously compressed images.',
    
    // Compressor Tool
    'compress.title': 'Image Compressor',
    'compress.professional': 'Professional Image Optimization',
    'compress.secure': 'Files processed securely',
    'compress.dropFiles': 'Drop images here or click to browse',
    'compress.supportedFormats': 'Support for JPG, PNG, WebP, HEIC up to 50MB each',
    'compress.selectFiles': 'Select Files',
    'compress.format': 'Output Format',
    'compress.selectFormat': 'Select format',
    'compress.autoFormat': 'Auto (Recommended)',
    'compress.quality': 'Quality Level',
    'compress.processing': 'Compressing...',
    'compress.compressImages': 'Compress Images',
    'compress.downloadAll': 'Download All',
    'compress.clearAll': 'Clear All',
    'compress.trySample': 'Try Sample File',
    'compress.batchProcessing': 'Batch Processing',
    'compress.multipleFormats': 'Multiple Formats',
    'compress.apiAccess': 'API Access',
    'compress.secureProcessing': 'Secure Processing',
    'compress.signUpFeatures': 'Sign Up & Get More Features',
    'compress.unlockFeatures': 'Unlock Full Features',
    'compress.getUnlimitedAccess': 'Get unlimited access to all features',
    'compress.trackHistory': 'Track your compression history',
    'compress.viewStats': 'View detailed compression statistics',
    'compress.createFreeAccount': 'Create Free Account',
    'compress.viewAll': 'View All',
    'compress.qualityPreset': 'Quality Preset',
    'compress.qualityBest': 'Best Quality',
    'compress.qualityHigh': 'High Quality',
    'compress.qualityMedium': 'Medium Quality',
    'compress.qualitySmall': 'Small File',
    'compress.qualityMinimum': 'Smallest File',
    'compress.showAdvanced': 'Show Advanced Options',
    'compress.hideAdvanced': 'Hide Advanced Options',
    'compress.autoRecommended': 'Auto (Recommended)',
    'compress.noFileChosen': 'No file chosen',
    'compress.dropImagesHere': 'Drop images here',
    'compress.supportFormats': 'Support formats',
    'compress.trySampleFile': 'Try Sample File',
    'compress.best': 'Best',
    'compress.qualityPercent': 'Quality',
    'compress.fiftyFreeDaily': '50 free compressions daily',
    'compress.premiumPlans': 'Premium plans available',
    'compress.freeCompressionAvailable': 'Free compression available - no registration required',
    'compress.professionalOptimization': 'Professional image optimization',
    'compress.filesProcessedSecurely': 'Files processed securely',
    'compress.createFreeAccount': 'Create Free Account',
    'compress.processingStatus': 'Processing...',
    'compress.processingProgress': 'Processing ({completed}/{total})',
    'compress.resizeImage': 'Resize image',
    'compress.colorFilter': 'Color filter',
    'compress.noFilter': 'No filter',
    'compress.grayscale': 'Grayscale',
    'compress.sepia': 'Sepia',
    'compress.vintage': 'Vintage',
    
    // Home page features (English)
    'home.title': 'Image Compressor',
    'home.subtitle': 'Compress images up to 90% smaller while maintaining visual quality. Perfect for web optimization and storage.',
    'home.batchProcessing': 'Batch Processing',
    'home.multipleFormats': 'Multiple Formats',
    'home.apiAccess': 'API Access',
    'home.secureProcessing': 'Secure Processing',
    'home.seoTitle': '#1 Image Compressor Tool 2025 | Trusted by 10M+ Users Worldwide',
    'home.popularSearches': 'Popular searches: compress image • image compressor • compress photos • reduce image size • compress jpeg • compress png • webp converter • tinypng alternative • bulk image compressor • best image compression tool 2025',
    'home.feature1.title': 'Batch Processing',
    'home.feature1.desc': 'Process hundreds of images simultaneously with our high-performance compression system.',
    'home.feature2.title': 'Multiple Formats',
    'home.feature2.desc': 'Support for JPG, PNG, WebP, HEIC and many other formats with automatic conversion.',
    'home.feature3.title': 'API Access',
    'home.feature3.desc': 'Integrate compression into your workflow with our powerful REST API.',
    'home.feature4.title': 'Secure Processing',
    'home.feature4.desc': 'All images are processed locally and automatically deleted for maximum security.',
    
    // Educational Content - English
    'education.title': 'Complete Guide to Image Compression',
    'education.subtitle': 'Learn everything about image compression, from basic concepts to advanced techniques.',
    'education.tipsTitle': 'Professional Image Compression Tips',
    'education.tip1Title': 'Choose the Right Format',
    'education.tip1Desc': 'JPEG for photos, PNG for graphics with transparency, WebP for modern browsers.',
    'education.tip2Title': 'Optimize Quality Settings',
    'education.tip2Desc': 'Use 80-85% quality for web images to balance file size and visual quality.',
    'education.tip3Title': 'Resize Before Compressing',
    'education.tip3Desc': 'Scale images to their display size before compression for maximum file size reduction.',
    'education.tip4Title': 'Consider Your Audience',
    'education.tip4Desc': 'Higher compression for mobile users, moderate compression for desktop viewing.',
    'education.tip5Title': 'Test and Compare',
    'education.tip5Desc': 'Always preview compressed images to ensure quality meets your standards.',
    'education.tip6Title': 'Batch Process',
    'education.tip6Desc': 'Upload multiple images at once to save time and ensure consistent settings.',
    'education.formatComparisonTitle': 'Image Format Comparison Guide',
    'education.formatHeader': 'Format',
    'education.bestForHeader': 'Best For',
    'education.compressionHeader': 'Compression',
    'education.transparencyHeader': 'Transparency',
    'education.jpegRow': 'Photographs, complex images',
    'education.excellentLossy': 'Excellent (lossy)',
    'education.no': 'No',
    'education.pngRow': 'Graphics, logos, screenshots',
    'education.goodLossless': 'Good (lossless)',
    'education.yes': 'Yes',
    'education.webpRow': 'Modern web applications',
    'education.superior': 'Superior',
    'education.heifRow': 'Mobile photography',
    'education.excellent': 'Excellent',
    'education.limited': 'Limited',
    'education.qualityGuideTitle': 'Quality vs File Size Guide',
    'education.highQualityTitle': 'High Quality (90-100%)',
    'education.balancedTitle': 'Balanced (70-85%)',
    'education.aggressiveTitle': 'Aggressive (50-70%)',
    'education.highQualityBest': 'Best for: Print, archival, professional photography',
    'education.highQualityTrade': 'Trade-off: Large file sizes, slower loading',
    'education.balancedBest': 'Best for: Web images, social media, blogs',
    'education.balancedTrade': 'Trade-off: Good quality, reasonable file size',
    'education.aggressiveBest': 'Best for: Thumbnails, previews, mobile',
    'education.aggressiveTrade': 'Trade-off: Smaller files, some quality loss',
    'education.proTipDesc': 'Start with 80% quality and adjust based on your specific needs. Most viewers won\'t notice the difference, but your website will load significantly faster.',
    
    // Landing Page
    'landing.title': 'Professional Image Compression',
    'landing.subtitle': 'Compress images up to 90% smaller while maintaining visual quality. Perfect for web optimization and storage.',
    'landing.cta': 'Start Compressing Free',
    'landing.features.title': 'Why Choose CompressHub?',
    'landing.features.subtitle': 'Professional-grade image compression with advanced algorithms and enterprise features.',
    'landing.feature1.title': 'Lightning Fast',
    'landing.feature1.desc': 'Process hundreds of images in seconds with our optimized compression engine.',
    'landing.feature2.title': 'Visual Quality',
    'landing.feature2.desc': 'Advanced algorithms preserve image quality while maximizing compression.',
    'landing.feature3.title': 'Developer APIs',
    'landing.feature3.desc': 'Integrate compression into your workflow with our powerful REST API.',
    'landing.feature4.title': 'Secure Processing',
    'landing.feature4.desc': 'End-to-end encryption ensures your images remain private and protected.',
    'landing.getStarted': 'Get Started Free',
    'landing.pricing.title': 'Simple Pricing',
    'landing.pricing.free': 'Free',
    'landing.pricing.free.desc': '50 compressions per day',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.desc': 'Unlimited compressions',
    'landing.pricing.pro.price': '$9/month',
    
    // Compress Page
    'compress.upload.title': 'Drop images here or click to upload',
    'compress.upload.subtitle': 'Support for JPG, PNG, WebP, HEIC files',
    'compress.upload.limit': 'Free users: up to 10 files, 50MB each',
    'compress.download': 'Download',
    'compress.stats.today': 'Today',
    'compress.stats.total': 'Total',
    'compress.stats.compressions': 'Compressions',
    'compress.stats.saved': 'Size Saved',
    
    // Stats Card
    'stats.todayActivity': "Today's Activity",
    'stats.imagesCompressed': 'Images Compressed',
    'stats.totalSizeSaved': 'Total Size Saved',
    'stats.averageReduction': 'Average Reduction',
    'stats.freeTierUsage': 'Free tier usage',
    
    // Recent History
    'recent.title': 'Recent Compressions',
    'recent.viewAll': 'View all',
    
    // Upgrade Card
    'upgrade.title': 'Upgrade to Pro',
    'upgrade.desc': 'Unlock unlimited compressions, larger files, batch processing, and priority support.',
    'upgrade.feature1': 'Unlimited compressions per day',
    'upgrade.feature2': 'Process files up to 100MB each',
    'upgrade.feature3': 'Batch upload up to 100 files',
    'upgrade.feature4': 'Priority processing speed',
    'upgrade.feature5': 'Advanced API access',
    'upgrade.feature6': '24/7 priority support',
    'upgrade.button': 'Upgrade Now - $9/month',
    
    // Checkout
    'checkout.title': 'Upgrade to Pro',
    'checkout.subtitle': 'Unlock unlimited compression and premium features for $9/month',
    'checkout.features': 'Premium Features',
    'checkout.feature.unlimited': 'Unlimited Daily Use',
    'checkout.feature.large': 'Files up to 100MB',
    'checkout.feature.batch': 'Batch Process 100 Files',
    'checkout.feature.priority': 'Priority Processing Speed',
    'checkout.feature.api': 'Advanced API Access',
    'checkout.feature.support': '24/7 Priority Support',
    'checkout.firstName': 'First Name',
    'checkout.lastName': 'Last Name',
    'checkout.email': 'Email Address',
    'checkout.password': 'Password',
    'checkout.firstNamePlaceholder': 'Enter your first name',
    'checkout.lastNamePlaceholder': 'Enter your last name',
    'checkout.emailPlaceholder': 'Enter your email address',
    'checkout.passwordPlaceholder': 'Create a secure password',
    'checkout.promoCode': 'Have a promo code?',
    'checkout.hidePromo': 'Hide promo code',
    'checkout.promoPlaceholder': 'Enter promo code',
    'checkout.payment': 'Secure Payment',
    'checkout.processing': 'Processing...',
    'checkout.startPro': 'Start Pro - $9/month',
    'checkout.subscribeNow': 'Subscribe Now - $9/month',
    'checkout.missingInfo': 'Missing Information',
    'checkout.fillFields': 'Please fill in email and password.',
    'checkout.paymentFailed': 'Payment Failed',
    'checkout.paymentSuccess': 'Payment Successful',
    'checkout.welcomePro': 'Welcome to Pro! You now have unlimited compression.',
    'checkout.upgradeSuccess': 'Upgrade Successful',
    'checkout.nowPro': 'You are now a Pro member with unlimited compression!',
    'checkout.batchProcessing': 'Batch Processing (100 files)',
    'checkout.priorityProcessing': 'Priority Processing',
    'checkout.unlimitedCompressions': 'Unlimited Compressions',
    'checkout.advancedSettings': 'Advanced Settings',
    'checkout.prioritySupport': 'Priority Support',
    'checkout.fullFeatures': 'Full Features',
    'checkout.monthlyBilling': 'Monthly Billing',
    'checkout.cancelAnytime': 'Cancel Anytime',
    'checkout.secureCheckout': 'Secure Checkout',
    'checkout.moneyBack': '30-Day Money Back Guarantee',
    'checkout.existingUser': 'Already have an account?',
    'checkout.signInInstead': 'Sign in instead',
    'checkout.subscribePro': 'Subscribe Pro - $9/month',
    'checkout.upgradeTitle': 'Upgrade to CompressHub Pro',
    'checkout.unlimitedFeatures': 'Unlock unlimited compression with professional features',
    'checkout.whatsIncluded': 'What\'s Included',
    'checkout.sslSecure': 'SSL Secure',
    'checkout.sslSecured': 'SSL Secured',
    'checkout.pciCompliant': 'PCI Compliant',
    'checkout.rating': '4.9/5 Rating',
    'checkout.createAccountSubscribe': 'Create Account & Subscribe',
    'checkout.joinThousands': 'Join thousands of creators using CompressHub Pro',
    'checkout.completeUpgrade': 'Complete Your Upgrade',
    'checkout.addPaymentMethod': 'Add payment method to unlock Pro features',
    
    // Pricing page features (English)
    'pricing.proFeatures': 'Pro Features',
    'pricing.upgradeTitle': 'Upgrade to Pro',
    'pricing.unlimitedFeatures': 'Unlock unlimited compressions, larger files, batch processing, and priority support.',
    'pricing.unlimitedCompressions': 'Unlimited compressions per day',
    'pricing.filesUpTo100MB': 'Process files up to 100MB each',
    'pricing.batchProcessing100': 'Batch upload up to 100 files',
    'pricing.priorityProcessing': 'Priority processing speed',
    'pricing.apiAccess': 'Advanced API access',
    'pricing.prioritySupport': '24/7 priority support',
    'pricing.upgradeNow': 'Upgrade Now',
    'checkout.perMonth': 'per month • Cancel anytime',
    
    // Messages
    'message.processing': 'Processing...',
    'message.unauthorized': 'Unauthorized',
    'message.loginRequired': 'You are logged out. Logging in again...',
    'message.paymentSuccess': 'Welcome to CompressHub Pro!',
    'message.paymentFailed': 'Payment Failed',
    'message.subscriptionActive': 'Your subscription has been activated.',
    'message.accountCreated': 'Your account has been created and subscription activated.',
    
    // Common
    'common.loading': 'Loading...',
    'common.cancel': 'Cancel',
    'common.save': 'Save',
    'common.close': 'Close',
    'common.back': 'Back',
    'common.next': 'Next',
    'common.submit': 'Submit',
    'common.upload': 'Upload',
    'common.download': 'Download',
    'message.processing': 'Processing...',
    'common.delete': 'Delete',
    
    // App name and footer
    'app.name': 'CompressHub',
    'landing.readyToCompress': 'Ready to compress your images?',
    'landing.trustMessage': 'Join thousands of professionals who trust CompressHub for their image optimization needs.',
    'footer.description': 'The most advanced image compression platform for professionals and businesses.',
    'footer.copyright': 'All rights reserved.',
    'common.edit': 'Edit',
    'common.settings': 'Settings',
    'common.profile': 'Profile',
    'common.help': 'Help',
    'common.about': 'About',
    'common.contact': 'Contact',
    'common.privacy': 'Privacy Policy',
    'common.terms': 'Terms of Service',

    // Ultimate Guide SEO Section (English)
    'education.ultimateGuideTitle': 'The Ultimate Image Compression Guide 2025',
    'education.ultimateGuideDesc': 'Master the art of image optimization with our comprehensive guide. Learn from industry experts and achieve professional results.',
    'education.jpegTitle': 'JPEG Compression',
    'education.jpegDesc': 'Master JPEG optimization techniques for web and print. Learn quality settings, progressive encoding, and color space optimization.',
    'education.bestForPhotos': 'Best for photos',
    'education.pngTitle': 'PNG Optimization',
    'education.pngDesc': 'Advanced PNG compression strategies for transparency preservation. Palette optimization and lossless compression techniques.',
    'education.bestForGraphics': 'Best for graphics',
    'education.webpTitle': 'WebP Conversion',
    'education.webpDesc': 'Next-generation WebP format for superior compression ratios. Browser compatibility and fallback strategies included.',
    'education.bestForWeb': 'Best for web',
    'education.bulkTitle': 'Bulk Processing',
    'education.bulkDesc': 'Enterprise-grade batch compression workflows. API integration and automated optimization pipelines for scale.',
    'education.bestForEnterprise': 'Best for enterprise',

    // ROI Calculator translations
    'education.storageSavingsTitle': 'Storage Savings',
    'education.storageSavingsDesc': 'Reduce storage costs by 60-80% across your entire image library.',
    'education.savingsAmount': '$500/month saved',
    'education.savingsNote': '*Based on 10TB image storage',
    'education.performanceGainsTitle': 'Performance Gains',
    'education.performanceGainsDesc': 'Improve page load speeds and user experience metrics.',
    'education.fasterLoadingPercent': '40% faster loading',
    'education.performanceNote': '*Average improvement across sites',
    'education.conversionIncreaseTitle': 'Conversion Increase',
    'education.conversionDesc': 'Higher conversion rates from improved user experience.',
    'education.conversionPercent': '+25% conversions',
    'education.conversionNote': '*E-commerce client average',
    'education.techSpecsTitle': 'Technical Specifications & Standards',
    'education.techSupportedFormats': 'Supported Formats & Algorithms',
    'education.webPerfTitle': 'Web Performance Standards',
    'education.mobileOptTitle': 'Mobile Optimization Strategy',

    // Educational Content - Landing Page
    'education.guideTitle': 'Complete Guide to Image Compression',
    'education.guideSubtitle': 'Learn everything you need to know about optimizing your images for web, mobile, and print.',
    'education.webDevTitle': 'Web Development',
    'education.webDevDesc': 'Optimize images for faster websites and better user experience. Compressed images reduce loading times and improve SEO rankings.',
    'education.compressionTitle': 'Understanding Image Compression',
    'education.compressionDesc': 'Image compression reduces file size while maintaining visual quality. There are two main types: lossless (PNG) and lossy (JPEG). Lossless compression preserves all original data, while lossy compression removes some data to achieve smaller file sizes.',
    'education.jpegBest': 'JPEG: Best for photos and complex images',
    'education.pngBest': 'PNG: Ideal for graphics with transparency',
    'education.webpBest': 'WebP: Modern format with superior compression',
    'education.performanceTitle': 'Web Performance Impact',
    'education.performanceDesc': 'Optimized images significantly improve website loading speed and user experience. Studies show that a 1-second delay in page load time can reduce conversions by up to 7%.',
    'education.fasterLoading': '40% faster page load times',
    'education.reducedBandwidth': 'Reduced bandwidth usage',
    'education.betterSeo': 'Better SEO rankings',
    'education.bestPracticesTitle': 'Compression Best Practices',
    'education.bestPracticesDesc': 'Follow these industry-standard practices to achieve optimal results while maintaining image quality that meets professional standards.',
    'education.qualityRange': 'Use 80-85% quality for web images',
    'education.resizeFirst': 'Resize images to display dimensions',
    'education.chooseFormat': 'Choose appropriate format for content',
    'education.technicalTitle': 'Technical Deep Dive: How Image Compression Works',
    'education.lossyVsLossless': 'Lossy vs Lossless Compression',
    'education.lossyDesc': 'Lossy compression permanently removes some image data to achieve smaller file sizes. This method is highly effective for photographs and complex images where minor quality loss is acceptable.',
    'education.losslessDesc': 'Lossless compression reduces file size without losing any image data. Every pixel remains exactly as it was in the original image, making it perfect for graphics, logos, and images requiring pixel-perfect accuracy.',
    'education.whenToUse': 'When to Use Each:',
    'education.lossyUse': 'Lossy (JPEG): Photos, artwork, complex images',
    'education.losslessUse': 'Lossless (PNG): Screenshots, graphics, logos',
    'education.webpUse': 'WebP: Modern websites supporting advanced compression',
    'education.qualityBalance': 'Quality vs File Size Balance',
    'education.balanceDesc': 'Finding the optimal balance between image quality and file size is crucial for web performance. Our compression algorithm analyzes each image to determine the best settings.',
    'education.largeFiles': 'Large file size',
    'education.optimalWeb': 'Optimal for web',
    'education.smallestFiles': 'Smallest files',
    'education.applicationsTitle': 'Real-World Applications',
    'education.applicationsDesc': 'Discover how different industries benefit from professional image compression solutions.',
    'education.webDev': 'Web Development',
    'education.ecommerce': 'E-commerce',
    'education.ecommerceDesc': 'Reduce product image sizes without compromising quality, leading to faster checkout and higher conversion rates.',
    'education.contentCreation': 'Content Creation',
    'education.contentDesc': 'Prepare images for social media, blogs, and marketing materials with optimal file sizes for each platform.',
    'education.mobileApps': 'Mobile Apps',
    'education.mobileDesc': 'Reduce app bundle sizes and improve loading times by optimizing images for mobile devices and varying screen densities.',

    // Educational Content - Compress Page
    'education.tipsTitle': 'Professional Image Compression Tips',
    'education.tip1Title': 'Choose the Right Format',
    'education.tip1Desc': 'JPEG for photos, PNG for graphics with transparency, WebP for modern browsers.',
    'education.tip2Title': 'Optimize Quality Settings',
    'education.tip2Desc': 'Use 80-85% quality for web images to balance file size and visual quality.',
    'education.tip3Title': 'Resize Before Compressing',
    'education.tip3Desc': 'Scale images to their display size before compression for maximum file size reduction.',
    'education.tip4Title': 'Consider Your Audience',
    'education.tip4Desc': 'Higher compression for mobile users, moderate compression for desktop viewing.',
    'education.tip5Title': 'Test and Compare',
    'education.tip5Desc': 'Always preview compressed images to ensure quality meets your standards.',
    'education.tip6Title': 'Batch Process',
    'education.tip6Desc': 'Upload multiple images at once to save time and ensure consistent settings.',
    'education.formatComparisonTitle': 'Image Format Comparison Guide',
    'education.formatHeader': 'Format',
    'education.bestForHeader': 'Best For',
    'education.compressionHeader': 'Compression',
    'education.transparencyHeader': 'Transparency',
    'education.jpegRow': 'Photographs, complex images',
    'education.pngRow': 'Graphics, logos, screenshots',
    'education.webpRow': 'Modern web applications',
    'education.heifRow': 'Mobile photography',
    'education.excellentLossy': 'Excellent (lossy)',
    'education.goodLossless': 'Good (lossless)',
    'education.superior': 'Superior',
    'education.excellent': 'Excellent',
    'education.yes': 'Yes',
    'education.no': 'No',
    'education.qualityGuideTitle': 'Quality vs File Size Guide',
    'education.balanceTitle': 'Quality vs File Size Balance',
    'education.balanceDesc': 'Finding the optimal balance between image quality and file size is crucial for web performance. Our compression algorithm analyzes each image to determine the best settings.',
    'education.highQuality': 'High Quality',
    'education.balanced': 'Balanced',
    'education.aggressive': 'Aggressive',
    'education.largeFiles': 'Large file size',
    'education.optimalWeb': 'Optimal for web', 
    'education.smallestFiles': 'Smallest files',
    'education.highQualityTitle': 'High Quality',
    'education.balancedTitle': 'Balanced Quality',
    'education.aggressiveTitle': 'Aggressive Compression',
    'education.highQualityBest': 'Best for: Print, archival, professional photography',
    'education.highQualityTrade': 'Trade-off: Large file sizes, slower loading',
    'education.balancedBest': 'Best for: Web images, social media, blogs',
    'education.balancedTrade': 'Trade-off: Good quality, reasonable file size',
    'education.aggressiveBest': 'Best for: Thumbnails, previews, mobile',
    'education.aggressiveTrade': 'Trade-off: Smaller files, some quality loss',
    'education.proTip': '💡 Pro Tip',
    'education.proTipDesc': 'Start with 80% quality and adjust based on your specific needs. Most viewers won\'t notice the difference, but your website will load significantly faster.',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': 'Enterprise Image Compression Solutions',
    'education.ecommerceOptTitle': 'E-commerce Optimization',
    'education.ecommerceOptDesc': 'Online retailers using CompressHub Pro report 40% faster page load times and 25% higher conversion rates. Product images load instantly, reducing cart abandonment and improving customer experience.',
    'education.batchProcess': 'Batch process 1000s of product images',
    'education.consistentQuality': 'Maintain consistent quality across catalog',
    'education.optimizeMobile': 'Optimize for mobile shoppers',
    'education.cmsTitle': 'Content Management Systems',
    'education.cmsDesc': 'Publishers and bloggers save 60% on storage costs while improving SEO rankings. Compressed images load faster, reducing bounce rates and improving search engine performance.',
    'education.apiIntegration': 'API integration with WordPress, Drupal',
    'education.autoCompression': 'Automatic compression on upload',
    'education.seoOptimized': 'SEO-optimized file sizes',
    'education.mobileDevTitle': 'Mobile App Development',
    'education.mobileDevDesc': 'Mobile developers reduce app bundle sizes by up to 75% while maintaining visual quality. Smaller apps download faster and use less device storage.',
    'education.optimizeIosAndroid': 'Optimize for iOS and Android',
    'education.densitySupport': 'Multiple density support',
    'education.fasterApproval': 'Faster app store approval',
    'education.roiTitle': 'Calculate Your Return on Investment',
    'education.storageSavings': 'Storage Savings',
    'education.storageSavingsDesc': 'Reduce storage costs by 60-80% across your entire image library.',
    'education.savingsAmount': '$500/month saved',
    'education.savingsNote': '*Based on 10TB image storage',
    'education.performanceGains': 'Performance Gains',
    'education.performanceGainsDesc': 'Improve page load speeds and user experience metrics.',
    'education.fasterLoadingPercent': '40% faster loading',
    'education.performanceNote': '*Average improvement across sites',
    'education.conversionIncrease': 'Conversion Increase',
    'education.conversionDesc': 'Higher conversion rates from improved user experience.',
    'education.conversionPercent': '+25% conversions',
    'education.conversionNote': '*E-commerce client average',
    'education.techSpecsTitle': 'Technical Specifications & Standards',
    'education.supportedFormatsTitle': 'Supported Formats & Algorithms',
    'education.jpegOptTitle': 'JPEG Optimization',
    'education.jpegOptDesc': 'Progressive JPEG encoding, Huffman table optimization, chroma subsampling',
    'education.pngCompTitle': 'PNG Compression',
    'education.pngCompDesc': 'DEFLATE algorithm optimization, palette reduction, alpha channel preservation',
    'education.webpFormatTitle': 'WebP Modern Format',
    'education.webpFormatDesc': 'VP8/VP9 encoding, lossy and lossless modes, advanced alpha transparency',
    'education.heifTitle': 'HEIF/HEIC Support',
    'education.heifDesc': 'High efficiency encoding, HDR support, burst photo optimization',
    'education.enterpriseFeaturesTitle': 'Enterprise Features',
    'education.apiIntegrationTitle': 'API Integration',
    'education.apiIntegrationDesc': 'RESTful API, webhook support, batch processing endpoints, real-time status updates',
    'education.securityTitle': 'Security & Compliance',
    'education.securityDesc': 'SOC 2 Type II, GDPR compliant, end-to-end encryption, automatic file deletion',
    'education.performanceMonitoringTitle': 'Performance Monitoring',
    'education.performanceMonitoringDesc': 'Real-time analytics, compression ratio tracking, bandwidth savings reports',
    'education.scaleTitle': 'Scale & Reliability',
    'education.scaleDesc': '99.9% uptime SLA, auto-scaling infrastructure, global CDN integration',
    'education.industryBestTitle': 'Industry Best Practices for Image Optimization',
    'education.webPerfTitle': 'Web Performance Standards',
    'education.webPerfDesc': '• Core Web Vitals: Google\'s performance metrics directly impact SEO rankings. Optimized images improve Largest Contentful Paint (LCP) scores by up to 40%.',
    'education.progressiveLoadingDesc': '• Progressive Loading: Implement progressive JPEG encoding for better perceived performance. Users see image content while it loads.',
    'education.responsiveImagesDesc': '• Responsive Images: Use srcset attributes with multiple image sizes to serve appropriate versions for different screen sizes and resolutions.',
    'education.lazyLoadingDesc': '• Lazy Loading: Combine image compression with lazy loading to reduce initial page load time and bandwidth usage.',
    'education.mobileOptTitle': 'Mobile Optimization Strategy',
    'education.adaptiveQualityDesc': '• Adaptive Quality: Serve lower quality images to users on slow connections while maintaining high quality for fast networks.',
    'education.formatSelectionDesc': '• Format Selection: Use WebP for supported browsers (95% coverage) with JPEG fallbacks for older browsers.',
    'education.bandwidthAwarenessDesc': '• Bandwidth Awareness: Consider data-saver modes and implement quality toggles for mobile users on limited data plans.',
    'education.appBundleDesc': '• App Bundle Optimization: For mobile apps, compress bundled images to reduce download size and improve app store approval rates.',
    
    // Missing pricing page enterprise content (English)
    'pricing.enterpriseTitle': 'Enterprise Image Compression Solutions',
    'pricing.ecommerceTitle': 'E-commerce Optimization',
    'pricing.ecommerceDesc': 'Online retailers using CompressHub Pro report 40% faster page load times and 25% higher conversion rates. Product images load instantly, reducing cart abandonment and improving customer experience.',
    'pricing.batchProcess1000s': 'Batch process thousands of product images',
    'pricing.maintainQuality': 'Maintain consistent quality across catalog',
    'pricing.optimizeMobile': 'Optimize for mobile shoppers',
    'pricing.cmsTitle': 'Content Management Systems',
    'pricing.cmsDesc': 'Publishers and bloggers save 60% on storage costs while improving SEO rankings. Compressed images load faster, reduce bounce rates and improve search engine performance.',
    'pricing.apiIntegration': 'API integration with WordPress, Drupal',
    'pricing.autoCompression': 'Automatic compression on upload',
    'pricing.seoOptimized': 'SEO-optimized file sizes',
    'pricing.mobileDevTitle': 'Mobile App Development',
    'pricing.mobileDevDesc': 'Mobile developers reduce app bundle sizes by up to 75% while maintaining visual quality. Smaller apps download faster and use less device storage.',
    'pricing.optimizeIosAndroid': 'Optimize for iOS and Android',
    'pricing.multipleDensity': 'Multiple density support',
    'pricing.fasterAppStore': 'Faster app store approval',
  },
  
  es: {
    // Navigation
    'nav.home': 'Inicio',
    'nav.compress': 'Comprimir',
    'nav.history': 'Historial',
    'nav.login': 'Iniciar Sesión',
    'nav.signup': 'Registrarse',
    'nav.logout': 'Cerrar Sesión',
    'nav.pricing': 'Precios',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Plan Gratuito',
    'nav.proActive': 'Pro Activo',
    
    // Login Page
    'login.title': 'Bienvenido de Nuevo',
    'login.subtitle': 'Inicia sesión en tu cuenta para continuar',
    'login.formTitle': 'Iniciar Sesión',
    'login.email': 'Correo Electrónico',
    'login.emailPlaceholder': 'Ingresa tu correo electrónico',
    'login.password': 'Contraseña',
    'login.passwordPlaceholder': 'Ingresa tu contraseña',
    'login.signingIn': 'Iniciando sesión...',
    'login.signIn': 'Iniciar Sesión',
    'login.noAccount': '¿No tienes una cuenta?',
    'login.signUp': 'Registrarse',
    'login.backToHome': '← Volver al inicio',
    'login.errors.failed': 'Error de Inicio de Sesión',
    'login.errors.invalid': 'Correo electrónico o contraseña inválidos',
    'login.errors.generic': 'Ocurrió un error. Por favor intenta de nuevo.',
    
    // Signup Page
    'signup.title': 'Crear Cuenta',
    'signup.subtitle': 'Únete a CompressHub y comienza a optimizar tus imágenes',
    'signup.formTitle': 'Registrarse',
    'signup.firstName': 'Nombre',
    'signup.firstNamePlaceholder': 'Juan',
    'signup.lastName': 'Apellido',
    'signup.lastNamePlaceholder': 'Pérez',
    'signup.email': 'Correo Electrónico',
    'signup.emailPlaceholder': 'juan@ejemplo.com',
    'signup.password': 'Contraseña',
    'signup.passwordPlaceholder': 'Al menos 6 caracteres',
    'signup.confirmPassword': 'Confirmar Contraseña',
    'signup.confirmPasswordPlaceholder': 'Confirma tu contraseña',
    'signup.creatingAccount': 'Creando cuenta...',
    'signup.createAccount': 'Crear Cuenta',
    'signup.haveAccount': '¿Ya tienes una cuenta?',
    'signup.signIn': 'Iniciar sesión',
    'signup.backToHome': '← Volver al inicio',
    'signup.success.title': 'Cuenta Creada',
    'signup.success.message': '¡Bienvenido a CompressHub! Ahora puedes comenzar a comprimir imágenes.',
    'signup.errors.failed': 'Error de Registro',
    'signup.errors.createFailed': 'Falló la creación de cuenta',
    'signup.errors.generic': 'Ocurrió un error. Por favor intenta de nuevo.',
    'signup.errors.firstNameShort': 'El nombre debe tener al menos 2 caracteres',
    'signup.errors.lastNameShort': 'El apellido debe tener al menos 2 caracteres',
    'signup.errors.emailInvalid': 'Por favor ingresa un correo electrónico válido',
    'signup.errors.passwordShort': 'La contraseña debe tener al menos 6 caracteres',
    'signup.errors.passwordMismatch': 'Las contraseñas no coinciden',
    
    // History Page
    'history.title': 'Historial de Compresión',
    'history.subtitle': 'Ve y descarga todas tus imágenes comprimidas anteriormente.',
    
    // Compressor Tool
    'compress.title': 'Compresor de Imágenes',
    'compress.secure': 'Archivos procesados de forma segura',
    'compress.dropFiles': 'Arrastra imágenes aquí o haz clic para explorar',
    'compress.supportedFormats': 'Soporte para JPG, PNG, WebP, HEIC hasta 50MB cada uno',
    'compress.selectFiles': 'Seleccionar Archivos',
    'compress.format': 'Formato de Salida',
    'compress.selectFormat': 'Seleccionar formato',
    'compress.autoFormat': 'Auto (Recomendado)',
    'compress.quality': 'Nivel de Calidad',
    'compress.processing': 'Comprimiendo...',
    'compress.compressImages': 'Comprimir Imágenes',
    'compress.downloadAll': 'Descargar Todo',
    'compress.clearAll': 'Limpiar Todo',
    'compress.freeCompressionAvailable': 'Compresión gratuita disponible - no se requiere registro',
    
    // Education translations (Spanish)
    'education.balanceTitle': 'Equilibrio entre Calidad e Tamaño de Archivo',
    'education.balanceDesc': 'Encontrar el equilibrio óptimo entre la calidad de imagen y el tamaño del archivo es crucial para el rendimiento web. Nuestro algoritmo de compresión analiza cada imagen para determinar la mejor configuración.',
    'education.highQuality': 'Mejor para: Impresión, archivo, fotografía profesional\n\nCompromiso: Archivos grandes, carga más lenta',
    'education.balanced': 'Mejor para: Imágenes web, redes sociales, blogs\n\nCompromiso: Buena calidad, tamaño de archivo razonable',
    'education.aggressive': 'Mejor para: Miniaturas, vistas previas, móvil\n\nCompromiso: Archivos más pequeños, alguna pérdida de calidad',
    'education.largeFiles': 'Archivos grandes',
    'education.optimalWeb': 'Óptimo para web',
    'education.smallestFiles': 'Archivos más pequeños',
    'education.highQualityTitle': 'Alta Calidad',
    'education.balancedTitle': 'Calidad Equilibrada',
    'education.aggressiveTitle': 'Compresión Agresiva',
    
    // Ultimate Guide SEO Section (Spanish)
    'education.ultimateGuideTitle': 'La Guía Definitiva de Compresión de Imágenes 2025',
    'education.ultimateGuideDesc': 'Domina el arte de la optimización de imágenes con nuestra guía completa. Aprende de expertos de la industria y logra resultados profesionales.',
    'education.jpegTitle': 'Compresión JPEG',
    'education.jpegDesc': 'Domina las técnicas de optimización JPEG para web e impresión. Aprende configuraciones de calidad, codificación progresiva y optimización del espacio de color.',
    'education.bestForPhotos': 'Mejor para fotos',
    'education.pngTitle': 'Optimización PNG',
    'education.pngDesc': 'Estrategias avanzadas de compresión PNG para preservación de transparencia. Optimización de paleta y técnicas de compresión sin pérdida.',
    'education.bestForGraphics': 'Mejor para gráficos',
    'education.webpTitle': 'Conversión WebP',
    'education.webpDesc': 'Formato WebP de nueva generación para ratios de compresión superiores. Compatibilidad de navegadores y estrategias de respaldo incluidas.',
    'education.bestForWeb': 'Mejor para web',
    'education.bulkTitle': 'Procesamiento Masivo',
    'education.bulkDesc': 'Flujos de trabajo de compresión por lotes de grado empresarial. Integración de API y canales de optimización automatizados para escala.',
    'education.bestForEnterprise': 'Mejor para empresas',
    
    // Landing Page
    'landing.title': 'Compresión Profesional de Imágenes',
    'landing.subtitle': 'Comprime imágenes hasta un 90% más pequeñas manteniendo la calidad visual. Perfecto para optimización web y almacenamiento.',
    'landing.cta': 'Comenzar Gratis',
    'landing.features.title': '¿Por qué elegir CompressHub?',
    'landing.features.subtitle': 'Compresión de imágenes de grado profesional con algoritmos avanzados y funciones empresariales.',
    'landing.feature1.title': 'Súper Rápido',
    'landing.feature1.desc': 'Procesa cientos de imágenes en segundos con nuestro motor de compresión optimizado.',
    'landing.feature2.title': 'Calidad Visual',
    'landing.feature2.desc': 'Algoritmos avanzados preservan la calidad de imagen maximizando la compresión.',
    'landing.feature3.title': 'APIs de Desarrollador',
    'landing.feature3.desc': 'Integra la compresión en tu flujo de trabajo con nuestra potente API REST.',
    'landing.feature4.title': 'Procesamiento Seguro',
    'landing.feature4.desc': 'El cifrado de extremo a extremo garantiza que tus imágenes permanezcan privadas y protegidas.',
    'landing.getStarted': 'Comenzar Gratis',
    'landing.pricing.title': 'Precios Simples',
    'landing.pricing.free': 'Gratis',
    'landing.pricing.free.desc': '50 compresiones por día',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.desc': 'Compresiones ilimitadas',
    'landing.pricing.pro.price': '$9/mes',
    
    // Compress Page
    'compress.upload.title': 'Arrastra imágenes aquí o haz clic para subir',
    'compress.upload.subtitle': 'Soporte para archivos JPG, PNG, WebP, HEIC',
    'compress.upload.limit': 'Usuarios gratuitos: hasta 10 archivos, 50MB cada uno',
    'compress.download': 'Descargar',
    'compress.stats.today': 'Hoy',
    'compress.stats.total': 'Total',
    'compress.stats.compressions': 'Compresiones',
    'compress.stats.saved': 'Tamaño Ahorrado',
    'compress.signUpFeatures': 'Registrarse y Obtener Más Funciones',
    'compress.secure': 'Archivos procesados de forma segura',
    'compress.qualityPreset': 'Preajuste de Calidad',
    'compress.qualityBest': 'Mejor',
    'compress.qualityHigh': 'Alto',
    'compress.qualityMedium': 'Medio',
    'compress.qualitySmall': 'Pequeño',
    'compress.qualityMinimum': 'Mínimo',
    'compress.format': 'Formato',
    'compress.autoRecommended': 'Auto (Recomendado)',
    'compress.showAdvanced': 'Mostrar Opciones Avanzadas',
    'compress.hideAdvanced': 'Ocultar Opciones Avanzadas',
    'education.highQuality': 'Alta Calidad (90-100%)',
    'education.balanced': 'Equilibrado (70-85%)',
    'education.aggressive': 'Agresivo (50-70%)',
    'compress.professionalOptimization': 'Optimización profesional de imágenes',
    'education.highQualityTitle': 'Alta Calidad (90-100%)',
    'education.balancedTitle': 'Equilibrado (70-85%)',
    'education.aggressiveTitle': 'Agresivo (50-70%)',
    
    // Stats Card
    'stats.todayActivity': 'Actividad de Hoy',
    'stats.imagesCompressed': 'Imágenes Comprimidas',
    'stats.totalSizeSaved': 'Tamaño Total Ahorrado',
    'stats.averageReduction': 'Reducción Promedio',
    'stats.freeTierUsage': 'Uso del nivel gratuito',
    
    // Recent History
    'recent.title': 'Compresiones Recientes',
    'recent.viewAll': 'Ver todo',
    
    // Upgrade Card
    'upgrade.title': 'Actualizar a Pro',
    'upgrade.desc': 'Desbloquea compresiones ilimitadas, archivos más grandes, procesamiento por lotes y soporte prioritario.',
    'upgrade.feature1': 'Compresiones ilimitadas por día',
    'upgrade.feature2': 'Procesa archivos hasta 100MB cada uno',
    'upgrade.feature3': 'Carga por lotes hasta 100 archivos',
    'upgrade.feature4': 'Velocidad de procesamiento prioritaria',
    'upgrade.feature5': 'Acceso API avanzado',
    'upgrade.feature6': 'Soporte prioritario 24/7',
    'upgrade.button': 'Actualizar Ahora - $9/mes',
    
    // Checkout
    'checkout.title': 'Actualizar a Pro',
    'checkout.subtitle': 'Desbloquea compresión ilimitada y características premium por $9/mes',
    'checkout.features': 'Características Premium',
    'checkout.feature.unlimited': 'Uso Diario Ilimitado',
    'checkout.feature.large': 'Archivos hasta 100MB',
    'checkout.feature.batch': 'Proceso por Lotes 100 Archivos',
    'checkout.feature.priority': 'Velocidad de Procesamiento Prioritaria',
    'checkout.feature.api': 'Acceso API Avanzado',
    'checkout.feature.support': 'Soporte Prioritario 24/7',
    'checkout.firstName': 'Nombre',
    'checkout.lastName': 'Apellido',
    'checkout.email': 'Correo Electrónico',
    'checkout.password': 'Contraseña',
    'checkout.promoCode': '¿Tienes un código promocional?',
    'checkout.hidePromo': 'Ocultar código promocional',
    'checkout.payment': 'Información de Pago',
    'checkout.startPro': 'Comenzar Pro - $9/mes',
    'checkout.subscribePro': 'Suscribirse Pro - $9/mes',
    'checkout.perMonth': 'por mes • Cancela en cualquier momento',
    'checkout.upgradeTitle': 'Actualizar a CompressHub Pro',
    'checkout.unlimitedFeatures': 'Desbloquea compresión ilimitada con características profesionales',
    'checkout.sslSecure': 'SSL Seguro',
    'checkout.cancelAnytime': 'Cancelar en Cualquier Momento',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 de 2,000+ usuarios',
    'checkout.createAccountSubscribe': 'Crear Cuenta y Suscribirse',
    'checkout.joinThousands': 'Únete a miles de creadores que usan CompressHub Pro',
    'checkout.sslSecured': 'SSL Seguro',
    'checkout.pciCompliant': 'Compatible con PCI',
    'checkout.whatsIncluded': 'Qué se Incluye',
    'checkout.payment': 'Pago Seguro',
    'checkout.completeUpgrade': 'Completa tu Actualización',
    'checkout.addPaymentMethod': 'Añade método de pago para desbloquear funciones Pro',
    
    // Messages
    'message.processing': 'Procesando...',
    'message.unauthorized': 'No autorizado',
    'message.loginRequired': 'Has cerrado sesión. Iniciando sesión nuevamente...',
    'message.paymentSuccess': '¡Bienvenido a CompressHub Pro!',
    
    // App name and footer
    'app.name': 'CompressHub',
    'landing.readyToCompress': '¿Listo para comprimir tus imágenes?',
    'landing.trustMessage': 'Únete a miles de profesionales que confían en CompressHub para sus necesidades de optimización de imágenes.',
    'footer.description': 'La plataforma de compresión de imágenes más avanzada para profesionales y empresas.',
    'footer.copyright': 'Todos los derechos reservados.',
    'message.paymentFailed': 'Pago Fallido',
    'message.subscriptionActive': 'Tu suscripción ha sido activada.',
    'message.accountCreated': 'Tu cuenta ha sido creada y suscripción activada.',
    
    // Educational Content - Landing Page
    'education.guideTitle': 'Guía Completa de Compresión de Imágenes',
    'education.guideSubtitle': 'Aprende todo lo que necesitas saber para optimizar tus imágenes para web, móvil e impresión.',
    'education.webDevTitle': 'Desarrollo Web',
    'education.webDevDesc': 'Optimiza imágenes para sitios web más rápidos y mejor experiencia de usuario. Las imágenes comprimidas reducen los tiempos de carga y mejoran el ranking SEO.',
    'education.compressionTitle': 'Entendiendo la Compresión de Imágenes',
    'education.compressionDesc': 'La compresión de imágenes reduce el tamaño del archivo manteniendo la calidad visual. Hay dos tipos principales: sin pérdida (PNG) y con pérdida (JPEG). La compresión sin pérdida preserva todos los datos originales, mientras que la compresión con pérdida elimina algunos datos para lograr archivos más pequeños.',
    'education.jpegBest': 'JPEG: Mejor para fotos e imágenes complejas',
    'education.pngBest': 'PNG: Ideal para gráficos con transparencia',
    'education.webpBest': 'WebP: Formato moderno con compresión superior',
    'education.performanceTitle': 'Impacto en el Rendimiento Web',
    'education.performanceDesc': 'Las imágenes optimizadas mejoran significativamente la velocidad de carga del sitio web y la experiencia del usuario. Los estudios muestran que un retraso de 1 segundo en el tiempo de carga puede reducir las conversiones hasta un 7%.',
    'education.fasterLoading': '40% más rápido en tiempos de carga',
    'education.reducedBandwidth': 'Uso reducido de ancho de banda',
    'education.betterSeo': 'Mejores rankings SEO',
    'education.bestPracticesTitle': 'Mejores Prácticas de Compresión',
    'education.bestPracticesDesc': 'Sigue estas mejores prácticas estándar de la industria para lograr resultados óptimos manteniendo la calidad de imagen que cumple con estándares profesionales.',
    'education.qualityRange': 'Usa 80-85% de calidad para imágenes web',
    'education.resizeFirst': 'Redimensiona imágenes a dimensiones de visualización',
    'education.chooseFormat': 'Elige el formato apropiado para el contenido',
    
    // Missing education content translations for Spanish
    'education.storageSavingsTitle': 'Ahorro de Almacenamiento',
    'education.performanceGainsTitle': 'Mejoras de Rendimiento', 
    'education.conversionIncreaseTitle': 'Aumento de Conversión',
    'education.techSupportedFormats': 'Formatos Soportados y Algoritmos',
    
    // Missing compress page translations
    'education.formatComparisonTitle': 'Guía de Comparación de Formatos de Imagen',
    'education.formatHeader': 'Formato',
    'education.bestForHeader': 'Mejor Para',
    'education.compressionHeader': 'Compresión',
    'education.transparencyHeader': 'Transparencia',
    'education.jpegRow': 'Fotografías, imágenes complejas',
    'education.excellentLossy': 'Excelente (con pérdida)',
    'education.no': 'No',
    'education.pngRow': 'Gráficos, logos, capturas de pantalla',
    'education.goodLossless': 'Bueno (sin pérdida)',
    'education.yes': 'Sí',
    'education.webpRow': 'Aplicaciones web modernas',
    'education.superior': 'Superior',
    'education.heifRow': 'Fotografía móvil',
    'education.excellent': 'Excelente',
    'education.limited': 'Limitado',
    'education.qualityGuideTitle': 'Guía de Calidad vs Tamaño de Archivo',
    'education.highQualityBest': 'Mejor para: Impresión, archivo, fotografía profesional',
    'education.highQualityTrade': 'Compromiso: Archivos grandes, carga lenta',
    'education.balancedBest': 'Mejor para: Imágenes web, redes sociales, blogs',
    'education.balancedTrade': 'Compromiso: Buena calidad, tamaño razonable',
    'education.aggressiveBest': 'Mejor para: Miniaturas, vistas previas, móvil',
    'education.aggressiveTrade': 'Compromiso: Archivos más pequeños, algo de pérdida de calidad',
    'education.proTip': '💡 Consejo Profesional',
    'education.proTipDesc': 'Comienza con 80% de calidad y ajusta según tus necesidades específicas. La mayoría de los espectadores no notarán la diferencia, pero tu sitio web cargará significativamente más rápido.',
    
    // Home page missing translations
    'home.batchProcessing': 'Procesamiento por Lotes',
    'home.multipleFormats': 'Múltiples Formatos',
    'home.apiAccess': 'Acceso API',
    'home.secureProcessing': 'Procesamiento Seguro',
    'home.qualityBalance': 'Balance de Calidad vs Tamaño de Archivo',
    'home.qualityBalanceDesc': 'Encontrar el equilibrio óptimo entre calidad de imagen y tamaño de archivo es crucial para el rendimiento web. Nuestro algoritmo de compresión analiza cada imagen para determinar la mejor configuración.',
    'home.webpModern': 'WebP: Sitios web modernos que soportan compresión avanzada',
    'home.webDevelopment': 'Desarrollo Web',
    'home.ecommerce': 'E-commerce',
    'home.contentCreation': 'Creación de Contenido',
    'home.mobileApps': 'Aplicaciones Móviles',
    'education.contentCreation': 'Creación de Contenido',
    'education.contentDesc': 'Prepara imágenes para redes sociales, blogs y materiales de marketing con tamaños de archivo óptimos para cada plataforma.',
    'education.ecommerce': 'E-commerce',
    'education.ecommerceDesc': 'Reduce los tiempos de carga de las páginas de productos para mejorar las tasas de conversión y la experiencia del usuario.',
    'education.mobileApps': 'Aplicaciones Móviles',
    'education.mobileDesc': 'Minimiza el tamaño de las aplicaciones y mejora el rendimiento reduciendo el tamaño de los assets de imagen.',
    
    // Compress page missing translations
    'compress.freeCompressionAvailable': 'Compresión gratuita disponible a continuación • Regístrate para acceso ilimitado e historial',
    'compress.filesProcessedSecurely': 'Archivos procesados de forma segura',
    'compress.unlockFullFeatures': 'Desbloquear Todas las Características',
    'compress.getUnlimitedAccess': 'Obtén acceso ilimitado y características premium',
    'compress.trackHistory': 'Rastrear historial de compresión',
    'compress.viewStats': 'Ver estadísticas detalladas',
    'compress.fiftyFreeDaily': '50 compresiones gratuitas diarias',
    'compress.premiumPlans': 'Planes premium para acceso ilimitado',
    'compress.createFreeAccount': 'Crear Cuenta Gratuita',
    'compress.dropImagesHere': 'Suelta imágenes aquí o haz clic para explorar',
    'compress.supportFormats': 'Soporte para JPG, PNG, WebP, HEIC hasta 50MB cada uno',
    'compress.trySampleFile': 'Probar Archivo de Muestra',
    
    // Pricing page missing translations
    'pricing.proFeatures': 'Características Pro',
    'pricing.unlimitedCompressions': 'Compresiones Ilimitadas',
    'pricing.filesUpTo100MB': 'Archivos hasta 100MB',
    'pricing.batchProcessing100': 'Procesamiento por Lotes (100 archivos)',
    'pricing.priorityProcessing': 'Procesamiento Prioritario',
    'pricing.apiAccess': 'Acceso API',
    'pricing.upgradeNow': 'Actualizar Ahora',
    'pricing.cmsDesc': 'Los editores y bloggers ahorran un 60% en costos de almacenamiento mientras mejoran las clasificaciones SEO. Las imágenes comprimidas se cargan más rápido, reduciendo las tasas de rebote y mejorando el rendimiento del motor de búsqueda.',
    'pricing.apiIntegration': 'Integración API con WordPress, Drupal',
    'pricing.prioritySupport': 'Soporte Prioritario 24/7',
    'pricing.perMonth': '$9/mes',
    'pricing.cancelAnytime': 'Cancelar en cualquier momento',
    'pricing.upgradeToCompressHub': 'Actualizar a CompressHub Pro',
    'pricing.unlockUnlimited': 'Desbloquea compresión ilimitada con características profesionales por $9/mes',
    'pricing.sslSecure': 'SSL Seguro',
    'pricing.batchProcessing': 'Procesamiento por Lotes',
    'pricing.rating': '4.9/5 Calificación',
    
    // ROI Calculator translations
    'education.storageSavingsTitle': 'Ahorro de Almacenamiento',
    'education.storageSavingsDesc': 'Reduce los costos de almacenamiento en un 60-80% en toda tu biblioteca de imágenes.',
    'education.savingsAmount': '$500/mes ahorrado',
    'education.savingsNote': '*Basado en 10TB de almacenamiento de imágenes',
    'education.performanceGainsTitle': 'Ganancias de Rendimiento',
    'education.performanceGainsDesc': 'Mejora la velocidad de carga de páginas y métricas de experiencia del usuario.',
    'education.fasterLoadingPercent': '40% más rápido cargando',
    'education.performanceNote': '*Mejora promedio en sitios web',
    'education.conversionIncreaseTitle': 'Aumento de Conversiones',
    'education.conversionDesc': 'Tasas de conversión más altas por mejor experiencia del usuario.',
    'education.conversionPercent': '+25% conversiones',
    'education.conversionNote': '*Promedio de cliente e-commerce',
    'education.techSpecsTitle': 'Especificaciones Técnicas y Estándares',
    'education.techSupportedFormats': 'Formatos Compatibles y Algoritmos',
    'education.webPerfTitle': 'Estándares de Rendimiento Web',
    'education.mobileOptTitle': 'Estrategia de Optimización Móvil',

    // Enterprise content translations
    'pricing.enterpriseTitle': 'Soluciones de Compresión de Imágenes Empresariales',
    'pricing.ecommerceOptimization': 'Optimización de E-commerce',
    'pricing.ecommerceOptDesc': 'Los minoristas en línea que usan CompressHub Pro reportan tiempos de carga 40% más rápidos y tasas de conversión 25% más altas. Las imágenes de productos cargan instantáneamente, reduciendo el abandono del carrito y mejorando la experiencia del cliente.',
    'pricing.batchProcess1000s': 'Procesar por lotes miles de imágenes de productos',
    'pricing.maintainQuality': 'Mantener calidad consistente en todo el catálogo',
    'pricing.optimizeMobile': 'Optimizar para compradores móviles',
    'pricing.cmsTitle': 'Sistemas de Gestión de Contenido',
    'pricing.cmsDesc': 'Los editores y bloggers ahorran 60% en costos de almacenamiento mientras mejoran el ranking SEO. Las imágenes comprimidas cargan más rápido, reduciendo las tasas de rebote y mejorando el rendimiento en motores de búsqueda.',
    'pricing.apiIntegration': 'Integración API con WordPress, Drupal',
    'pricing.autoCompression': 'Compresión automática al subir',
    'pricing.seoOptimized': 'Tamaños de archivo optimizados para SEO',
    'pricing.mobileAppDev': 'Desarrollo de Aplicaciones Móviles',
    'pricing.mobileDevDesc': 'Los desarrolladores móviles reducen el tamaño del bundle de la app hasta un 75% mientras mantienen la calidad visual. Las aplicaciones más pequeñas se descargan más rápido y usan menos almacenamiento del dispositivo.',
    'pricing.optimizeIosAndroid': 'Optimizar para iOS y Android',
    'pricing.multipleDensity': 'Soporte para múltiples densidades',
    'pricing.fasterAppStore': 'Aprobación más rápida en app store',

    // Education Section
    'education.title': 'Guía Completa de Compresión de Imágenes',
    'education.subtitle': 'Aprende todo sobre la compresión de imágenes, desde conceptos básicos hasta técnicas avanzadas.',
    'education.technicalTitle': 'Inmersión Técnica: Cómo Funciona la Compresión de Imágenes',
    'education.lossyVsLossless': 'Compresión con Pérdida vs Sin Pérdida',
    'education.lossyDesc': 'La compresión con pérdida elimina algunos datos de imagen para reducir el tamaño del archivo. Esto resulta en archivos más pequeños pero con una ligera pérdida de calidad.',
    'education.losslessDesc': 'La compresión sin pérdida conserva todos los datos originales de la imagen. Los archivos son más grandes pero mantienen una calidad perfecta.',
    'education.whenToUse': 'Cuándo Usar Cada Tipo',
    'education.lossyUse': 'Con pérdida: Fotografías, imágenes web, redes sociales',
    'education.losslessUse': 'Sin pérdida: Logos, gráficos, imágenes médicas',
    'education.webpUse': 'WebP: Sitios web modernos que soportan compresión avanzada',
    'education.qualityBalance': 'Balance de Calidad vs Tamaño de Archivo',
    'education.balanceDesc': 'Encontrar el equilibrio óptimo entre calidad de imagen y tamaño de archivo es crucial para el rendimiento web. Nuestro algoritmo de compresión analiza cada imagen para determinar la mejor configuración.',
    'education.largeFiles': 'Archivos grandes',
    'education.optimalWeb': 'Óptimo para web',
    'education.smallestFiles': 'Archivos más pequeños',
    'education.algorithmsTitle': 'Algoritmos de Compresión',
    'education.jpegAlgorithm': 'JPEG utiliza transformada coseno discreta (DCT) para comprimir imágenes dividiendo la imagen en bloques de 8x8 píxeles.',
    'education.pngAlgorithm': 'PNG utiliza compresión DEFLATE, que combina el algoritmo LZ77 con codificación Huffman.',
    'education.webpAlgorithm': 'WebP utiliza compresión predictiva para reducir los datos necesarios para codificar una imagen.',
    'education.applicationsTitle': 'Casos de Uso en la Industria',
    'education.ecommerceTitle': 'E-commerce y Retail',
    'education.ecommerceDesc': 'Reduce los tiempos de carga de las páginas de productos para mejorar las tasas de conversión y la experiencia del usuario.',
    'education.mediaTitle': 'Medios Digitales y Publicación',
    'education.mediaDesc': 'Optimiza imágenes para sitios web, revistas digitales y plataformas de medios sociales.',
    'education.mobileTitle': 'Desarrollo de Aplicaciones Móviles',
    'education.mobileDesc': 'Minimiza el tamaño de las aplicaciones y mejora el rendimiento reduciendo el tamaño de los assets de imagen.',
    'education.marketingTitle': 'Marketing y Publicidad',
    'education.marketingDesc': 'Asegura que las campañas publicitarias se carguen rápidamente en todos los dispositivos y conexiones.',
    'education.tipsTitle': 'Consejos Profesionales de Compresión',
    'education.tip1Title': 'Elige el Formato Correcto',
    'education.tip1Desc': 'JPEG para fotografías, PNG para imágenes con transparencia, WebP para la web moderna.',
    'education.tip2Title': 'Optimiza para el Contexto',
    'education.tip2Desc': 'Las imágenes web pueden usar mayor compresión que las imágenes de impresión.',
    'education.tip3Title': 'Usa Herramientas de Calidad',
    'education.tip3Desc': 'Invierte en software de compresión profesional para obtener mejores resultados.',
    'education.tip4Title': 'Considera el Rendimiento',
    'education.tip4Desc': 'Equilibra la calidad de la imagen con los tiempos de carga para una experiencia de usuario óptima.',
    'education.tip5Title': 'Prueba y Compara',
    'education.tip5Desc': 'Siempre previsualiza las imágenes comprimidas para asegurar que la calidad cumple con tus estándares.',
    'education.tip6Title': 'Procesamiento por Lotes',
    'education.tip6Desc': 'Sube múltiples imágenes a la vez para ahorrar tiempo y asegurar configuraciones consistentes.',
    'education.formatTitle': 'Guía de Comparación de Formatos de Imagen',
    'education.jpegSpecs': 'JPEG: Ideal para fotografías y imágenes complejas. Compresión con pérdida, tamaños de archivo pequeños.',
    'education.pngSpecs': 'PNG: Perfecto para gráficos, logos y imágenes con transparencia. Compresión sin pérdida.',
    'education.webpSpecs': 'WebP: Formato web moderno con compresión superior. Soporta tanto con pérdida como sin pérdida.',
    'education.heifSpecs': 'HEIF: Formato de alta eficiencia de Apple. Mejor compresión que JPEG con mayor calidad.',
    'education.qualityTitle': 'Guía de Calidad vs Tamaño de Archivo',
    'education.qualityDesc': 'Comprende el equilibrio entre calidad de imagen y tamaño de archivo para tomar decisiones informadas.',
    'education.quality100': 'Calidad 100%: Máxima calidad, archivo más grande',
    'education.quality80': 'Calidad 80%: Excelente calidad, buen equilibrio',
    'education.quality60': 'Calidad 60%: Buena calidad, archivo más pequeño',
    'education.quality40': 'Calidad 40%: Calidad aceptable, archivo muy pequeño',
    'education.quality20': 'Calidad 20%: Calidad baja, archivo mínimo',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': 'Soluciones de Compresión de Imágenes Empresariales',
    'education.ecommerceOptTitle': 'Optimización de E-commerce',
    'education.ecommerceOptDesc': 'Los minoristas en línea que usan CompressHub Pro reportan tiempos de carga 40% más rápidos y tasas de conversión 25% más altas. Las imágenes de productos cargan instantáneamente, reduciendo el abandono del carrito y mejorando la experiencia del cliente.',
    'education.batchProcess': 'Procesar por lotes miles de imágenes de productos',
    'education.consistentQuality': 'Mantener calidad consistente en todo el catálogo',
    'education.optimizeMobile': 'Optimizar para compradores móviles',
    'education.cmsTitle': 'Sistemas de Gestión de Contenido',
    'education.cmsDesc': 'Los editores y bloggers ahorran 60% en costos de almacenamiento mientras mejoran el ranking SEO. Las imágenes comprimidas cargan más rápido, reduciendo las tasas de rebote y mejorando el rendimiento en motores de búsqueda.',
    'education.apiIntegration': 'Integración API con WordPress, Drupal',
    'education.autoCompression': 'Compresión automática al subir',
    'education.seoOptimized': 'Tamaños de archivo optimizados para SEO',
    'education.mobileDevTitle': 'Desarrollo de Aplicaciones Móviles',
    'education.mobileDevDesc': 'Los desarrolladores móviles reducen el tamaño del bundle de la app hasta un 75% mientras mantienen la calidad visual. Las aplicaciones más pequeñas se descargan más rápido y usan menos almacenamiento del dispositivo.',
    'education.optimizeIosAndroid': 'Optimizar para iOS y Android',
    'education.densitySupport': 'Soporte para múltiples densidades',
    'education.fasterApproval': 'Aprobación más rápida en app store',
    'education.roiTitle': 'Calcula Tu Retorno de Inversión',
    'education.storageSavings': 'Ahorros de Almacenamiento',
    'education.storageSavingsDesc': 'Reduce los costos de almacenamiento en un 60-80% en toda tu biblioteca de imágenes.',
    'education.savingsAmount': '$500/mes ahorrados',
    'education.savingsNote': '*Basado en almacenamiento de imágenes de 10TB',
    'education.performanceGains': 'Ganancias de Rendimiento',
    'education.performanceGainsDesc': 'Mejora la velocidad de carga de páginas y las métricas de experiencia del usuario.',
    'education.fasterLoadingPercent': '40% más rápido',
    'education.performanceNote': '*Mejora promedio en sitios web',
    'education.conversionIncrease': 'Aumento de Conversión',
    'education.conversionDesc': 'Tasas de conversión más altas por la experiencia de usuario mejorada.',
    'education.conversionPercent': '+25% conversiones',
    'education.conversionNote': '*Promedio de cliente e-commerce',
    'education.techSpecsTitle': 'Especificaciones Técnicas y Estándares',
    'education.supportedFormatsTitle': 'Formatos y Algoritmos Soportados',
    'education.jpegOptTitle': 'Optimización JPEG',
    'education.jpegOptDesc': 'Codificación JPEG progresiva, optimización de tabla Huffman, submuestreo de croma',
    'education.pngCompTitle': 'Compresión PNG',
    'education.pngCompDesc': 'Optimización del algoritmo DEFLATE, reducción de paleta, preservación del canal alfa',
    'education.webpFormatTitle': 'Formato Moderno WebP',
    'education.webpFormatDesc': 'Codificación VP8/VP9, modos con y sin pérdida, transparencia alfa avanzada',
    'education.heifTitle': 'Soporte HEIF/HEIC',
    'education.heifDesc': 'Codificación de alta eficiencia, soporte HDR, optimización de fotos en ráfaga',
    'education.enterpriseFeaturesTitle': 'Características Empresariales',
    'education.apiIntegrationTitle': 'Integración API',
    'education.apiIntegrationDesc': 'API RESTful, soporte de webhooks, endpoints de procesamiento por lotes, actualizaciones de estado en tiempo real',
    'education.securityTitle': 'Seguridad y Cumplimiento',
    'education.securityDesc': 'SOC 2 Tipo II, cumplimiento GDPR, cifrado de extremo a extremo, eliminación automática de archivos',
    'education.performanceMonitoringTitle': 'Monitoreo de Rendimiento',
    'education.performanceMonitoringDesc': 'Análisis en tiempo real, seguimiento de ratio de compresión, reportes de ahorro de ancho de banda',
    'education.scaleTitle': 'Escala y Confiabilidad',
    'education.scaleDesc': 'SLA de 99.9% de tiempo de actividad, infraestructura de auto-escalado, integración CDN global',
    'education.industryBestTitle': 'Mejores Prácticas de la Industria para Optimización de Imágenes',
    'education.webPerfTitle': 'Estándares de Rendimiento Web',
    'education.webPerfDesc': '• Core Web Vitals: Las métricas de rendimiento de Google impactan directamente en los rankings SEO. Las imágenes optimizadas mejoran los puntajes de Largest Contentful Paint (LCP) hasta un 40%.',
    'education.progressiveLoadingDesc': '• Carga Progresiva: Implementa codificación JPEG progresiva para mejor rendimiento percibido. Los usuarios ven el contenido de la imagen mientras se carga.',
    'education.responsiveImagesDesc': '• Imágenes Responsivas: Usa atributos srcset con múltiples tamaños de imagen para servir versiones apropiadas para diferentes tamaños de pantalla y resoluciones.',
    'education.lazyLoadingDesc': '• Carga Perezosa: Combina la compresión de imágenes con carga perezosa para reducir el tiempo de carga inicial de la página y el uso de ancho de banda.',
    'education.mobileOptTitle': 'Estrategia de Optimización Móvil',
    'education.adaptiveQualityDesc': '• Calidad Adaptiva: Sirve imágenes de menor calidad a usuarios con conexiones lentas mientras mantienes alta calidad para redes rápidas.',
    'education.formatSelectionDesc': '• Selección de Formato: Usa WebP para navegadores compatibles (95% de cobertura) con respaldos JPEG para navegadores antiguos.',
    'education.bandwidthAwarenessDesc': '• Conciencia de Ancho de Banda: Considera los modos de ahorro de datos e implementa toggles de calidad para usuarios móviles con planes de datos limitados.',
    'education.appBundleDesc': '• Optimización de Bundle de App: Para apps móviles, comprime imágenes empaquetadas para reducir el tamaño de descarga y mejorar las tasas de aprobación en app stores.',

    // Common
    'common.loading': 'Cargando...',
    'common.cancel': 'Cancelar',
    'common.save': 'Guardar',
    'common.close': 'Cerrar',
    'common.back': 'Atrás',
    'common.next': 'Siguiente',
    'common.submit': 'Enviar',
    'common.upload': 'Subir',
    'common.download': 'Descargar',
    'message.processing': 'Procesando...',
    'common.delete': 'Eliminar',
    'common.edit': 'Editar',
    'common.settings': 'Configuración',
    'common.profile': 'Perfil',
    'common.help': 'Ayuda',
    'common.about': 'Acerca de',
    'common.contact': 'Contacto',
    'common.privacy': 'Política de Privacidad',
    'common.terms': 'Términos de Servicio',
  },
  
  // Add more languages with key translations
  fr: {
    // Navigation
    'nav.home': 'Accueil',
    'nav.compress': 'Compresser',
    'nav.history': 'Historique',
    'nav.login': 'Connexion',
    'nav.signup': 'Inscription',
    'nav.logout': 'Déconnexion',
    'nav.pricing': 'Tarifs',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Plan Gratuit',
    'nav.proActive': 'Pro Actif',
    
    // Login Page  
    'login.title': 'Bon Retour',
    'login.subtitle': 'Connectez-vous à votre compte pour continuer',
    'login.formTitle': 'Connexion',
    'login.email': 'Email',
    'login.emailPlaceholder': 'Entrez votre email',
    'login.password': 'Mot de passe',
    'login.passwordPlaceholder': 'Entrez votre mot de passe',
    'login.signingIn': 'Connexion...',
    'login.signIn': 'Se connecter',
    'login.noAccount': "Pas de compte?",
    'login.signUp': "S'inscrire",
    'login.backToHome': '← Retour à l\'accueil',
    'login.errors.failed': 'Échec de connexion',
    'login.errors.invalid': 'Email ou mot de passe invalide',
    'login.errors.generic': 'Une erreur s\'est produite. Veuillez réessayer.',
    
    // Signup Page
    'signup.title': 'Créer un Compte',
    'signup.subtitle': 'Rejoignez CompressHub et commencez à optimiser vos images',
    'signup.formTitle': 'Inscription',
    'signup.firstName': 'Prénom',
    'signup.firstNamePlaceholder': 'Jean',
    'signup.lastName': 'Nom',
    'signup.lastNamePlaceholder': 'Dupont',
    'signup.email': 'Email',
    'signup.emailPlaceholder': 'jean@exemple.com',
    'signup.password': 'Mot de passe',
    'signup.passwordPlaceholder': 'Au moins 6 caractères',
    'signup.confirmPassword': 'Confirmer le mot de passe',
    'signup.confirmPasswordPlaceholder': 'Confirmez votre mot de passe',
    'signup.creatingAccount': 'Création du compte...',
    'signup.createAccount': 'Créer un compte',
    'signup.haveAccount': 'Déjà un compte?',
    'signup.signIn': 'Se connecter',
    'signup.backToHome': '← Retour à l\'accueil',
    'signup.success.title': 'Compte créé',
    'signup.success.message': 'Bienvenue sur CompressHub! Vous pouvez maintenant commencer à compresser des images.',
    'signup.errors.failed': 'Échec d\'inscription',
    'signup.errors.createFailed': 'Échec de création de compte',
    'signup.errors.generic': 'Une erreur s\'est produite. Veuillez réessayer.',
    'signup.errors.firstNameShort': 'Le prénom doit contenir au moins 2 caractères',
    'signup.errors.lastNameShort': 'Le nom doit contenir au moins 2 caractères',
    'signup.errors.emailInvalid': 'Veuillez entrer un email valide',
    'signup.errors.passwordShort': 'Le mot de passe doit contenir au moins 6 caractères',
    'signup.errors.passwordMismatch': 'Les mots de passe ne correspondent pas',
    
    // History Page
    'history.title': 'Historique de Compression',
    'history.subtitle': 'Visualisez et téléchargez toutes vos images compressées précédemment.',
    
    // Landing Page
    'landing.title': 'Compression d\'Images Professionnelle',
    'landing.subtitle': 'Compressez les images jusqu\'à 90% plus petites tout en conservant la qualité visuelle. Parfait pour l\'optimisation web et le stockage.',
    'landing.cta': 'Commencer Gratuitement',
    'landing.features.title': 'Pourquoi choisir CompressHub?',
    'landing.features.subtitle': 'Compression d\'images de niveau professionnel avec algorithmes avancés et fonctionnalités d\'entreprise.',
    'landing.feature1.title': 'Super Rapide',
    'landing.feature1.desc': 'Traitez des centaines d\'images en secondes avec notre moteur de compression optimisé.',
    'landing.feature2.title': 'Qualité Visuelle',
    'landing.feature2.desc': 'Les algorithmes avancés préservent la qualité d\'image tout en maximisant la compression.',
    'landing.feature3.title': 'APIs Développeur',
    'landing.feature3.desc': 'Intégrez la compression dans votre flux de travail avec notre puissante API REST.',
    'landing.feature4.title': 'Traitement Sécurisé',
    'landing.feature4.desc': 'Le chiffrement de bout en bout garantit que vos images restent privées et protégées.',
    'landing.getStarted': 'Commencer Gratuitement',
    'landing.pricing.title': 'Tarifs Simples',
    'landing.pricing.free': 'Gratuit',
    'landing.pricing.free.desc': '50 compressions par jour',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': 'Compressions illimitées',
    'landing.pricing.upgrade': 'Passer à Pro',
    
    // Home Page
    'home.welcome': 'Bienvenue sur CompressHub',
    
    // App name and footer
    'app.name': 'CompressHub',
    'landing.readyToCompress': 'Prêt à compresser vos images?',
    'landing.trustMessage': 'Rejoignez des milliers de professionnels qui font confiance à CompressHub pour leurs besoins d\'optimisation d\'images.',
    'footer.description': 'La plateforme de compression d\'images la plus avancée pour les professionnels et entreprises.',
    'footer.copyright': 'Tous droits réservés.',
    'home.subtitle': 'Votre outil professionnel de compression d\'images',
    'home.startCompressing': 'Commencer la Compression',
    
    // Compress Page
    'compress.title': 'Compresser Images',
    'compress.dragDrop': 'Glissez et déposez vos images ici, ou cliquez pour parcourir',
    'compress.dropFiles': 'Glissez et déposez vos images ici ou cliquez pour parcourir',
    'compress.supportedFormats': 'Support pour JPG, PNG, WebP, HEIC jusqu\'à 50MB chacun',
    'compress.selectFiles': 'Sélectionner Fichiers',
    'compress.trySample': 'Essayer un Fichier Exemple',
    'compress.processing': 'Traitement...',
    'compress.completed': 'Terminé',
    'compress.download': 'Télécharger',
    'compress.downloadAll': 'Télécharger Tout',
    'compress.quality': 'Qualité',
    'compress.format': 'Format',
    'compress.stats.files': 'fichier(s) traité(s)',
    'compress.stats.saved': 'Espace Économisé',
    'compress.professionalOptimization': 'Optimisation professionnelle d\'images',
    'compress.resizeImage': 'Redimensionner l\'image',
    'compress.colorFilter': 'Filtre de couleur',
    'compress.noFilter': 'Aucun filtre',
    'compress.grayscale': 'Niveaux de gris',
    'compress.sepia': 'Sépia',
    'compress.vintage': 'Vintage',
    'compress.qualityPreset': 'Préréglage de qualité',
    'compress.qualityBest': 'Meilleure',
    'compress.qualityHigh': 'Haute',
    'compress.qualityMedium': 'Moyenne',
    'compress.qualitySmall': 'Petite',
    'compress.qualityMinimum': 'Minimum',
    'compress.autoRecommended': 'Auto (Recommandé)',
    'compress.showAdvanced': 'Afficher les options avancées',
    'compress.hideAdvanced': 'Masquer les options avancées',
    'compress.secure': 'Fichiers traités de manière sécurisée',
    'education.highQualityTitle': 'Haute Qualité (90-100%)',
    'education.balancedTitle': 'Équilibré (70-85%)',
    'education.aggressiveTitle': 'Agressif (50-70%)',
    
    // Stats Card
    'stats.todayActivity': "Activité d'Aujourd'hui",
    'stats.imagesCompressed': 'Images Compressées',
    'stats.totalSizeSaved': 'Taille Totale Économisée',
    'stats.averageReduction': 'Réduction Moyenne',
    'stats.freeTierUsage': 'Utilisation niveau gratuit',
    
    // Recent History
    'recent.title': 'Compressions Récentes',
    'recent.viewAll': 'Voir tout',
    
    // Upgrade Card
    'upgrade.title': 'Passer à Pro',
    'upgrade.desc': 'Débloquez les compressions illimitées, fichiers plus volumineux, traitement par lots et support prioritaire.',
    'upgrade.feature1': 'Compressions illimitées par jour',
    'upgrade.feature2': 'Traitement des fichiers jusqu\'à 100MB chacun',
    'upgrade.feature3': 'Chargement par lots jusqu\'à 100 fichiers',
    'upgrade.feature4': 'Vitesse de traitement prioritaire',
    'upgrade.feature5': 'Accès API avancé',
    'upgrade.feature6': 'Support prioritaire 24/7',
    'upgrade.button': 'Passer à Pro - $9/mois',
    
    // Checkout
    'checkout.title': 'Passer à Pro',
    'checkout.subtitle': 'Débloquez la compression illimitée et les fonctionnalités premium pour $9/mois',
    'checkout.features': 'Fonctionnalités Premium',
    'checkout.feature.unlimited': 'Utilisation Quotidienne Illimitée',
    'checkout.feature.large': 'Fichiers jusqu\'à 100MB',
    'checkout.feature.batch': 'Traitement par Lots 100 Fichiers',
    'checkout.feature.priority': 'Vitesse de Traitement Prioritaire',
    'checkout.feature.api': 'Accès API Avancé',
    'checkout.feature.support': 'Support Prioritaire 24/7',
    'checkout.firstName': 'Prénom',
    'checkout.lastName': 'Nom',
    'checkout.email': 'E-mail',
    'checkout.password': 'Mot de passe',
    'checkout.promoCode': 'Avez-vous un code promo?',
    'checkout.hidePromo': 'Masquer le code promo',
    'checkout.payment': 'Paiement Sécurisé',
    'checkout.startPro': 'Commencer Pro - $9/mois',
    'checkout.subscribePro': 'S\'abonner Pro - $9/mois',
    'checkout.perMonth': 'par mois • Annulez à tout moment',
    'checkout.upgradeTitle': 'Passer à CompressHub Pro',
    'checkout.unlimitedFeatures': 'Débloquez la compression illimitée avec des fonctionnalités professionnelles',
    'checkout.whatsIncluded': 'Ce qui est inclus',
    'checkout.sslSecure': 'SSL Sécurisé',
    'checkout.cancelAnytime': 'Annuler à tout moment',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 de 2,000+ utilisateurs',
    'checkout.createAccountSubscribe': 'Créer un compte et s\'abonner',
    'checkout.joinThousands': 'Rejoignez des milliers de créateurs utilisant CompressHub Pro',
    'checkout.sslSecured': 'SSL Sécurisé',
    'checkout.pciCompliant': 'Conforme PCI',
    'checkout.completeUpgrade': 'Complétez votre mise à niveau',
    'checkout.addPaymentMethod': 'Ajoutez un moyen de paiement pour débloquer les fonctionnalités Pro',
    
    // Educational Content - Landing Page
    'education.guideTitle': 'Guide Complet de la Compression d\'Images',
    'education.guideSubtitle': 'Apprenez tout ce qu\'il faut savoir pour optimiser vos images pour le web, mobile et l\'impression.',
    'education.webDevTitle': 'Développement Web',
    'education.webDevDesc': 'Optimisez les images pour des sites web plus rapides et une meilleure expérience utilisateur. Les images compressées réduisent les temps de chargement et améliorent le référencement SEO.',
    'education.compressionTitle': 'Comprendre la Compression d\'Images',
    'education.compressionDesc': 'La compression d\'images réduit la taille du fichier tout en maintenant la qualité visuelle. Il existe deux types principaux : sans perte (PNG) et avec perte (JPEG). La compression sans perte préserve toutes les données originales, tandis que la compression avec perte supprime certaines données pour obtenir des fichiers plus petits.',
    'education.jpegBest': 'JPEG : Meilleur pour les photos et images complexes',
    'education.pngBest': 'PNG : Idéal pour les graphiques avec transparence',
    'education.webpBest': 'WebP : Format moderne avec compression supérieure',
    'education.performanceTitle': 'Impact sur les Performances Web',
    'education.performanceDesc': 'Les images optimisées améliorent considérablement la vitesse de chargement du site web et l\'expérience utilisateur. Les études montrent qu\'un délai de 1 seconde dans le temps de chargement peut réduire les conversions jusqu\'à 7%.',
    'education.fasterLoading': '40% plus rapide en temps de chargement',
    'education.reducedBandwidth': 'Utilisation réduite de la bande passante',
    'education.betterSeo': 'Meilleurs classements SEO',
    'education.bestPracticesTitle': 'Meilleures Pratiques de Compression',
    'education.bestPracticesDesc': 'Suivez ces meilleures pratiques standard de l\'industrie pour obtenir des résultats optimaux tout en maintenant la qualité d\'image qui répond aux normes professionnelles.',
    'education.qualityRange': 'Utilisez 80-85% de qualité pour les images web',
    'education.resizeFirst': 'Redimensionnez les images aux dimensions d\'affichage',
    'education.chooseFormat': 'Choisissez le format approprié pour le contenu',
    
    // Missing education content translations for French
    'education.storageSavingsTitle': 'Économies de Stockage',
    'education.performanceGainsTitle': 'Gains de Performance', 
    'education.conversionIncreaseTitle': 'Augmentation des Conversions',
    'education.techSupportedFormats': 'Formats Pris en Charge et Algorithmes',
    
    // Ultimate Guide SEO Section (French)
    'education.ultimateGuideTitle': 'Le Guide Ultime de la Compression d\'Images 2025',
    'education.ultimateGuideDesc': 'Maîtrisez l\'art de l\'optimisation d\'images avec notre guide complet. Apprenez des experts de l\'industrie et obtenez des résultats professionnels.',
    'education.jpegTitle': 'Compression JPEG',
    'education.jpegDesc': 'Maîtrisez les techniques d\'optimisation JPEG pour le web et l\'impression. Apprenez les paramètres de qualité, l\'encodage progressif et l\'optimisation de l\'espace colorimétrique.',
    'education.bestForPhotos': 'Idéal pour les photos',
    'education.pngTitle': 'Optimisation PNG',
    'education.pngDesc': 'Stratégies avancées de compression PNG pour la préservation de la transparence. Optimisation de palette et techniques de compression sans perte.',
    'education.bestForGraphics': 'Idéal pour les graphiques',
    'education.webpTitle': 'Conversion WebP',
    'education.webpDesc': 'Format WebP de nouvelle génération pour des ratios de compression supérieurs. Compatibilité des navigateurs et stratégies de secours incluses.',
    'education.bestForWeb': 'Idéal pour le web',
    'education.bulkTitle': 'Traitement en Lot',
    'education.bulkDesc': 'Flux de travail de compression par lots de niveau entreprise. Intégration API et pipelines d\'optimisation automatisés pour l\'échelle.',
    'education.bestForEnterprise': 'Idéal pour l\'entreprise',
    
    // Educational tips - French
    'education.tipsTitle': 'Conseils Professionnels de Compression',
    'education.tip1Title': 'Choisissez le Bon Format',
    'education.tip1Desc': 'JPEG pour les photos, PNG pour les graphiques avec transparence, WebP pour les navigateurs modernes.',
    'education.tip2Title': 'Optimisez les Paramètres de Qualité', 
    'education.tip2Desc': 'Utilisez 80-85% de qualité pour les images web pour équilibrer taille et qualité visuelle.',
    'education.tip3Title': 'Redimensionnez Avant de Compresser',
    'education.tip3Desc': 'Adaptez les images à leur taille d\'affichage avant compression pour réduire au maximum la taille.',
    'education.tip4Title': 'Considérez Votre Audience',
    'education.tip4Desc': 'Plus de compression pour les utilisateurs mobiles, modérée pour l\'affichage desktop.',
    'education.tip5Title': 'Testez et Comparez',
    'education.tip5Desc': 'Prévisualisez toujours les images compressées pour vous assurer que la qualité répond à vos standards.',
    'education.tip6Title': 'Traitement par Lots',
    'education.tip6Desc': 'Téléchargez plusieurs images à la fois pour économiser du temps et assurer des paramètres cohérents.',
    
    // Missing compress page translations
    'education.formatComparisonTitle': 'Guide de Comparaison des Formats d\'Images',
    'education.formatHeader': 'Format',
    'education.bestForHeader': 'Meilleur Pour',
    'education.compressionHeader': 'Compression',
    'education.transparencyHeader': 'Transparence',
    'education.jpegRow': 'Photographies, images complexes',
    'education.excellentLossy': 'Excellent (avec perte)',
    'education.no': 'Non',
    'education.pngRow': 'Graphiques, logos, captures d\'écran',
    'education.goodLossless': 'Bon (sans perte)',
    'education.yes': 'Oui',
    'education.webpRow': 'Applications web modernes',
    'education.superior': 'Supérieur',
    'education.heifRow': 'Photographie mobile',
    'education.excellent': 'Excellent',
    'education.limited': 'Limité',
    'education.qualityGuideTitle': 'Guide Qualité vs Taille de Fichier',
    'education.highQualityTitle': 'Haute Qualité (90-100%)',
    'education.highQualityBest': 'Meilleur pour : Impression, archivage, photographie professionnelle',
    'education.highQualityTrade': 'Compromis : Fichiers volumineux, chargement lent',
    'education.balancedTitle': 'Équilibré (70-85%)',
    'education.balancedBest': 'Meilleur pour : Images web, réseaux sociaux, blogs',
    'education.balancedTrade': 'Compromis : Bonne qualité, taille raisonnable',
    'education.aggressiveTitle': 'Agressif (50-70%)',
    'education.aggressiveBest': 'Meilleur pour : Miniatures, aperçus, mobile',
    'education.aggressiveTrade': 'Compromis : Fichiers plus petits, perte de qualité',
    'education.proTip': '💡 Conseil Pro',
    'education.proTipDesc': 'Commencez avec 80% de qualité et ajustez selon vos besoins spécifiques. La plupart des spectateurs ne remarqueront pas la différence, mais votre site web se chargera considérablement plus vite.',
    
    // Home page missing translations
    'home.batchProcessing': 'Traitement par Lots',
    'home.multipleFormats': 'Formats Multiples',
    'home.apiAccess': 'Accès API',
    'home.secureProcessing': 'Traitement Sécurisé',
    'home.qualityBalance': 'Équilibre Qualité vs Taille de Fichier',
    'home.qualityBalanceDesc': 'Trouver l\'équilibre optimal entre qualité d\'image et taille de fichier est crucial pour les performances web. Notre algorithme de compression analyse chaque image pour déterminer les meilleurs paramètres.',
    'home.webpModern': 'WebP: Sites web modernes supportant la compression avancée',
    'home.webDevelopment': 'Développement Web',
    'home.ecommerce': 'E-commerce',
    'home.contentCreation': 'Création de Contenu',
    'home.mobileApps': 'Applications Mobiles',
    'education.contentCreation': 'Création de Contenu',
    'education.contentDesc': 'Préparez les images pour les réseaux sociaux, blogs et supports marketing avec des tailles de fichier optimales pour chaque plateforme.',
    'education.mobileApps': 'Applications Mobiles',
    'education.mobileDesc': 'Minimisez la taille des applications et améliorez les performances en réduisant la taille des assets d\'image.',
    'education.highQuality': 'Haute Qualité (90-100%)',
    'education.balanced': 'Équilibré (70-85%)',
    'education.aggressive': 'Agressif (50-70%)',
    
    // Compress page missing translations
    'compress.freeCompressionAvailable': 'Compression gratuite disponible ci-dessous • Inscrivez-vous pour un accès illimité et historique',
    'compress.filesProcessedSecurely': 'Fichiers traités de manière sécurisée',
    'compress.unlockFullFeatures': 'Débloquer Toutes les Fonctionnalités',
    'compress.getUnlimitedAccess': 'Obtenez un accès illimité et des fonctionnalités premium',
    'compress.trackHistory': 'Suivre l\'historique de compression',
    'compress.viewStats': 'Voir les statistiques détaillées',
    'compress.fiftyFreeDaily': '50 compressions gratuites par jour',
    'compress.premiumPlans': 'Plans premium pour un accès illimité',
    'compress.createFreeAccount': 'Créer un Compte Gratuit',
    'compress.dropImagesHere': 'Déposez les images ici ou cliquez pour parcourir',
    'compress.supportFormats': 'Support pour JPG, PNG, WebP, HEIC jusqu\'à 50MB chacun',
    'compress.trySampleFile': 'Essayer un Fichier d\'Exemple',
    'compress.signUpFeatures': 'S\'inscrire et Obtenir Plus de Fonctionnalités',
    'compress.secure': 'Fichiers traités de manière sécurisée',
    'compress.qualityPreset': 'Préréglage de Qualité',
    'compress.qualityBest': 'Meilleur',
    'compress.qualityHigh': 'Élevé',
    'compress.qualityMedium': 'Moyen',
    'compress.qualitySmall': 'Petit',
    'compress.qualityMinimum': 'Minimal',
    'compress.format': 'Format',
    'compress.autoRecommended': 'Auto (Recommandé)',
    'compress.showAdvanced': 'Afficher les Options Avancées',
    'compress.hideAdvanced': 'Masquer les Options Avancées',
    'compress.title': 'Compresser Images',
    
    // Pricing page missing translations
    'pricing.proFeatures': 'Fonctionnalités Pro',
    'pricing.unlimitedCompressions': 'Compressions Illimitées',
    'pricing.filesUpTo100MB': 'Fichiers jusqu\'à 100MB',
    'pricing.batchProcessing100': 'Traitement par Lots (100 fichiers)',
    'pricing.priorityProcessing': 'Traitement Prioritaire',
    'pricing.apiAccess': 'Accès API',
    'pricing.prioritySupport': 'Support Prioritaire 24/7',
    'pricing.perMonth': '9€/mois',
    'pricing.cancelAnytime': 'Annuler à tout moment',
    'pricing.upgradeToCompressHub': 'Passer à CompressHub Pro',
    'pricing.unlockUnlimited': 'Débloquez la compression illimitée avec des fonctionnalités professionnelles pour 9€/mois',
    'pricing.sslSecure': 'SSL Sécurisé',
    'pricing.rating': '4,9/5 Note',
    
    // Enterprise content translations
    'pricing.enterpriseTitle': 'Solutions de Compression d\'Images Entreprise',
    'pricing.ecommerceOptimization': 'Optimisation E-commerce',
    'pricing.ecommerceOptDesc': 'Les détaillants en ligne utilisant CompressHub Pro rapportent des temps de chargement 40% plus rapides et des taux de conversion 25% plus élevés. Les images de produits se chargent instantanément, réduisant l\'abandon de panier et améliorant l\'expérience client.',
    'pricing.batchProcess1000s': 'Traiter par lots des milliers d\'images de produits',
    'pricing.maintainQuality': 'Maintenir une qualité constante dans tout le catalogue',
    'pricing.optimizeMobile': 'Optimiser pour les acheteurs mobiles',
    'pricing.cmsTitle': 'Systèmes de Gestion de Contenu',
    'pricing.cmsDesc': 'Les éditeurs et blogueurs économisent 60% sur les coûts de stockage tout en améliorant le classement SEO. Les images compressées se chargent plus rapidement, réduisant les taux de rebond et améliorant les performances des moteurs de recherche.',
    'pricing.apiIntegration': 'Intégration API avec WordPress, Drupal',
    'pricing.autoCompression': 'Compression automatique lors du téléchargement',
    'pricing.seoOptimized': 'Tailles de fichiers optimisées pour le SEO',
    'pricing.mobileAppDev': 'Développement d\'Applications Mobiles',
    'pricing.mobileDevDesc': 'Les développeurs mobiles réduisent la taille du bundle d\'application jusqu\'à 75% tout en maintenant la qualité visuelle. Les applications plus petites se téléchargent plus rapidement et utilisent moins de stockage sur l\'appareil.',
    'pricing.optimizeIosAndroid': 'Optimiser pour iOS et Android',
    'pricing.multipleDensity': 'Support de densités multiples',
    'pricing.fasterAppStore': 'Approbation plus rapide de l\'app store',

    // Upgrade Card
    'upgrade.title': 'Passer à Pro',
    'upgrade.desc': 'Compression illimitée, accès API et traitement prioritaire.',
    'upgrade.feature1': 'Compression illimitée',
    'upgrade.feature2': 'Traitement par lots jusqu\'à 100 fichiers',
    'upgrade.feature3': 'Accès API et webhooks',
    'upgrade.feature4': 'Vitesse de traitement prioritaire',
    'upgrade.feature5': 'Accès API avancé',
    'upgrade.feature6': 'Support prioritaire 24/7',
    'upgrade.button': 'Passer à Pro - 9€/mois',
    
    // Compress page features
    'compress.unlockFeatures': 'Débloquez toutes les fonctionnalités',
    'compress.getUnlimitedAccess': 'Obtenez un accès illimité à toutes les fonctionnalités',
    'compress.trackHistory': 'Suivez l\'historique de compression',
    'compress.viewStats': 'Consultez les statistiques détaillées',
    'compress.fiftyFreeDaily': '50 compressions gratuites par jour',
    'compress.premiumPlans': 'Plans premium à partir de 9€/mois',
    'compress.createFreeAccount': 'Créer un compte gratuit',
    
    // Education Section
    'education.title': 'Guide Complet de la Compression d\'Images',
    'education.subtitle': 'Apprenez tout sur la compression d\'images, des concepts de base aux techniques avancées.',
    'education.technicalTitle': 'Plongée Technique : Comment Fonctionne la Compression d\'Images',
    'education.lossyVsLossless': 'Compression avec Perte vs Sans Perte',
    'education.lossyDesc': 'La compression avec perte supprime certaines données d\'image pour réduire la taille du fichier. Cela résulte en des fichiers plus petits mais avec une légère perte de qualité.',
    'education.losslessDesc': 'La compression sans perte préserve toutes les données originales de l\'image. Les fichiers sont plus volumineux mais maintiennent une qualité parfaite.',
    'education.whenToUse': 'Quand Utiliser Chaque Type',
    'education.lossyUse': 'Avec perte : Photographies, images web, réseaux sociaux',
    'education.losslessUse': 'Sans perte : Logos, graphiques, images médicales',
    'education.webpUse': 'WebP : Sites web modernes supportant la compression avancée',
    'education.qualityBalance': 'Équilibre Qualité vs Taille de Fichier',
    'education.balanceDesc': 'Trouver l\'équilibre optimal entre qualité d\'image et taille de fichier est crucial pour les performances web. Notre algorithme de compression analyse chaque image pour déterminer les meilleurs paramètres.',
    'education.largeFiles': 'Gros fichiers',
    'education.optimalWeb': 'Optimal pour le web',
    'education.smallestFiles': 'Fichiers les plus petits',
    'education.algorithmsTitle': 'Algorithmes de Compression',
    'education.jpegAlgorithm': 'JPEG utilise la transformation cosinus discrète (DCT) pour compresser les images en divisant l\'image en blocs de 8x8 pixels.',
    'education.pngAlgorithm': 'PNG utilise la compression DEFLATE, qui combine l\'algorithme LZ77 avec l\'encodage Huffman.',
    'education.webpAlgorithm': 'WebP utilise la compression prédictive pour réduire les données nécessaires pour encoder une image.',
    'education.applicationsTitle': 'Cas d\'Usage dans l\'Industrie',
    'education.ecommerceTitle': 'E-commerce et Retail',
    'education.ecommerceDesc': 'Réduisez les temps de chargement des pages produits pour améliorer les taux de conversion et l\'expérience utilisateur.',
    'education.mediaTitle': 'Médias Numériques et Publication',
    'education.mediaDesc': 'Optimisez les images pour les sites web, magazines numériques et plateformes de médias sociaux.',
    'education.mobileTitle': 'Développement d\'Applications Mobiles',
    'education.mobileDesc': 'Minimisez la taille des applications et améliorez les performances en réduisant la taille des assets d\'image.',
    'education.marketingTitle': 'Marketing et Publicité',
    'education.marketingDesc': 'Assurez-vous que les campagnes publicitaires se chargent rapidement sur tous les appareils et connexions.',
    'education.tipsTitle': 'Conseils Professionnels de Compression',
    'education.tip1Title': 'Choisissez le Bon Format',
    'education.tip1Desc': 'JPEG pour les photographies, PNG pour les images avec transparence, WebP pour le web moderne.',
    'education.tip2Title': 'Optimisez pour le Contexte',
    'education.tip2Desc': 'Les images web peuvent utiliser une compression plus élevée que les images d\'impression.',
    'education.tip3Title': 'Utilisez des Outils de Qualité',
    'education.tip3Desc': 'Investissez dans un logiciel de compression professionnel pour de meilleurs résultats.',
    'education.tip4Title': 'Considérez les Performances',
    'education.tip4Desc': 'Équilibrez la qualité de l\'image avec les temps de chargement pour une expérience utilisateur optimale.',
    'education.formatTitle': 'Guide de Comparaison des Formats d\'Images',
    'education.jpegSpecs': 'JPEG : Idéal pour les photographies et images complexes. Compression avec perte, petites tailles de fichier.',
    'education.pngSpecs': 'PNG : Parfait pour les graphiques, logos et images avec transparence. Compression sans perte.',
    'education.webpSpecs': 'WebP : Format web moderne avec compression supérieure. Supporte à la fois avec et sans perte.',
    'education.heifSpecs': 'HEIF : Format haute efficacité d\'Apple. Meilleure compression que JPEG avec qualité supérieure.',
    'education.qualityTitle': 'Guide Qualité vs Taille de Fichier',
    'education.qualityDesc': 'Comprenez l\'équilibre entre qualité d\'image et taille de fichier pour prendre des décisions éclairées.',
    'education.quality100': 'Qualité 100% : Qualité maximale, fichier plus volumineux',
    'education.quality80': 'Qualité 80% : Excellente qualité, bon équilibre',
    'education.quality60': 'Qualité 60% : Bonne qualité, fichier plus petit',
    'education.quality40': 'Qualité 40% : Qualité acceptable, fichier très petit',
    'education.quality20': 'Qualité 20% : Qualité faible, fichier minimal',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': 'Solutions de Compression d\'Images d\'Entreprise',
    'education.ecommerceOptTitle': 'Optimisation E-commerce',
    'education.ecommerceOptDesc': 'Les détaillants en ligne utilisant CompressHub Pro rapportent des temps de chargement 40% plus rapides et des taux de conversion 25% plus élevés. Les images de produits se chargent instantanément, réduisant l\'abandon de panier et améliorant l\'expérience client.',
    'education.batchProcess': 'Traitement par lots de milliers d\'images de produits',
    'education.consistentQuality': 'Maintenir une qualité constante sur tout le catalogue',
    'education.optimizeMobile': 'Optimiser pour les acheteurs mobiles',
    'education.cmsTitle': 'Systèmes de Gestion de Contenu',
    'education.cmsDesc': 'Les éditeurs et blogueurs économisent 60% sur les coûts de stockage tout en améliorant les classements SEO. Les images compressées se chargent plus rapidement, réduisant les taux de rebond et améliorant les performances des moteurs de recherche.',
    'education.apiIntegration': 'Intégration API avec WordPress, Drupal',
    'education.autoCompression': 'Compression automatique lors du téléchargement',
    'education.seoOptimized': 'Tailles de fichiers optimisées pour le SEO',
    'education.mobileDevTitle': 'Développement d\'Applications Mobiles',
    'education.mobileDevDesc': 'Les développeurs mobiles réduisent la taille du bundle d\'application jusqu\'à 75% tout en maintenant la qualité visuelle. Les applications plus petites se téléchargent plus rapidement et utilisent moins de stockage sur l\'appareil.',
    'education.optimizeIosAndroid': 'Optimiser pour iOS et Android',
    'education.densitySupport': 'Support de densités multiples',
    'education.fasterApproval': 'Approbation plus rapide de l\'app store',
    'education.roiTitle': 'Calculez Votre Retour sur Investissement',
    'education.storageSavings': 'Économies de Stockage',
    'education.storageSavingsDesc': 'Réduisez les coûts de stockage de 60-80% sur toute votre bibliothèque d\'images.',
    'education.savingsAmount': '500$/mois économisés',
    'education.savingsNote': '*Basé sur 10TB de stockage d\'images',
    'education.performanceGains': 'Gains de Performance',
    'education.performanceGainsDesc': 'Améliorez les vitesses de chargement des pages et les métriques d\'expérience utilisateur.',
    'education.fasterLoadingPercent': '40% plus rapide',
    'education.performanceNote': '*Amélioration moyenne sur les sites web',
    'education.conversionIncrease': 'Augmentation des Conversions',
    'education.conversionDesc': 'Taux de conversion plus élevés grâce à l\'amélioration de l\'expérience utilisateur.',
    'education.conversionPercent': '+25% conversions',
    'education.conversionNote': '*Moyenne client e-commerce',
    'education.techSpecsTitle': 'Spécifications Techniques et Standards',
    'education.supportedFormatsTitle': 'Formats et Algorithmes Supportés',
    'education.jpegOptTitle': 'Optimisation JPEG',
    'education.jpegOptDesc': 'Encodage JPEG progressif, optimisation table Huffman, sous-échantillonnage chroma',
    'education.pngCompTitle': 'Compression PNG',
    'education.pngCompDesc': 'Optimisation algorithme DEFLATE, réduction palette, préservation canal alpha',
    'education.webpFormatTitle': 'Format Moderne WebP',
    'education.webpFormatDesc': 'Encodage VP8/VP9, modes avec et sans perte, transparence alpha avancée',
    'education.heifTitle': 'Support HEIF/HEIC',
    'education.heifDesc': 'Encodage haute efficacité, support HDR, optimisation photos en rafale',
    'education.enterpriseFeaturesTitle': 'Fonctionnalités Entreprise',
    'education.apiIntegrationTitle': 'Intégration API',
    'education.apiIntegrationDesc': 'API RESTful, support webhooks, endpoints traitement par lots, mises à jour statut temps réel',
    'education.securityTitle': 'Sécurité et Conformité',
    'education.securityDesc': 'SOC 2 Type II, conforme GDPR, chiffrement bout en bout, suppression automatique fichiers',
    'education.performanceMonitoringTitle': 'Surveillance des Performances',
    'education.performanceMonitoringDesc': 'Analytiques temps réel, suivi ratio compression, rapports économies bande passante',
    'education.scaleTitle': 'Échelle et Fiabilité',
    'education.scaleDesc': 'SLA 99.9% temps de fonctionnement, infrastructure auto-scaling, intégration CDN globale',
    'education.industryBestTitle': 'Meilleures Pratiques Industrie pour Optimisation Images',
    'education.webPerfTitle': 'Standards Performance Web',
    'education.webPerfDesc': '• Core Web Vitals : Les métriques de performance Google impactent directement les classements SEO. Les images optimisées améliorent les scores Largest Contentful Paint (LCP) jusqu\'à 40%.',
    'education.progressiveLoadingDesc': '• Chargement Progressif : Implémentez l\'encodage JPEG progressif pour de meilleures performances perçues. Les utilisateurs voient le contenu image pendant le chargement.',
    'education.responsiveImagesDesc': '• Images Responsives : Utilisez les attributs srcset avec plusieurs tailles d\'images pour servir des versions appropriées aux différentes tailles d\'écran et résolutions.',
    'education.lazyLoadingDesc': '• Chargement Paresseux : Combinez la compression d\'images avec le chargement paresseux pour réduire le temps de chargement initial de la page et l\'utilisation de bande passante.',
    'education.mobileOptTitle': 'Stratégie d\'Optimisation Mobile',
    'education.adaptiveQualityDesc': '• Qualité Adaptative : Servez des images de qualité inférieure aux utilisateurs sur connexions lentes tout en maintenant haute qualité pour réseaux rapides.',
    'education.formatSelectionDesc': '• Sélection Format : Utilisez WebP pour navigateurs supportés (95% couverture) avec fallbacks JPEG pour navigateurs anciens.',
    'education.bandwidthAwarenessDesc': '• Conscience Bande Passante : Considérez les modes économie données et implémentez des toggles qualité pour utilisateurs mobiles sur forfaits données limités.',
    'education.appBundleDesc': '• Optimisation Bundle App : Pour apps mobiles, compressez images empaquetées pour réduire taille téléchargement et améliorer taux approbation app stores.',

    // Checkout page missing translations (French)
    'checkout.upgradeTitle': 'Passer à Pro',
    'checkout.unlimitedFeatures': 'Fonctionnalités Illimitées',
    'checkout.sslSecure': 'SSL Sécurisé',
    'checkout.cancelAnytime': 'Annuler à tout moment',
    'checkout.rating': '4.9/5 Évaluation',
    'checkout.createAccountSubscribe': 'Créer un Compte et S\'abonner',
    'checkout.joinThousands': 'Rejoignez des milliers de créateurs utilisant CompressHub Pro',

    // Common
    'common.loading': 'Chargement...',
    'common.cancel': 'Annuler',
    'common.save': 'Enregistrer',
    'common.close': 'Fermer',
    'common.back': 'Retour',
    'common.next': 'Suivant',
    'common.submit': 'Soumettre',
    'common.upload': 'Télécharger',
    'common.download': 'Télécharger',
    'message.processing': 'Traitement en cours...',
    'pricing.upgradeNow': 'Mettre à niveau maintenant',
    'pricing.cmsDesc': 'Les éditeurs et blogueurs économisent 60% des coûts de stockage tout en améliorant les classements SEO. Les images compressées se chargent plus rapidement, réduisant les taux de rebond et améliorant les performances des moteurs de recherche.',
    'pricing.apiIntegration': 'Intégration API avec WordPress, Drupal',
  },
  
  de: {
    // Navigation
    'nav.home': 'Startseite',
    'nav.compress': 'Komprimieren',
    'nav.history': 'Verlauf',
    'nav.login': 'Anmelden',
    'nav.signup': 'Registrieren',
    'nav.logout': 'Abmelden',
    'nav.pricing': 'Preise',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Kostenloser Plan',
    'nav.proActive': 'Pro Aktiv',
    
    // History Page
    'history.title': 'Komprimierungsverlauf',
    'history.subtitle': 'Sehen und laden Sie alle Ihre zuvor komprimierten Bilder herunter.',
    
    // Landing Page
    'landing.title': 'Professionelle Bildkomprimierung',
    'landing.subtitle': 'Komprimieren Sie Bilder bis zu 90% kleiner bei gleichbleibender visueller Qualität. Perfekt für Web-Optimierung und Speicherung.',
    'landing.cta': 'Kostenlos Starten',
    'landing.features.title': 'Warum CompressHub wählen?',
    'landing.features.subtitle': 'Professionelle Bildkomprimierung mit fortschrittlichen Algorithmen und Unternehmensfunktionen.',
    'landing.feature1.title': 'Blitzschnell',
    'landing.feature1.desc': 'Verarbeiten Sie Hunderte von Bildern in Sekunden mit unserer optimierten Komprimierungs-Engine.',
    'landing.feature2.title': 'Visuelle Qualität',
    'landing.feature2.desc': 'Fortschrittliche Algorithmen bewahren die Bildqualität bei maximaler Komprimierung.',
    'landing.feature3.title': 'Entwickler-APIs',
    'landing.feature3.desc': 'Integrieren Sie Komprimierung in Ihren Workflow mit unserer leistungsstarken REST-API.',
    'landing.feature4.title': 'Sichere Verarbeitung',
    'landing.feature4.desc': 'End-to-End-Verschlüsselung gewährleistet, dass Ihre Bilder privat und geschützt bleiben.',
    'landing.getStarted': 'Kostenlos Starten',
    'landing.pricing.title': 'Einfache Preise',
    'landing.pricing.free': 'Kostenlos',
    'landing.pricing.free.desc': '50 Komprimierungen pro Tag',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': 'Unbegrenzte Komprimierungen',
    'landing.pricing.upgrade': 'Auf Pro Upgraden',
    
    // Home Page
    'home.welcome': 'Willkommen bei CompressHub',
    
    // App name and footer
    'app.name': 'CompressHub',
    'landing.readyToCompress': 'Bereit, Ihre Bilder zu komprimieren?',
    'landing.trustMessage': 'Schließen Sie sich Tausenden von Fachleuten an, die CompressHub für ihre Bildoptimierungsanforderungen vertrauen.',
    'footer.description': 'Die fortschrittlichste Bildkomprimierungsplattform für Profis und Unternehmen.',
    'footer.copyright': 'Alle Rechte vorbehalten.',
    'home.subtitle': 'Ihr professionelles Bildkomprimierungs-Tool',
    'home.startCompressing': 'Komprimierung Starten',
    
    // Compress Page
    'compress.title': 'Bilder Komprimieren',
    'compress.dragDrop': 'Ziehen Sie hier Ihre Bilder hinein oder klicken Sie zum Durchsuchen',
    'compress.dropFiles': 'Bilder hier ablegen oder zum Durchsuchen klicken',
    'compress.supportedFormats': 'Unterstützung für JPG, PNG, WebP, HEIC bis zu 50MB je Datei',
    'compress.selectFiles': 'Dateien Auswählen',
    'compress.trySample': 'Beispieldatei Testen',
    'compress.processing': 'Verarbeitung...',
    'compress.completed': 'Abgeschlossen',
    'compress.download': 'Herunterladen',
    'compress.downloadAll': 'Alle Herunterladen',
    'compress.quality': 'Qualität',
    'compress.format': 'Format',
    'compress.stats.files': 'Datei(en) verarbeitet',
    'compress.stats.saved': 'Platz Gespart',
    'compress.professionalOptimization': 'Professionelle Bildoptimierung',
    'compress.resizeImage': 'Bild verkleinern',
    'compress.colorFilter': 'Farbfilter',
    'compress.noFilter': 'Kein Filter',
    'compress.grayscale': 'Graustufen',
    'compress.sepia': 'Sepia',
    'compress.vintage': 'Vintage',
    'compress.qualityPreset': 'Qualitätsvoreinstellung',
    'compress.qualityBest': 'Beste',
    'compress.qualityHigh': 'Hoch',
    'compress.qualityMedium': 'Mittel',
    'compress.qualitySmall': 'Klein',
    'compress.qualityMinimum': 'Minimum',
    'compress.autoRecommended': 'Auto (Empfohlen)',
    'compress.showAdvanced': 'Erweiterte Optionen anzeigen',
    'compress.hideAdvanced': 'Erweiterte Optionen ausblenden',
    'compress.secure': 'Dateien sicher verarbeitet',
    
    // Stats Card
    'stats.todayActivity': 'Heutige Aktivität',
    'stats.imagesCompressed': 'Bilder Komprimiert',
    'stats.totalSizeSaved': 'Gesamtgröße Gespart',
    'stats.averageReduction': 'Durchschnittliche Reduzierung',
    'stats.freeTierUsage': 'Nutzung der kostenlosen Stufe',
    
    // Recent History
    'recent.title': 'Letzte Komprimierungen',
    'recent.viewAll': 'Alle anzeigen',
    
    // Upgrade Card
    'upgrade.title': 'Auf Pro Upgraden',
    'upgrade.desc': 'Schalten Sie unbegrenzte Komprimierungen, größere Dateien, Batch-Verarbeitung und prioritären Support frei.',
    'upgrade.feature1': 'Unbegrenzte Komprimierungen pro Tag',
    'upgrade.feature2': 'Dateien bis zu 100MB verarbeiten',
    'upgrade.feature3': 'Batch-Upload bis zu 100 Dateien',
    'upgrade.feature4': 'Prioritäre Verarbeitungsgeschwindigkeit',
    'upgrade.feature5': 'Erweiterter API-Zugang',
    'upgrade.feature6': '24/7 prioritärer Support',
    'upgrade.button': 'Auf Pro Upgraden - $9/Monat',
    
    // Checkout
    'checkout.title': 'Auf Pro Upgraden',
    'checkout.subtitle': 'Schalten Sie unbegrenzte Komprimierung und Premium-Funktionen für $9/Monat frei',
    'checkout.features': 'Premium-Funktionen',
    'checkout.feature.unlimited': 'Unbegrenzte Tägliche Nutzung',
    'checkout.feature.large': 'Dateien bis zu 100MB',
    'checkout.feature.batch': 'Batch-Verarbeitung 100 Dateien',
    'checkout.feature.priority': 'Prioritäre Verarbeitungsgeschwindigkeit',
    'checkout.feature.api': 'Erweiterter API-Zugang',
    'checkout.feature.support': '24/7 Prioritärer Support',
    'checkout.firstName': 'Vorname',
    'checkout.lastName': 'Nachname',
    'checkout.email': 'E-Mail',
    'checkout.password': 'Passwort',
    'checkout.promoCode': 'Haben Sie einen Promo-Code?',
    'checkout.hidePromo': 'Promo-Code ausblenden',
    'checkout.payment': 'Zahlungsinformationen',
    'checkout.startPro': 'Pro Starten - $9/Monat',
    'checkout.subscribePro': 'Pro Abonnieren - $9/Monat',
    'checkout.perMonth': 'pro Monat • Jederzeit kündbar',
    'checkout.upgradeTitle': 'Auf Pro upgraden',
    'checkout.unlimitedFeatures': 'Unbegrenzte Funktionen',
    'checkout.sslSecure': 'SSL Sicher',
    'checkout.cancelAnytime': 'Jederzeit kündbar',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 von 2.000+ Nutzern',
    'checkout.createAccountSubscribe': 'Konto erstellen und abonnieren',
    'checkout.joinThousands': 'Schließen Sie sich Tausenden von Erstellern an, die CompressHub Pro verwenden',
    'checkout.sslSecured': 'SSL Gesichert',
    'checkout.pciCompliant': 'PCI-Konform',
    
    // Login Page (German)
    'login.title': 'Willkommen zurück',
    'login.subtitle': 'Melden Sie sich in Ihr Konto an, um fortzufahren',
    'login.formTitle': 'Anmelden',
    'login.email': 'E-Mail-Adresse',
    'login.emailPlaceholder': 'Geben Sie Ihre E-Mail-Adresse ein',
    'login.password': 'Passwort',
    'login.passwordPlaceholder': 'Geben Sie Ihr Passwort ein',
    'login.signingIn': 'Anmelden...',
    'login.signIn': 'Anmelden',
    'login.noAccount': 'Haben Sie noch kein Konto?',
    'login.signUp': 'Registrieren',
    'login.backToHome': '← Zurück zur Startseite',
    'login.errors.failed': 'Anmeldung fehlgeschlagen',
    'login.errors.invalid': 'Ungültige E-Mail oder Passwort',
    'login.errors.generic': 'Ein Fehler ist aufgetreten. Bitte versuchen Sie es erneut.',
    
    // Signup Page (German)
    'signup.title': 'Konto erstellen',
    'signup.subtitle': 'Treten Sie CompressHub bei und beginnen Sie mit der Optimierung Ihrer Bilder',
    'signup.formTitle': 'Registrieren',
    'signup.firstName': 'Vorname',
    'signup.firstNamePlaceholder': 'Max',
    'signup.lastName': 'Nachname',
    'signup.lastNamePlaceholder': 'Mustermann',
    'signup.email': 'E-Mail-Adresse',
    'signup.emailPlaceholder': 'max@beispiel.de',
    'signup.password': 'Passwort',
    'signup.passwordPlaceholder': 'Mindestens 6 Zeichen',
    'signup.confirmPassword': 'Passwort bestätigen',
    'signup.confirmPasswordPlaceholder': 'Bestätigen Sie Ihr Passwort',
    'signup.creatingAccount': 'Konto wird erstellt...',
    'signup.createAccount': 'Konto erstellen',
    'signup.hasAccount': 'Haben Sie bereits ein Konto?',
    'signup.signIn': 'Anmelden',
    'signup.backToHome': '← Zurück zur Startseite',
    'signup.success.title': 'Konto erstellt',
    'signup.success.message': 'Ihr Konto wurde erfolgreich erstellt!',
    
    // Education Section (German)
    'education.title': 'Komplette Anleitung zur Bildkomprimierung',
    'education.subtitle': 'Lernen Sie alles über Bildkomprimierung, von Grundlagen bis zu fortgeschrittenen Techniken.',
    'education.technicalTitle': 'Technische Vertiefung: Wie Bildkomprimierung funktioniert',
    'education.lossyVsLossless': 'Verlustbehaftete vs. Verlustfreie Komprimierung',
    'education.lossyDesc': 'Verlustbehaftete Komprimierung entfernt einige Bilddaten, um die Dateigröße zu reduzieren.',
    'education.losslessDesc': 'Verlustfreie Komprimierung behält alle ursprünglichen Bilddaten bei.',
    'education.whenToUse': 'Wann welchen Typ verwenden',
    'education.lossyUse': 'Verlustbehaftet: Fotografien, Web-Bilder, soziale Medien',
    'education.losslessUse': 'Verlustfrei: Logos, Grafiken, medizinische Bilder',
    'education.webpUse': 'WebP: Moderne Websites mit fortschrittlicher Komprimierung',
    'education.algorithmsTitle': 'Komprimierungsalgorithmen',
    'education.jpegAlgorithm': 'JPEG verwendet diskrete Cosinus-Transformation (DCT) zur Bildkomprimierung.',
    'education.pngAlgorithm': 'PNG verwendet DEFLATE-Komprimierung mit LZ77-Algorithmus.',
    'education.webpAlgorithm': 'WebP nutzt prädiktive Komprimierung für bessere Effizienz.',
    'education.applicationsTitle': 'Anwendungsfälle in der Industrie',
    'education.ecommerceTitle': 'E-Commerce und Einzelhandel',
    'education.mediaTitle': 'Digitale Medien und Verlagswesen',
    'education.mediaDesc': 'Optimieren Sie Bilder für Websites und digitale Magazine.',
    'education.mobileTitle': 'Mobile App-Entwicklung',
    'education.marketingTitle': 'Marketing und Werbung',
    'education.marketingDesc': 'Gewährleisten Sie schnelle Ladezeiten für Werbekampagnen.',
    'education.tipsTitle': 'Professionelle Komprimierungstipps',
    'education.tip1Title': 'Richtiges Format wählen',
    'education.tip1Desc': 'JPEG für Fotos, PNG für Transparenz, WebP für moderne Websites.',
    'education.tip2Title': 'Für Kontext optimieren',
    'education.tip2Desc': 'Web-Bilder können stärker komprimiert werden als Druckbilder.',
    'education.tip3Title': 'Qualitäts-Tools verwenden',
    'education.tip3Desc': 'Investieren Sie in professionelle Komprimierungssoftware.',
    'education.tip4Title': 'Performance berücksichtigen',
    'education.tip4Desc': 'Balancieren Sie Bildqualität mit Ladezeiten.',
    'education.tip5Title': 'Testen und Vergleichen',
    'education.tip5Desc': 'Vorschau der komprimierten Bilder immer prüfen, um sicherzustellen, dass die Qualität Ihren Standards entspricht.',
    'education.tip6Title': 'Stapelverarbeitung',
    'education.tip6Desc': 'Laden Sie mehrere Bilder gleichzeitig hoch, um Zeit zu sparen und konsistente Einstellungen zu gewährleisten.',
    'education.formatTitle': 'Bildformat-Vergleichsleitfaden',
    'education.formatComparisonTitle': 'Bildformat-Vergleichsleitfaden',
    'education.formatTableFormat': 'Format',
    'education.formatTableBestFor': 'Am besten für',
    'education.formatTableCompression': 'Komprimierung',
    'education.formatTableTransparency': 'Transparenz',
    'education.jpegBestFor': 'Fotografien, komplexe Bilder',
    'education.jpegCompression': 'Ausgezeichnet (verlustbehaftet)',
    'education.jpegTransparency': 'Nein',
    'education.pngBestFor': 'Grafiken, Logos, Screenshots',
    'education.pngCompression': 'Gut (verlustfrei)',
    'education.pngTransparency': 'Ja',
    'education.webpBestFor': 'Moderne Webanwendungen',
    'education.webpCompression': 'Überlegen',
    'education.webpTransparency': 'Ja',
    'education.heifBestFor': 'Mobile Fotografie',
    'education.heifCompression': 'Ausgezeichnet',
    'education.heifTransparency': 'Ja',
    'education.formatHeader': 'Format',
    'education.bestForHeader': 'Am besten für',
    'education.compressionHeader': 'Komprimierung',
    'education.transparencyHeader': 'Transparenz',
    'education.jpegRow': 'Fotografien, komplexe Bilder',
    'education.excellentLossy': 'Ausgezeichnet (verlustbehaftet)',
    'education.no': 'Nein',
    'education.pngRow': 'Grafiken, Logos, Screenshots',
    'education.goodLossless': 'Gut (verlustfrei)',
    'education.yes': 'Ja',
    'education.webpRow': 'Moderne Webanwendungen',
    'education.superior': 'Überlegen',
    'education.heifRow': 'Mobile Fotografie',
    'education.excellent': 'Ausgezeichnet',
    'education.limited': 'Begrenzt',
    'education.qualityGuideTitle': 'Qualität vs. Dateigröße Leitfaden',
    'education.highQualityTitle': 'Hohe Qualität (90-100%)',
    'education.highQualityBest': 'Am besten für: Druck, Archivierung, professionelle Fotografie',
    'education.highQualityTrade': 'Kompromiss: Große Dateien, langsameres Laden',
    'education.balancedTitle': 'Ausgewogen (70-85%)',
    'education.balancedBest': 'Am besten für: Web-Bilder, soziale Medien, Blogs',
    'education.balancedTrade': 'Kompromiss: Gute Qualität, angemessene Dateigröße',
    'education.aggressiveTitle': 'Aggressiv (50-70%)',
    'education.aggressiveBest': 'Am besten für: Miniaturbilder, Vorschauen, mobil',
    'education.aggressiveTrade': 'Kompromiss: Kleinere Dateien, etwas Qualitätsverlust',
    'education.highQuality': 'Hohe Qualität (90-100%)',
    'education.balanced': 'Ausgewogen (70-85%)',
    'education.aggressive': 'Aggressiv (50-70%)',
    'education.contentCreation': 'Content-Erstellung',
    'education.contentDesc': 'Bereiten Sie Bilder für soziale Medien, Blogs und Marketingmaterialien mit optimalen Dateigrößen für jede Plattform vor.',
    'education.webDevTitle': 'Webentwicklung',
    'education.webDevDesc': 'Optimieren Sie Bilder für schnellere Websites und bessere Benutzererfahrung. Komprimierte Bilder reduzieren Ladezeiten und verbessern SEO-Rankings.',
    'education.ecommerce': 'E-Commerce',
    'education.ecommerceDesc': 'Reduzieren Sie Ladezeiten von Produktseiten zur Verbesserung der Conversion-Raten und Benutzererfahrung.',
    'education.mobileApps': 'Mobile Apps',
    'education.mobileDesc': 'Minimieren Sie die App-Größe und verbessern Sie die Performance durch Reduzierung der Bildgröße.',
    'education.pngRow': 'Grafiken, Logos, Screenshots',
    'education.goodLossless': 'Gut (verlustfrei)',
    'education.yes': 'Ja',
    'education.webpRow': 'Moderne Webanwendungen',
    'education.superior': 'Überlegen',
    'education.heifRow': 'Mobile Fotografie',
    'education.excellent': 'Ausgezeichnet',
    'education.proTip': '💡 Profi-Tipp',
    'education.proTipDesc': 'Beginnen Sie mit 80% Qualität und passen Sie je nach Ihren spezifischen Anforderungen an. Die meisten Betrachter werden den Unterschied nicht bemerken, aber Ihre Website wird deutlich schneller laden.',
    'education.jpegSpecs': 'JPEG: Ideal für Fotografien. Verlustbehaftete Komprimierung.',
    'education.pngSpecs': 'PNG: Perfekt für Grafiken mit Transparenz. Verlustfrei.',
    'education.webpSpecs': 'WebP: Modernes Web-Format mit überlegener Komprimierung.',
    'education.heifSpecs': 'HEIF: Apples hocheffizientes Format mit besserer Komprimierung.',
    'education.qualityTitle': 'Qualität vs. Dateigröße-Leitfaden',
    'education.qualityDesc': 'Verstehen Sie das Gleichgewicht zwischen Qualität und Größe.',
    'education.quality100': 'Qualität 100%: Maximale Qualität, größte Datei',
    'education.quality80': 'Qualität 80%: Ausgezeichnete Qualität, guter Kompromiss',
    'education.quality60': 'Qualität 60%: Gute Qualität, kleinere Datei',
    'education.quality40': 'Qualität 40%: Akzeptable Qualität, sehr kleine Datei',
    'education.quality20': 'Qualität 20%: Niedrige Qualität, minimale Datei',
    'education.highQuality': 'Hohe Qualität (90-100%)',
    'education.balanced': 'Ausgewogen (70-85%)',
    'education.aggressive': 'Aggressiv (50-70%)',
    'education.highQualityTitle': 'Hohe Qualität (90-100%)',
    'education.highQualityBest': 'Am besten für: Druck, Archivierung, professionelle Fotografie',
    'education.highQualityTrade': 'Kompromiss: Große Dateien, langsameres Laden',
    'education.balancedTitle': 'Ausgewogen (70-85%)',
    'education.balancedBest': 'Am besten für: Web-Bilder, soziale Medien, Blogs',
    'education.balancedTrade': 'Kompromiss: Gute Qualität, angemessene Dateigröße',
    'education.aggressiveTitle': 'Aggressiv (50-70%)',
    'education.aggressiveBest': 'Am besten für: Miniaturbilder, Vorschauen, Mobile',
    'education.aggressiveTrade': 'Kompromiss: Kleinere Dateien, etwas Qualitätsverlust',
    
    // Upgrade Card (German)
    'upgrade.title': 'Auf Pro upgraden',
    'upgrade.desc': 'Unbegrenzte Komprimierung, API-Zugang und vorrangige Verarbeitung.',
    'upgrade.feature1': 'Unbegrenzte Komprimierung',
    'upgrade.feature2': 'Batch-Verarbeitung bis zu 100 Dateien',
    'upgrade.feature3': 'API-Zugang und Webhooks',
    'upgrade.feature4': 'Vorrangige Verarbeitungsgeschwindigkeit',
    'upgrade.feature5': 'Erweiterte API-Zugang',
    'upgrade.feature6': '24/7 vorrangiger Support',
    'upgrade.button': 'Auf Pro upgraden - 9€/Monat',
    
    // Compress page features (German)
    'compress.unlockFeatures': 'Alle Funktionen freischalten',
    'compress.getUnlimitedAccess': 'Erhalten Sie unbegrenzten Zugang zu allen Funktionen',
    'compress.trackHistory': 'Komprimierungshistorie verfolgen',
    'compress.viewStats': 'Detaillierte Statistiken anzeigen',
    'compress.fiftyFreeDaily': '50 kostenlose Komprimierungen täglich',
    'compress.premiumPlans': 'Premium-Pläne ab 9€/Monat',
    'compress.createFreeAccount': 'Kostenloses Konto erstellen',
    
    // Home page missing translations (German)
    'home.batchProcessing': 'Stapelverarbeitung',
    'home.multipleFormats': 'Mehrere Formate',
    'home.apiAccess': 'API-Zugang',
    'home.secureProcessing': 'Sichere Verarbeitung',
    'home.qualityBalance': 'Qualität vs. Dateigröße-Balance',
    'home.qualityBalanceDesc': 'Das optimale Gleichgewicht zwischen Bildqualität und Dateigröße zu finden ist entscheidend für die Web-Performance. Unser Komprimierungsalgorithmus analysiert jedes Bild, um die besten Einstellungen zu bestimmen.',
    'home.webpModern': 'WebP: Moderne Websites mit fortschrittlicher Komprimierung',
    'home.webDevelopment': 'Web-Entwicklung',
    'home.ecommerce': 'E-Commerce',
    'home.contentCreation': 'Content-Erstellung',
    'home.mobileApps': 'Mobile Apps',
    
    // Educational content keys (German)
    'education.guideTitle': 'Vollständiger Leitfaden zur Bildkomprimierung',
    'education.guideSubtitle': 'Lernen Sie alles, was Sie über die Optimierung Ihrer Bilder für Web, Mobile und Druck wissen müssen.',
    'education.contentCreation': 'Inhaltserstellung',
    'education.contentDesc': 'Bereiten Sie Bilder für soziale Medien, Blogs und Marketingmaterialien mit optimalen Dateigrößen für jede Plattform vor.',
    'education.webDev': 'Web-Entwicklung',
    'education.webDevDesc': 'Reduzieren Sie Ladezeiten und verbessern Sie Core Web Vitals für bessere SEO-Rankings.',
    'education.compressionTitle': 'Warum Bildkomprimierung wichtig ist',
    'education.compressionDesc': 'Bildkomprimierung ist entscheidend für moderne Webanwendungen und reduziert Bandbreitennutzung und Ladezeiten.',
    'education.performanceTitle': 'Performance-Vorteile',
    'education.performanceDesc': 'Richtig komprimierte Bilder verbessern Seitenladegeschwindigkeit und Benutzererfahrung.',
    'education.fasterLoading': 'Schnellere Ladezeiten',
    'education.reducedBandwidth': 'Reduzierte Bandbreitennutzung',
    'education.betterSeo': 'Bessere SEO-Rankings',
    'education.bestPracticesTitle': 'Best Practices für Komprimierung',
    'education.bestPracticesDesc': 'Folgen Sie diesen bewährten Praktiken für optimale Ergebnisse bei gleichzeitiger Beibehaltung der Bildqualität.',
    'education.qualityRange': 'Verwenden Sie 80-85% Qualität für Web-Bilder',
    'education.resizeFirst': 'Ändern Sie Bildgrößen auf Anzeigemaße',
    'education.chooseFormat': 'Wählen Sie das richtige Format für den Inhalt',
    'education.jpegBest': 'JPEG: Am besten für Fotos',
    'education.pngBest': 'PNG: Am besten für Grafiken',
    'education.webpBest': 'WebP: Am besten für moderne Browser',
    
    // Ultimate Guide SEO Section (German)
    'education.ultimateGuideTitle': 'Der Ultimative Bildkomprimierungs-Leitfaden 2025',
    'education.ultimateGuideDesc': 'Meistern Sie die Kunst der Bildoptimierung mit unserem umfassenden Leitfaden. Lernen Sie von Branchenexperten und erzielen Sie professionelle Ergebnisse.',
    'education.jpegTitle': 'JPEG-Komprimierung',
    'education.jpegDesc': 'Meistern Sie JPEG-Optimierungstechniken für Web und Druck. Lernen Sie Qualitätseinstellungen, progressive Kodierung und Farbraum-Optimierung.',
    'education.bestForPhotos': 'Am besten für Fotos',
    'education.pngTitle': 'PNG-Optimierung',
    'education.pngDesc': 'Erweiterte PNG-Komprimierungsstrategien für Transparenz-Erhaltung. Palette-Optimierung und verlustfreie Komprimierungstechniken.',
    'education.bestForGraphics': 'Am besten für Grafiken',
    'education.webpTitle': 'WebP-Konvertierung',
    'education.webpDesc': 'WebP-Format der nächsten Generation für überlegene Komprimierungsverhältnisse. Browser-Kompatibilität und Fallback-Strategien inklusive.',
    'education.bestForWeb': 'Am besten für Web',
    'education.bulkTitle': 'Stapelverarbeitung',
    'education.bulkDesc': 'Batch-Komprimierungs-Workflows auf Unternehmensebene. API-Integration und automatisierte Optimierungs-Pipelines für Skalierung.',
    'education.bestForEnterprise': 'Am besten für Unternehmen',
    
    // Compress page missing translations (German)
    'compress.freeCompressionAvailable': 'Kostenlose Komprimierung verfügbar unten • Registrieren für unbegrenzten Zugang & Verlauf',
    'compress.filesProcessedSecurely': 'Dateien sicher verarbeitet',
    'compress.unlockFullFeatures': 'Alle Funktionen freischalten',
    'compress.getUnlimitedAccess': 'Unbegrenzten Zugang und Premium-Funktionen erhalten',
    'compress.trackHistory': 'Komprimierungsverlauf verfolgen',
    'compress.viewStats': 'Detaillierte Statistiken anzeigen',
    'compress.fiftyFreeDaily': '50 kostenlose Komprimierungen täglich',
    'compress.premiumPlans': 'Premium-Pläne für unbegrenzten Zugang',
    'compress.secure': 'Dateien sicher verarbeitet',
    'compress.qualityPreset': 'Qualitätsvorgabe',
    'compress.qualityBest': 'Beste',
    'compress.qualityHigh': 'Hoch',
    'compress.qualityMedium': 'Mittel',
    'compress.qualitySmall': 'Klein',
    'compress.qualityMinimum': 'Minimal',
    'compress.format': 'Format',
    'compress.autoRecommended': 'Auto (Empfohlen)',
    'compress.showAdvanced': 'Erweiterte Optionen anzeigen',
    'compress.hideAdvanced': 'Erweiterte Optionen ausblenden',
    'compress.signUpFeatures': 'Registrieren & Mehr Funktionen Erhalten',
    'compress.createFreeAccount': 'Kostenloses Konto erstellen',
    'compress.dropImagesHere': 'Bilder hier ablegen oder klicken zum Durchsuchen',
    'compress.supportFormats': 'Unterstützung für JPG, PNG, WebP, HEIC bis zu 50MB jeweils',
    'compress.trySampleFile': 'Beispieldatei ausprobieren',
    
    // Pricing page missing translations (German)
    'pricing.proFeatures': 'Pro-Funktionen',
    'pricing.unlimitedCompressions': 'Unbegrenzte Komprimierungen',
    'pricing.filesUpTo100MB': 'Dateien bis zu 100MB',
    'pricing.batchProcessing100': 'Stapelverarbeitung (100 Dateien)',
    'pricing.priorityProcessing': 'Prioritätsverarbeitung',
    'pricing.apiAccess': 'API-Zugang',
    'pricing.prioritySupport': '24/7 Priority Support',
    'pricing.perMonth': '$9/Monat',
    'pricing.cancelAnytime': 'Jederzeit kündbar',
    'pricing.upgradeToCompressHub': 'Auf CompressHub Pro upgraden',
    'pricing.unlockUnlimited': 'Unbegrenzte Komprimierung mit professionellen Funktionen für $9/Monat freischalten',
    'pricing.sslSecure': 'SSL Sicher',
    'pricing.rating': '4,9/5 Bewertung',
    
    // Missing checkout translations for German
    'checkout.upgradeTitle': 'Auf CompressHub Pro upgraden',
    'checkout.unlimitedFeatures': 'Unbegrenzte Komprimierung mit professionellen Funktionen freischalten',
    'checkout.whatsIncluded': 'Was ist enthalten',
    'checkout.sslSecure': 'SSL Sicher',
    'checkout.cancelAnytime': 'Jederzeit kündbar',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4,9/5 von 2.000+ Nutzern',
    'checkout.createAccountSubscribe': 'Konto erstellen & abonnieren',
    'checkout.joinThousands': 'Schließen Sie sich Tausenden von Erstellern an, die CompressHub Pro verwenden',
    'checkout.sslSecured': 'SSL Gesichert',
    'checkout.pciCompliant': 'PCI-konform',
    'checkout.payment': 'Sichere Zahlung',
    'checkout.completeUpgrade': 'Upgrade abschließen',
    'checkout.addPaymentMethod': 'Zahlungsmethode hinzufügen, um Pro-Funktionen freizuschalten',
    
    // Missing education content translations for German
    'education.storageSavingsTitle': 'Speicher-Einsparungen',
    'education.performanceGainsTitle': 'Leistungsverbesserungen', 
    'education.conversionIncreaseTitle': 'Conversion-Steigerung',
    'education.techSupportedFormats': 'Unterstützte Formate und Algorithmen',
    
    // Enterprise content translations (German)
    'pricing.enterpriseTitle': 'Unternehmenslösungen für Bildkomprimierung',
    'pricing.ecommerceOptimization': 'E-Commerce-Optimierung',
    'pricing.ecommerceOptDesc': 'Online-Händler, die CompressHub Pro verwenden, berichten von 40% schnelleren Seitenladezeiten und 25% höheren Conversion-Raten. Produktbilder laden sofort, reduzieren Warenkorbabbrüche und verbessern die Kundenerfahrung.',
    'pricing.batchProcess1000s': 'Tausende von Produktbildern stapelweise verarbeiten',
    'pricing.maintainQuality': 'Konsistente Qualität im gesamten Katalog aufrechterhalten',
    'pricing.optimizeMobile': 'Für mobile Käufer optimieren',
    'pricing.cmsTitle': 'Content-Management-Systeme',
    'pricing.cmsDesc': 'Verleger und Blogger sparen 60% bei Speicherkosten und verbessern gleichzeitig SEO-Rankings. Komprimierte Bilder laden schneller, reduzieren Absprungraten und verbessern Suchmaschinen-Performance.',
    'pricing.apiIntegration': 'API-Integration mit WordPress, Drupal',
    'pricing.autoCompression': 'Automatische Komprimierung beim Upload',
    'pricing.seoOptimized': 'SEO-optimierte Dateigrößen',
    'pricing.mobileAppDev': 'Mobile App-Entwicklung',
    'pricing.mobileDevDesc': 'Mobile Entwickler reduzieren App-Bundle-Größen um bis zu 75% bei gleichbleibender visueller Qualität. Kleinere Apps laden schneller und verbrauchen weniger Gerätespeicher.',
    'pricing.optimizeIosAndroid': 'Für iOS und Android optimieren',
    'pricing.multipleDensity': 'Unterstützung mehrerer Dichten',
    'pricing.fasterAppStore': 'Schnellere App Store-Genehmigung',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': 'Enterprise Bildkomprimierungs-Lösungen',
    'education.ecommerceOptTitle': 'E-Commerce Optimierung',
    'education.ecommerceOptDesc': 'Online-Händler, die CompressHub Pro verwenden, berichten über 40% schnellere Ladezeiten und 25% höhere Conversion-Raten. Produktbilder laden sofort, reduzieren Warenkorbabbrüche und verbessern die Kundenerfahrung.',
    'education.batchProcess': 'Tausende von Produktbildern stapelweise verarbeiten',
    'education.consistentQuality': 'Konsistente Qualität im gesamten Katalog aufrechterhalten',
    'education.optimizeMobile': 'Für mobile Käufer optimieren',
    'education.cmsTitle': 'Content-Management-Systeme',
    'education.cmsDesc': 'Verleger und Blogger sparen 60% bei Speicherkosten und verbessern gleichzeitig SEO-Rankings. Komprimierte Bilder laden schneller, reduzieren Absprungraten und verbessern Suchmaschinen-Performance.',
    'education.apiIntegration': 'API-Integration mit WordPress, Drupal',
    'education.autoCompression': 'Automatische Komprimierung beim Upload',
    'education.seoOptimized': 'SEO-optimierte Dateigrößen',
    'education.mobileDevTitle': 'Mobile App-Entwicklung',
    'education.mobileDevDesc': 'Mobile Entwickler reduzieren App-Bundle-Größen um bis zu 75% bei gleichbleibender visueller Qualität. Kleinere Apps laden schneller und verbrauchen weniger Gerätespeicher.',
    'education.optimizeIosAndroid': 'Für iOS und Android optimieren',
    'education.densitySupport': 'Unterstützung mehrerer Dichten',
    'education.fasterApproval': 'Schnellere App Store-Genehmigung',
    'education.roiTitle': 'Berechnen Sie Ihren Return on Investment',
    'education.storageSavings': 'Speicher-Einsparungen',
    'education.storageSavingsDesc': 'Reduzieren Sie Speicherkosten um 60-80% in Ihrer gesamten Bildbibliothek.',
    'education.savingsAmount': '$500/Monat gespart',
    'education.savingsNote': '*Basierend auf 10TB Bildspeicher',
    'education.performanceGains': 'Performance-Verbesserungen',
    'education.performanceGainsDesc': 'Verbessern Sie Seitenladegeschwindigkeiten und Benutzererfahrungs-Metriken.',
    'education.fasterLoadingPercent': '40% schneller',
    'education.performanceNote': '*Durchschnittliche Verbesserung auf Websites',
    'education.conversionIncrease': 'Conversion-Steigerung',
    'education.conversionDesc': 'Höhere Conversion-Raten durch verbesserte Benutzererfahrung.',
    'education.conversionPercent': '+25% Conversions',
    'education.conversionNote': '*E-Commerce Kundendurchschnitt',
    'education.techSpecsTitle': 'Technische Spezifikationen & Standards',
    'education.supportedFormatsTitle': 'Unterstützte Formate & Algorithmen',
    'education.jpegOptTitle': 'JPEG Optimierung',
    'education.jpegOptDesc': 'Progressive JPEG-Kodierung, Huffman-Tabellen-Optimierung, Chroma-Subsampling',
    'education.pngCompTitle': 'PNG Komprimierung',
    'education.pngCompDesc': 'DEFLATE-Algorithmus-Optimierung, Palette-Reduzierung, Alpha-Kanal-Erhaltung',
    'education.webpFormatTitle': 'Modernes WebP Format',
    'education.webpFormatDesc': 'VP8/VP9-Kodierung, verlustbehaftete und verlustfreie Modi, erweiterte Alpha-Transparenz',
    'education.heifTitle': 'HEIF/HEIC Unterstützung',
    'education.heifDesc': 'Hocheffiziente Kodierung, HDR-Unterstützung, Burst-Foto-Optimierung',
    'education.enterpriseFeaturesTitle': 'Unternehmensfunktionen',
    'education.apiIntegrationTitle': 'API-Integration',
    'education.apiIntegrationDesc': 'RESTful API, Webhook-Unterstützung, Batch-Processing-Endpunkte, Echtzeit-Status-Updates',
    'education.securityTitle': 'Sicherheit & Compliance',
    'education.securityDesc': 'SOC 2 Type II, GDPR-konform, Ende-zu-Ende-Verschlüsselung, automatische Dateilöschung',
    'education.performanceMonitoringTitle': 'Leistungsüberwachung',
    'education.performanceMonitoringDesc': 'Echtzeit-Analytik, Komprimierungsraten-Tracking, Bandbreiten-Einsparungs-Berichte',
    'education.scaleTitle': 'Skalierung & Zuverlässigkeit',
    'education.scaleDesc': '99.9% Uptime SLA, Auto-Scaling-Infrastruktur, globale CDN-Integration',
    'education.industryBestTitle': 'Industrie-Best-Practices für Bildoptimierung',
    'education.webPerfTitle': 'Web-Performance-Standards',
    'education.webPerfDesc': '• Core Web Vitals: Googles Performance-Metriken beeinflussen direkt SEO-Rankings. Optimierte Bilder verbessern Largest Contentful Paint (LCP) Scores um bis zu 40%.',
    'education.progressiveLoadingDesc': '• Progressive Loading: Implementieren Sie progressive JPEG-Kodierung für bessere wahrgenommene Performance. Benutzer sehen Bildinhalte während des Ladens.',
    'education.responsiveImagesDesc': '• Responsive Images: Verwenden Sie srcset-Attribute mit mehreren Bildgrößen, um angemessene Versionen für verschiedene Bildschirmgrößen und Auflösungen zu liefern.',
    'education.lazyLoadingDesc': '• Lazy Loading: Kombinieren Sie Bildkomprimierung mit Lazy Loading, um anfängliche Seitenladezeit und Bandbreitennutzung zu reduzieren.',
    'education.mobileOptTitle': 'Mobile Optimierungs-Strategie',
    'education.adaptiveQualityDesc': '• Adaptive Qualität: Liefern Sie niedrigere Qualitätsbilder an Benutzer mit langsamen Verbindungen, während Sie hohe Qualität für schnelle Netzwerke beibehalten.',
    'education.formatSelectionDesc': '• Format-Auswahl: Verwenden Sie WebP für unterstützte Browser (95% Abdeckung) mit JPEG-Fallbacks für ältere Browser.',
    'education.bandwidthAwarenessDesc': '• Bandbreiten-Bewusstsein: Berücksichtigen Sie Datenspar-Modi und implementieren Sie Qualitäts-Toggles für mobile Benutzer mit begrenzten Datentarifen.',
    'education.appBundleDesc': '• App-Bundle-Optimierung: Für mobile Apps komprimieren Sie gepackte Bilder, um Download-Größe zu reduzieren und App Store-Genehmigungsraten zu verbessern.',
    
    // Common
    'common.loading': 'Wird geladen...',
    'common.cancel': 'Abbrechen',
    'common.save': 'Speichern',
    'common.close': 'Schließen',
    'common.back': 'Zurück',
    'common.next': 'Weiter',
    'common.submit': 'Absenden',
    'common.upload': 'Hochladen',
    'common.download': 'Herunterladen',
    'message.processing': 'Verarbeitung...',
    'pricing.upgradeNow': 'Jetzt Upgraden',
    'pricing.cmsDesc': 'Herausgeber und Blogger sparen 60% der Speicherkosten und verbessern gleichzeitig SEO-Rankings. Komprimierte Bilder laden schneller, reduzieren Absprungraten und verbessern Suchmaschinen-Performance.',
    'pricing.apiIntegration': 'API-Integration mit WordPress, Drupal',
  },
  
  zh: {
    // Navigation
    'nav.home': '首页',
    'nav.compress': '压缩',
    'nav.history': '历史记录',
    'nav.login': '登录',
    'nav.signup': '注册',
    'nav.logout': '退出登录',
    'nav.pricing': '价格',
    'nav.pro': 'Pro',
    'nav.freePlan': '免费计划',
    'nav.proActive': 'Pro 激活',
    
    // History Page
    'history.title': '压缩历史',
    'history.subtitle': '查看并下载所有之前压缩的图片。',
    
    // Landing Page
    'landing.title': '专业图片压缩',
    'landing.subtitle': '压缩图片高达90%而不损失视觉质量。完美适用于网页优化和存储。',
    'landing.cta': '免费开始',
    'landing.features.title': '为什么选择CompressHub？',
    'landing.features.subtitle': '专业级图片压缩，配备先进算法和企业功能。',
    'landing.feature1.title': '超快速度',
    'landing.feature1.desc': '使用我们优化的压缩引擎在几秒钟内处理数百张图片。',
    'landing.feature2.title': '视觉质量',
    'landing.feature2.desc': '先进算法在最大化压缩的同时保持图片质量。',
    'landing.feature3.title': '开发者API',
    'landing.feature3.desc': '使用我们强大的REST API将压缩集成到您的工作流程中。',
    'landing.feature4.title': '安全处理',
    'landing.feature4.desc': '端到端加密确保您的图片保持私密和受保护。',
    'landing.getStarted': '免费开始',
    'landing.pricing.title': '简单定价',
    'landing.pricing.free': '免费',
    'landing.pricing.free.desc': '每天50次压缩',
    'landing.pricing.pro': '专业版',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': '无限压缩',
    'landing.pricing.upgrade': '升级到专业版',
    
    // Home Page
    'home.welcome': '欢迎使用CompressHub',
    'home.subtitle': '您的专业图片压缩工具',
    'home.startCompressing': '开始压缩',
    
    // Compress Page
    'compress.title': '压缩图片',
    'compress.unlockFeatures': '解锁全部功能',
    'compress.getUnlimitedAccess': '获得所有功能的无限访问权限',
    'compress.trackHistory': '跟踪您的压缩历史记录',
    'compress.viewStats': '查看详细的压缩统计信息',
    'compress.fiftyFreeDaily': '每日50次免费压缩',
    'compress.premiumPlans': '提供高级计划',
    'compress.createFreeAccount': '创建免费账户',
    'compress.dragDrop': '将图片拖拽到此处，或点击浏览',
    'compress.selectFiles': '选择文件',
    'compress.processing': '处理中...',
    'compress.completed': '已完成',
    'compress.download': '下载',
    'compress.downloadAll': '下载全部',
    'compress.quality': '质量',
    'compress.format': '格式',
    'compress.stats.files': '个文件已处理',
    'compress.stats.saved': '节省空间',
    
    // Stats Card
    'stats.todayActivity': '今日活动',
    'stats.imagesCompressed': '压缩图片数',
    'stats.totalSizeSaved': '节省总大小',
    'stats.averageReduction': '平均压缩率',
    'stats.freeTierUsage': '免费版使用量',
    
    // Recent History
    'recent.title': '最近压缩',
    'recent.viewAll': '查看全部',
    
    // Ultimate Guide SEO Section (Chinese)
    'education.ultimateGuideTitle': '2025年终极图像压缩指南',
    'education.ultimateGuideDesc': '通过我们的综合指南掌握图像优化艺术。向行业专家学习，获得专业成果。',
    'education.jpegTitle': 'JPEG压缩',
    'education.jpegDesc': '掌握用于网络和印刷的JPEG优化技术。学习质量设置、渐进编码和色彩空间优化。',
    'education.bestForPhotos': '最适合照片',
    'education.pngTitle': 'PNG优化',
    'education.pngDesc': '用于透明度保存的高级PNG压缩策略。调色板优化和无损压缩技术。',
    'education.bestForGraphics': '最适合图形',
    'education.webpTitle': 'WebP转换',
    'education.webpDesc': '下一代WebP格式，具有卓越的压缩比。包含浏览器兼容性和回退策略。',
    'education.bestForWeb': '最适合网络',
    'education.bulkTitle': '批量处理',
    'education.bulkDesc': '企业级批量压缩工作流程。API集成和自动化优化管道，用于规模化。',
    'education.bestForEnterprise': '最适合企业',
    
    // Education Section (Chinese)
    'education.title': '图像压缩完整指南',
    'education.subtitle': '学习图像压缩的一切知识，从基础概念到高级技术。',
    'education.technicalTitle': '技术深入：图像压缩是如何工作的',
    'education.lossyVsLossless': '有损与无损压缩',
    'education.lossyDesc': '有损压缩通过删除一些图像数据来减少文件大小，文件更小但质量略有损失。',
    'education.losslessDesc': '无损压缩保留所有原始图像数据，文件较大但保持完美质量。',
    'education.whenToUse': '何时使用每种类型',
    'education.lossyUse': '有损：照片、网络图像、社交媒体',
    'education.losslessUse': '无损：标志、图形、医学图像',
    'education.webpUse': 'WebP：支持先进压缩的现代网站',
    'education.qualityBalance': '质量与文件大小平衡',
    'education.balanceDesc': '在图像质量和文件大小之间找到最佳平衡对于网络性能至关重要。我们的压缩算法分析每张图像以确定最佳设置。',
    'education.largeFiles': '大文件',
    'education.optimalWeb': '网络最优',
    'education.smallestFiles': '最小文件',
    'education.algorithmsTitle': '压缩算法',
    'education.jpegAlgorithm': 'JPEG使用离散余弦变换(DCT)通过将图像分割为8x8像素块来压缩图像。',
    'education.pngAlgorithm': 'PNG使用DEFLATE压缩，结合LZ77算法和霍夫曼编码。',
    'education.webpAlgorithm': 'WebP使用预测压缩来减少编码图像所需的数据。',
    'education.applicationsTitle': '行业应用案例',
    'education.ecommerceTitle': '电商和零售',
    'education.ecommerceDesc': '减少产品页面加载时间，提高转化率和用户体验。',
    'education.mediaTitle': '数字媒体和出版',
    'education.mediaDesc': '为网站、数字杂志和社交媒体平台优化图像。',
    'education.mobileTitle': '移动应用开发',
    'education.mobileDesc': '通过减少图像资源大小来最小化应用大小并改善性能。',
    'education.marketingTitle': '营销和广告',
    'education.marketingDesc': '确保广告活动在所有设备和连接上快速加载。',
    'education.tipsTitle': '专业压缩技巧',
    'education.tip1Title': '选择正确的格式',
    'education.tip1Desc': 'JPEG用于照片，PNG用于带透明度的图像，WebP用于现代网络。',
    'education.tip2Title': '针对上下文优化',
    'education.tip2Desc': '网络图像可以使用比印刷图像更高的压缩率。',
    'education.tip3Title': '使用质量工具',
    'education.tip3Desc': '投资专业压缩软件以获得更好的结果。',
    'education.tip4Title': '考虑性能',
    'education.tip4Desc': '平衡图像质量与加载时间以获得最佳用户体验。',
    'education.formatTitle': '图像格式比较指南',
    'education.jpegSpecs': 'JPEG：适用于照片和复杂图像。有损压缩，文件大小小。',
    'education.pngSpecs': 'PNG：适用于图形、标志和带透明度的图像。无损压缩。',
    'education.webpSpecs': 'WebP：具有卓越压缩的现代网络格式。支持有损和无损。',
    'education.heifSpecs': 'HEIF：苹果的高效格式。比JPEG压缩更好，质量更高。',
    'education.qualityTitle': '质量与文件大小指南',
    'education.qualityDesc': '了解图像质量和文件大小之间的平衡以做出明智决策。',
    'education.quality100': '质量100%：最高质量，最大文件',
    'education.quality80': '质量80%：优秀质量，良好平衡',
    'education.quality60': '质量60%：良好质量，较小文件',
    'education.quality40': '质量40%：可接受质量，很小文件',
    'education.quality20': '质量20%：低质量，最小文件',
    
    // Home page missing translations (Chinese)
    'home.batchProcessing': '批量处理',
    'home.multipleFormats': '多种格式',
    'home.apiAccess': 'API访问',
    'home.secureProcessing': '安全处理',
    'home.qualityBalance': '质量与文件大小平衡',
    'home.qualityBalanceDesc': '找到图像质量和文件大小之间的最佳平衡对网络性能至关重要。我们的压缩算法分析每个图像以确定最佳设置。',
    'home.webpModern': 'WebP: 支持先进压缩的现代网站',
    'home.webDevelopment': '网络开发',
    'home.ecommerce': '电商',
    'home.contentCreation': '内容创作',
    'home.mobileApps': '移动应用',
    
    // Compress page missing translations (Chinese)
    'compress.freeCompressionAvailable': '下方提供免费压缩 • 注册享受无限访问和历史记录',
    'compress.filesProcessedSecurely': '文件安全处理',
    'compress.unlockFullFeatures': '解锁全部功能',
    'compress.getUnlimitedAccess': '获得无限访问和高级功能',
    'compress.trackHistory': '跟踪压缩历史',
    'compress.viewStats': '查看详细统计',
    'compress.fiftyFreeDaily': '每日50次免费压缩',
    'compress.premiumPlans': '高级计划，无限访问',
    'compress.createFreeAccount': '创建免费账户',
    'compress.dropImagesHere': '将图像拖放到此处或点击浏览',
    'compress.supportFormats': '支持JPG、PNG、WebP、HEIC，每个最大50MB',
    'compress.trySampleFile': '试用示例文件',
    
    // Pricing page missing translations (Chinese)
    'pricing.proFeatures': '专业功能',
    'pricing.unlimitedCompressions': '无限压缩',
    'pricing.filesUpTo100MB': '文件最大100MB',
    'pricing.batchProcessing100': '批量处理（100个文件）',
    'pricing.priorityProcessing': '优先处理',
    'pricing.apiAccess': 'API访问',
    'pricing.prioritySupport': '24/7优先支持',
    'pricing.perMonth': '$9/月',
    'pricing.cancelAnytime': '随时取消',
    'pricing.upgradeToCompressHub': '升级到CompressHub Pro',
    'pricing.unlockUnlimited': '以$9/月解锁无限压缩和专业功能',
    'pricing.sslSecure': 'SSL安全',
    'pricing.rating': '4.9/5评分',
    
    // Enterprise content translations (Chinese)
    'pricing.enterpriseTitle': '企业图像压缩解决方案',
    'pricing.ecommerceOptimization': '电商优化',
    'pricing.ecommerceOptDesc': '使用CompressHub Pro的在线零售商报告页面加载时间快40%，转化率提高25%。产品图像即时加载，减少购物车放弃，改善客户体验。',
    'pricing.batchProcess1000s': '批量处理数千个产品图像',
    'pricing.maintainQuality': '在整个目录中保持一致的质量',
    'pricing.optimizeMobile': '为移动购物者优化',
    'pricing.cmsTitle': '内容管理系统',
    'pricing.cmsDesc': '发布商和博主节省60%的存储成本，同时提高SEO排名。压缩图像加载更快，减少跳出率，改善搜索引擎性能。',
    'pricing.apiIntegration': '与WordPress、Drupal的API集成',
    'pricing.autoCompression': '上传时自动压缩',
    'pricing.seoOptimized': 'SEO优化的文件大小',
    'pricing.mobileAppDev': '移动应用开发',
    'pricing.mobileDevDesc': '移动开发者将应用包大小减少高达75%，同时保持视觉质量。更小的应用下载更快，使用更少的设备存储。',
    'pricing.optimizeIosAndroid': '为iOS和Android优化',
    'pricing.multipleDensity': '多密度支持',
    'pricing.fasterAppStore': '更快的应用商店审批',

    // App name and footer
    'app.name': 'CompressHub',
    'landing.readyToCompress': '准备压缩您的图片吗？',
    'landing.trustMessage': '加入数千名信任CompressHub满足其图像优化需求的专业人士。',
    'footer.description': '专业人士和企业最先进的图像压缩平台。',
    'footer.copyright': '版权所有。',
    
    // Upgrade Card
    'upgrade.title': '升级到专业版',
    'upgrade.desc': '解锁无限压缩、更大文件、批量处理和优先支持。',
    'upgrade.feature1': '每日无限压缩',
    'upgrade.feature2': '处理高达100MB的文件',
    'upgrade.feature3': '批量上传高达100个文件',
    'upgrade.feature4': '优先处理速度',
    'upgrade.feature5': '高级API访问',
    'upgrade.feature6': '24/7优先支持',
    'upgrade.button': '升级到专业版 - $9/月',
    
    // Checkout
    'checkout.title': '升级到专业版',
    'checkout.subtitle': '解锁无限压缩和高级功能，仅需$9/月',
    'checkout.features': '高级功能',
    'checkout.feature.unlimited': '无限日使用',
    'checkout.feature.large': '文件高达100MB',
    'checkout.feature.batch': '批量处理100个文件',
    'checkout.feature.priority': '优先处理速度',
    'checkout.feature.api': '高级API访问',
    'checkout.feature.support': '24/7优先支持',
    'checkout.firstName': '名字',
    'checkout.lastName': '姓氏',
    'checkout.email': '邮箱',
    'checkout.password': '密码',
    'checkout.promoCode': '有优惠码吗？',
    'checkout.hidePromo': '隐藏优惠码',
    'checkout.payment': '支付信息',
    'checkout.startPro': '开始专业版 - $9/月',
    'checkout.subscribePro': '订阅专业版 - $9/月',
    'checkout.perMonth': '每月 • 随时取消',
    'checkout.upgradeTitle': '升级到CompressHub Pro',
    'checkout.unlimitedFeatures': '解锁无限压缩和专业功能',
    'checkout.whatsIncluded': '包含内容',
    'checkout.sslSecure': 'SSL安全',
    'checkout.cancelAnytime': '随时取消',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 来自2,000+用户',
    'checkout.createAccountSubscribe': '创建账户并订阅',
    'checkout.joinThousands': '加入数千名使用CompressHub Pro的创作者',
    'checkout.sslSecured': 'SSL安全保护',
    'checkout.pciCompliant': 'PCI合规',
    'checkout.completeUpgrade': '完成您的升级',
    'checkout.addPaymentMethod': '添加付款方式以解锁Pro功能',
    
    // Missing education content translations for Chinese
    'education.storageSavingsTitle': '存储节省',
    'education.performanceGainsTitle': '性能提升', 
    'education.conversionIncreaseTitle': '转化率提升',
    'education.techSupportedFormats': '支持的格式和算法',
    
    // Common
    'common.loading': '加载中...',
    'common.cancel': '取消',
    'common.save': '保存',
    'common.close': '关闭',
    'common.back': '返回',
    'common.next': '下一步',
    'common.submit': '提交',
    'common.upload': '上传',
    'common.download': '下载',
    'message.processing': '处理中...',
    'pricing.upgradeNow': '立即升级',
    'pricing.cmsDesc': '发布商和博主节省60%的存储成本，同时提高SEO排名。压缩图像加载更快，降低跳出率并改善搜索引擎性能。',
    'pricing.apiIntegration': '与WordPress、Drupal的API集成',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': '企业图像压缩解决方案',
    'education.ecommerceOptTitle': '电商优化',
    'education.ecommerceOptDesc': '使用CompressHub Pro的在线零售商报告页面加载时间快40%，转化率提高25%。产品图像即时加载，减少购物车放弃，改善客户体验。',
    'education.batchProcess': '批量处理数千个产品图像',
    'education.consistentQuality': '在整个目录中保持一致的质量',
    'education.optimizeMobile': '为移动购物者优化',
    'education.cmsTitle': '内容管理系统',
    'education.cmsDesc': '出版商和博客作者在存储成本上节省60%，同时提高SEO排名。压缩图像加载更快，减少跳出率并改善搜索引擎性能。',
    'education.apiIntegration': 'WordPress、Drupal API集成',
    'education.autoCompression': '上传时自动压缩',
    'education.seoOptimized': 'SEO优化文件大小',
    'education.mobileDevTitle': '移动应用开发',
    'education.mobileDevDesc': '移动开发者将应用包大小减少高达75%，同时保持视觉质量。更小的应用下载更快，使用更少的设备存储。',
    'education.optimizeIosAndroid': '针对iOS和Android优化',
    'education.densitySupport': '多密度支持',
    'education.fasterApproval': '应用商店审批更快',
    'education.roiTitle': '计算您的投资回报',
    'education.storageSavings': '存储节省',
    'education.storageSavingsDesc': '在整个图像库中减少60-80%的存储成本。',
    'education.savingsAmount': '每月节省$500',
    'education.savingsNote': '*基于10TB图像存储',
    'education.performanceGains': '性能提升',
    'education.performanceGainsDesc': '改善页面加载速度和用户体验指标。',
    'education.fasterLoadingPercent': '快40%',
    'education.performanceNote': '*网站平均改善',
    'education.conversionIncrease': '转化率提升',
    'education.conversionDesc': '通过改善用户体验获得更高的转化率。',
    'education.conversionPercent': '+25%转化',
    'education.conversionNote': '*电商客户平均',
    'education.techSpecsTitle': '技术规格和标准',
    'education.supportedFormatsTitle': '支持的格式和算法',
    'education.jpegOptTitle': 'JPEG优化',
    'education.jpegOptDesc': '渐进式JPEG编码，霍夫曼表优化，色度子采样',
    'education.pngCompTitle': 'PNG压缩',
    'education.pngCompDesc': 'DEFLATE算法优化，调色板减少，alpha通道保留',
    'education.webpFormatTitle': '现代WebP格式',
    'education.webpFormatDesc': 'VP8/VP9编码，有损和无损模式，高级alpha透明度',
    'education.heifTitle': 'HEIF/HEIC支持',
    'education.heifDesc': '高效编码，HDR支持，连拍照片优化',
    'education.enterpriseFeaturesTitle': '企业功能',
    'education.apiIntegrationTitle': 'API集成',
    'education.apiIntegrationDesc': 'RESTful API，webhook支持，批处理端点，实时状态更新',
    'education.securityTitle': '安全与合规',
    'education.securityDesc': 'SOC 2 Type II，GDPR合规，端到端加密，自动文件删除',
    'education.performanceMonitoringTitle': '性能监控',
    'education.performanceMonitoringDesc': '实时分析，压缩比跟踪，带宽节省报告',
    'education.scaleTitle': '规模与可靠性',
    'education.scaleDesc': '99.9%正常运行时间SLA，自动扩展基础设施，全球CDN集成',
    'education.industryBestTitle': '图像优化行业最佳实践',
    'education.webPerfTitle': 'Web性能标准',
    'education.webPerfDesc': '• 核心网络指标：Google的性能指标直接影响SEO排名。优化图像将最大内容绘制（LCP）分数提高多达40%。',
    'education.progressiveLoadingDesc': '• 渐进式加载：实施渐进式JPEG编码以获得更好的感知性能。用户在加载时看到图像内容。',
    'education.responsiveImagesDesc': '• 响应式图像：使用具有多种图像尺寸的srcset属性为不同屏幕尺寸和分辨率提供适当版本。',
    'education.lazyLoadingDesc': '• 懒加载：将图像压缩与懒加载相结合，以减少初始页面加载时间和带宽使用。',
    'education.mobileOptTitle': '移动优化策略',
    'education.adaptiveQualityDesc': '• 自适应质量：为慢速连接用户提供较低质量图像，同时为快速网络保持高质量。',
    'education.formatSelectionDesc': '• 格式选择：对支持的浏览器使用WebP（95%覆盖率），对旧浏览器使用JPEG回退。',
    'education.bandwidthAwarenessDesc': '• 带宽意识：考虑数据保存模式，为有限数据计划的移动用户实施质量切换。',
    'education.appBundleDesc': '• 应用包优化：对于移动应用，压缩打包图像以减少下载大小并提高应用商店批准率。',
  },
  
  ja: {
    // Navigation
    'nav.home': 'ホーム',
    'nav.compress': '圧縮',
    'nav.history': '履歴',
    'nav.login': 'ログイン',
    'nav.signup': 'サインアップ',
    'nav.logout': 'ログアウト',
    'nav.pricing': '料金',
    'nav.pro': 'プロ',
    'nav.freePlan': '無料プラン',
    'nav.proActive': 'プロ有効',
    
    // History Page
    'history.title': '圧縮履歴',
    'history.subtitle': '以前に圧縮したすべての画像を表示およびダウンロードします。',
    
    // Landing Page
    'landing.title': 'プロフェッショナル画像圧縮',
    'landing.subtitle': '視覚的品質を保ちながら画像を最大90%まで小さく圧縮。ウェブ最適化とストレージに最適。',
    'landing.cta': '無料で始める',
    'landing.features.title': 'なぜCompressHubを選ぶのか？',
    'landing.features.subtitle': '高度なアルゴリズムとエンタープライズ機能を備えたプロ級画像圧縮。',
    'landing.feature1.title': '超高速',
    'landing.feature1.desc': '最適化された圧縮エンジンで何百もの画像を数秒で処理。',
    'landing.feature2.title': '視覚品質',
    'landing.feature2.desc': '高度なアルゴリズムが圧縮を最大化しながら画像品質を保持。',
    'landing.feature3.title': 'デベロッパーAPI',
    'landing.feature3.desc': '強力なREST APIでワークフローに圧縮を統合。',
    'landing.feature4.title': 'セキュア処理',
    'landing.feature4.desc': 'エンドツーエンド暗号化で画像のプライバシーと保護を保証。',
    'landing.getStarted': '無料で始める',
    'landing.pricing.title': 'シンプルな料金',
    'landing.pricing.free': '無料',
    'landing.pricing.free.desc': '1日50回の圧縮',
    'landing.pricing.pro': 'プロ',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': '無制限圧縮',
    'landing.pricing.upgrade': 'プロにアップグレード',
    
    // Home Page
    'home.welcome': 'CompressHubへようこそ',
    'home.subtitle': 'あなたのプロ画像圧縮ツール',
    'home.startCompressing': '圧縮を開始',
    
    // Compress Page
    'compress.title': '画像圧縮',
    'compress.unlockFeatures': '全機能を解除',
    'compress.getUnlimitedAccess': 'すべての機能への無制限アクセスを取得',
    'compress.trackHistory': '圧縮履歴を追跡',
    'compress.viewStats': '詳細な圧縮統計を表示',
    'compress.fiftyFreeDaily': '毎日50回無料圧縮',
    'compress.premiumPlans': 'プレミアムプラン利用可能',
    'compress.createFreeAccount': '無料アカウント作成',
    'compress.dragDrop': 'ここに画像をドラッグするか、クリックして参照',
    'compress.selectFiles': 'ファイルを選択',
    'compress.processing': '処理中...',
    'compress.completed': '完了',
    'compress.download': 'ダウンロード',
    'compress.downloadAll': 'すべてダウンロード',
    'compress.quality': '品質',
    'compress.format': 'フォーマット',
    'compress.stats.files': 'ファイル処理済み',
    'compress.stats.saved': 'スペース節約',
    
    // Upgrade Card
    'upgrade.title': 'プロにアップグレード',
    'upgrade.desc': '無制限圧縮、大容量ファイル、バッチ処理、優先サポートを解除。',
    'upgrade.feature1': '1日あたり無制限圧縮',
    'upgrade.feature2': '最大100MBのファイル処理',
    'upgrade.feature3': '最大100ファイルのバッチアップロード',
    'upgrade.feature4': '優先処理速度',
    'upgrade.feature5': '高度なAPIアクセス',
    'upgrade.feature6': '24/7優先サポート',
    'upgrade.button': 'プロにアップグレード - $9/月',
    
    // Checkout
    'checkout.title': 'プロにアップグレード',
    'checkout.subtitle': '無制限圧縮とプレミアム機能を月額$9で解除',
    'checkout.features': 'プレミアム機能',
    'checkout.feature.unlimited': '無制限日使用',
    'checkout.feature.large': '最大100MBファイル',
    'checkout.feature.batch': 'バッチ処理100ファイル',
    'checkout.feature.priority': '優先処理速度',
    'checkout.feature.api': '高度なAPIアクセス',
    'checkout.feature.support': '24/7優先サポート',
    'checkout.firstName': '名前',
    'checkout.lastName': '姓',
    'checkout.email': 'メール',
    'checkout.password': 'パスワード',
    'checkout.promoCode': 'プロモコードはありますか？',
    'checkout.hidePromo': 'プロモコードを非表示',
    'checkout.payment': '安全な支払い',
    'checkout.startPro': 'プロを開始 - $9/月',
    'checkout.subscribePro': 'プロを購読 - $9/月',
    'checkout.perMonth': '月額 • いつでもキャンセル',
    'checkout.upgradeTitle': 'CompressHub Proにアップグレード',
    'checkout.unlimitedFeatures': '無制限圧縮とプロ機能を解除',
    'checkout.whatsIncluded': '含まれる内容',
    'checkout.sslSecure': 'SSL セキュア',
    'checkout.cancelAnytime': 'いつでもキャンセル',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 2,000+ユーザーから',
    'checkout.createAccountSubscribe': 'アカウント作成と購読',
    'checkout.joinThousands': 'CompressHub Proを使用する数千のクリエイターに参加',
    'checkout.sslSecured': 'SSL保護済み',
    'checkout.pciCompliant': 'PCI準拠',
    'checkout.completeUpgrade': 'アップグレードを完了',
    'checkout.addPaymentMethod': 'Pro機能を解除するために支払い方法を追加',
    
    // Missing education content translations for Japanese
    'education.storageSavingsTitle': 'ストレージ節約',
    'education.performanceGainsTitle': 'パフォーマンス向上', 
    'education.conversionIncreaseTitle': 'コンバージョン増加',
    'education.techSupportedFormats': 'サポートされている形式とアルゴリズム',
    
    // Ultimate Guide SEO Section (Japanese)
    'education.ultimateGuideTitle': '2025年究極の画像圧縮ガイド',
    'education.ultimateGuideDesc': '包括的なガイドで画像最適化の技術をマスターしましょう。業界専門家から学び、プロフェッショナルな結果を達成してください。',
    'education.jpegTitle': 'JPEG圧縮',
    'education.jpegDesc': 'ウェブおよび印刷用のJPEG最適化技術をマスターしましょう。品質設定、プログレッシブエンコーディング、色空間最適化を学習します。',
    'education.bestForPhotos': '写真に最適',
    'education.pngTitle': 'PNG最適化',
    'education.pngDesc': '透明度保持のための高度なPNG圧縮戦略。パレット最適化とロスレス圧縮技術。',
    'education.bestForGraphics': 'グラフィックに最適',
    'education.webpTitle': 'WebP変換',
    'education.webpDesc': '優れた圧縮比を実現する次世代WebPフォーマット。ブラウザ互換性とフォールバック戦略が含まれます。',
    'education.bestForWeb': 'ウェブに最適',
    'education.bulkTitle': '一括処理',
    'education.bulkDesc': 'エンタープライズグレードのバッチ圧縮ワークフロー。スケール用のAPI統合と自動最適化パイプライン。',
    'education.bestForEnterprise': '企業に最適',
    
    // Education Section (Japanese)
    'education.title': '画像圧縮完全ガイド',
    'education.subtitle': '基本概念から高度な技術まで、画像圧縮のすべてを学習します。',
    'education.technicalTitle': '技術的詳細：画像圧縮の仕組み',
    'education.lossyVsLossless': '非可逆圧縮 vs 可逆圧縮',
    'education.lossyDesc': '非可逆圧縮は一部の画像データを削除してファイルサイズを削減します。',
    'education.losslessDesc': '可逆圧縮はすべての元の画像データを保持します。',
    'education.whenToUse': 'いつ各タイプを使用するか',
    'education.lossyUse': '非可逆：写真、ウェブ画像、ソーシャルメディア',
    'education.losslessUse': '可逆：ロゴ、グラフィック、医療画像',
    'education.webpUse': 'WebP：先進的圧縮をサポートする現代的なウェブサイト',
    'education.qualityBalance': '品質とファイルサイズのバランス',
    'education.balanceDesc': '画像品質とファイルサイズの最適なバランスを見つけることは、ウェブパフォーマンスにとって重要です。私たちの圧縮アルゴリズムは各画像を分析して最適な設定を決定します。',
    'education.largeFiles': '大容量ファイル',
    'education.optimalWeb': 'ウェブ最適',
    'education.smallestFiles': '最小ファイル',
    'education.algorithmsTitle': '圧縮アルゴリズム',
    'education.jpegAlgorithm': 'JPEGは離散コサイン変換（DCT）を使用して画像を圧縮します。',
    'education.pngAlgorithm': 'PNGはLZ77アルゴリズムとハフマン符号化を組み合わせたDEFLATE圧縮を使用します。',
    'education.webpAlgorithm': 'WebPは予測圧縮を使用して必要なデータを削減します。',
    'education.applicationsTitle': '業界での使用例',
    'education.ecommerceTitle': 'Eコマースと小売',
    'education.ecommerceDesc': 'コンバージョン率向上のためページ読み込み時間を短縮します。',
    'education.mediaTitle': 'デジタルメディアと出版',
    'education.mediaDesc': 'ウェブサイト、デジタル雑誌、ソーシャルメディア向けに画像を最適化します。',
    'education.mobileTitle': 'モバイルアプリ開発',
    'education.mobileDesc': '画像アセットのサイズ削減によりアプリサイズを最小化します。',
    'education.marketingTitle': 'マーケティングと広告',
    'education.marketingDesc': 'すべてのデバイスと接続で広告キャンペーンの高速読み込みを確保します。',
    'education.tipsTitle': 'プロ向け圧縮のコツ',
    'education.tip1Title': '正しい形式を選択',
    'education.tip1Desc': '写真にはJPEG、透明度にはPNG、モダンウェブにはWebP。',
    'education.tip2Title': 'コンテキストに最適化',
    'education.tip2Desc': 'ウェブ画像は印刷画像より高い圧縮を使用できます。',
    'education.tip3Title': '品質ツールを使用',
    'education.tip3Desc': 'より良い結果のためプロ向け圧縮ソフトウェアに投資してください。',
    'education.tip4Title': 'パフォーマンスを考慮',
    'education.tip4Desc': '最適なユーザー体験のため画質と読み込み時間のバランスを取ります。',
    'education.formatTitle': '画像形式比較ガイド',
    'education.jpegSpecs': 'JPEG：写真と複雑な画像に理想的。非可逆圧縮。',
    'education.pngSpecs': 'PNG：透明度のあるグラフィックやロゴに最適。可逆圧縮。',
    'education.webpSpecs': 'WebP：優れた圧縮のモダンウェブ形式。可逆・非可逆両対応。',
    'education.heifSpecs': 'HEIF：Appleの高効率形式。JPEGより良い圧縮。',
    'education.qualityTitle': '品質 vs ファイルサイズガイド',
    'education.qualityDesc': '情報に基づいた決定のため品質とサイズのバランスを理解します。',
    'education.quality100': '品質100%：最高品質、最大ファイル',
    'education.quality80': '品質80%：優秀品質、良いバランス',
    'education.quality60': '品質60%：良い品質、小さいファイル',
    'education.quality40': '品質40%：許容可能品質、非常に小さいファイル',
    'education.quality20': '品質20%：低品質、最小ファイル',

    // Educational Content - Pricing Page  
    'education.enterpriseTitle': 'エンタープライズ画像圧縮ソリューション',
    'education.ecommerceOptTitle': 'eコマース最適化',
    'education.ecommerceOptDesc': 'CompressHub Proを使用するオンライン小売業者は、ページ読み込み時間が40%高速化し、コンバージョン率が25%向上したと報告しています。商品画像が瞬時に読み込まれ、カート放棄を減らし、顧客体験を向上させます。',
    'education.roiTitle': '投資収益率を計算',
    'education.storageSavings': 'ストレージ削減',
    'education.storageSavingsDesc': '画像ライブラリ全体でストレージコストを60-80%削減します。',
    'education.savingsAmount': '月額$500節約',
    'education.savingsNote': '*10TB画像ストレージに基づく',
    'education.performanceGains': 'パフォーマンス向上',
    'education.performanceGainsDesc': 'ページ読み込み速度とユーザー体験指標を改善します。',
    'education.fasterLoadingPercent': '40%高速化',
    'education.performanceNote': '*ウェブサイトの平均改善',
    'education.conversionIncrease': 'コンバージョン増加',
    'education.conversionDesc': 'ユーザー体験の改善により高いコンバージョン率を実現。',
    'education.conversionPercent': '+25%コンバージョン',
    'education.conversionNote': '*eコマースクライアント平均',
    'education.techSpecsTitle': '技術仕様と標準',
    'education.supportedFormatsTitle': 'サポートされるフォーマットとアルゴリズム',
    'education.jpegOptTitle': 'JPEG最適化',
    'education.jpegOptDesc': 'プログレッシブJPEGエンコーディング、ハフマンテーブル最適化、クロマサブサンプリング',
    'education.pngCompTitle': 'PNG圧縮',
    'education.pngCompDesc': 'DEFLATEアルゴリズム最適化、パレット削減、アルファチャンネル保持',
    'education.webpFormatTitle': 'モダンWebPフォーマット',
    'education.webpFormatDesc': 'VP8/VP9エンコーディング、ロッシーおよびロスレスモード、高度なアルファ透明度',
    'education.heifTitle': 'HEIF/HEICサポート',
    'education.heifDesc': '高効率エンコーディング、HDRサポート、バースト写真最適化',
    'education.enterpriseFeaturesTitle': 'エンタープライズ機能',
    'education.apiIntegrationTitle': 'API統合',
    'education.apiIntegrationDesc': 'RESTful API、ウェブフックサポート、バッチ処理エンドポイント、リアルタイムステータス更新',
    'education.securityTitle': 'セキュリティとコンプライアンス',
    'education.securityDesc': 'SOC 2 Type II、GDPR準拠、エンドツーエンド暗号化、自動ファイル削除',
    'education.performanceMonitoringTitle': 'パフォーマンス監視',
    'education.performanceMonitoringDesc': 'リアルタイム分析、圧縮率追跡、帯域幅節約レポート',
    'education.scaleTitle': 'スケールと信頼性',
    'education.scaleDesc': '99.9%稼働時間SLA、オートスケーリングインフラ、グローバルCDN統合',
    'education.industryBestTitle': '画像最適化の業界ベストプラクティス',
    'education.webPerfTitle': 'ウェブパフォーマンス標準',
    'education.webPerfDesc': '• コアウェブバイタル：GoogleのパフォーマンスメトリクスはSEOランキングに直接影響します。最適化された画像はLargest Contentful Paint（LCP）スコアを最大40%改善します。',
    'education.progressiveLoadingDesc': '• プログレッシブローディング：プログレッシブJPEGエンコーディングを実装して知覚パフォーマンスを向上させます。ユーザーは読み込み中に画像コンテンツを見ることができます。',
    'education.responsiveImagesDesc': '• レスポンシブ画像：srcset属性を使用して複数の画像サイズで異なる画面サイズと解像度に適切なバージョンを提供します。',
    'education.lazyLoadingDesc': '• 遅延読み込み：画像圧縮と遅延読み込みを組み合わせて初期ページ読み込み時間と帯域幅使用量を削減します。',
    'education.mobileOptTitle': 'モバイル最適化戦略',
    'education.adaptiveQualityDesc': '• 適応品質：遅い接続のユーザーには低品質画像を提供しながら、高速ネットワークでは高品質を維持します。',
    'education.formatSelectionDesc': '• フォーマット選択：サポートされているブラウザ（95%カバレッジ）にはWebPを使用し、古いブラウザにはJPEGフォールバックを使用します。',
    'education.bandwidthAwarenessDesc': '• 帯域幅認識：データ節約モードを考慮し、限られたデータプランのモバイルユーザーに品質トグルを実装します。',
    'education.appBundleDesc': '• アプリバンドル最適化：モバイルアプリでは、パッケージ化された画像を圧縮してダウンロードサイズを削減し、アプリストア承認率を向上させます。',

    // Common
    'common.loading': '読み込み中...',
    'common.cancel': 'キャンセル',
    'common.save': '保存',
    'common.close': '閉じる',
    'common.back': '戻る',
    'common.next': '次へ',
    'common.submit': '送信',
    'common.upload': 'アップロード',
    'common.download': 'ダウンロード',
    'message.processing': '処理中...',
    'pricing.upgradeNow': '今すぐアップグレード',
    'pricing.cmsDesc': '編集者とブロガーは、SEOランキングを向上させながらストレージコストを60%削減します。圧縮された画像は高速で読み込まれ、離脱率を減らし、検索エンジンのパフォーマンスを向上させます。',
    'pricing.apiIntegration': 'WordPress、DrupalとのAPI統合',
    
    // Missing translation keys (Japanese)
    'landing.readyToCompress': '画像の圧縮準備はできましたか？',
    'landing.trustMessage': 'CompressHubを画像最適化ニーズで信頼する数千人のプロフェッショナルに参加してください。',
  },
  
  // Portuguese - Complete translations
  pt: {
    'nav.home': 'Início',
    'nav.compress': 'Comprimir',
    'nav.history': 'Histórico',
    'nav.login': 'Entrar',
    'nav.signup': 'Cadastrar',
    'nav.logout': 'Sair',
    'nav.pricing': 'Preços',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Plano Gratuito',
    'nav.proActive': 'Pro Ativo',
    
    // History Page
    'history.title': 'Histórico de Compressão',
    'history.subtitle': 'Visualize e baixe todas as suas imagens comprimidas anteriormente.',
    
    'landing.title': 'Compressão Profissional de Imagens',
    'landing.subtitle': 'Comprima imagens até 90% menores mantendo a qualidade visual. Perfeito para otimização web e armazenamento.',
    'landing.cta': 'Começar Grátis',
    'landing.features.title': 'Por que escolher CompressHub?',
    'landing.feature1.title': 'Super Rápido',
    'landing.feature1.desc': 'Processe centenas de imagens em segundos com nosso motor de compressão otimizado.',
    'landing.feature2.title': 'Qualidade Visual',
    'landing.feature2.desc': 'Algoritmos avançados preservam a qualidade da imagem maximizando a compressão.',
    'landing.pricing.title': 'Preços Simples',
    'landing.pricing.free': 'Grátis',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.price': '$9',
    
    // Upgrade Card
    'upgrade.title': 'Atualizar para Pro',
    'upgrade.desc': 'Desbloqueie compressões ilimitadas, arquivos maiores, processamento em lote e suporte prioritário.',
    'upgrade.feature1': 'Compressões ilimitadas por dia',
    'upgrade.feature2': 'Processar arquivos até 100MB cada',
    'upgrade.feature3': 'Upload em lote até 100 arquivos',
    'upgrade.feature4': 'Velocidade de processamento prioritária',
    'upgrade.feature5': 'Acesso API avançado',
    'upgrade.feature6': 'Suporte prioritário 24/7',
    'upgrade.button': 'Atualizar para Pro - $9/mês',
    
    // Missing checkout/pricing keys for Portuguese  
    'checkout.upgradeTitle': 'Atualizar para CompressHub Pro',
    'checkout.unlimitedFeatures': 'Desbloqueie compressão ilimitada com recursos profissionais',
    'checkout.whatsIncluded': 'O que está incluído',
    'checkout.sslSecure': 'SSL Seguro',
    'checkout.cancelAnytime': 'Cancele a qualquer momento',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4,9/5 de 2.000+ usuários',
    'checkout.createAccountSubscribe': 'Criar conta e assinar',
    'checkout.joinThousands': 'Junte-se a milhares de criadores usando CompressHub Pro',
    'checkout.sslSecured': 'SSL Protegido',
    'checkout.pciCompliant': 'Compatível com PCI',
    'checkout.completeUpgrade': 'Complete sua atualização',
    'checkout.addPaymentMethod': 'Adicione método de pagamento para desbloquear recursos Pro',
    
    // Missing compress page radio button and interface translations (Portuguese)
    'compress.qualityBest': 'Melhor qualidade',
    'compress.qualityHigh': 'Alta qualidade',
    'compress.qualityMedium': 'Qualidade média',
    'compress.qualitySmall': 'Arquivo pequeno',
    'compress.qualityMinimum': 'Arquivo mínimo',
    'compress.resizeImage': 'Redimensionar imagem',
    'compress.colorFilter': 'Filtro de cor',
    'compress.noFilter': 'Sem filtro',
    'compress.grayscale': 'Escala de cinza',
    'compress.sepia': 'Sépia',
    'compress.vintage': 'Vintage',
    'compress.outputFormat': 'Formato de saída',
    'compress.batchProcessing': 'Processamento em lote',
    'compress.multipleFormats': 'Múltiplos formatos',
    'compress.apiAccess': 'Acesso à API',
    'compress.secureProcessing': 'Processamento seguro',
    'compress.signUpFeatures': 'Cadastre-se e obtenha mais recursos',
    'compress.unlockFeatures': 'Desbloquear recursos',
    
    // Checkout
    'checkout.title': 'Atualizar para Pro',
    'checkout.subtitle': 'Desbloqueie compressão ilimitada e recursos premium por $9/mês',
    'checkout.features': 'Recursos Premium',
    'checkout.feature.unlimited': 'Uso Diário Ilimitado',
    'checkout.feature.large': 'Arquivos até 100MB',
    'checkout.feature.batch': 'Processamento em Lote 100 Arquivos',
    'checkout.feature.priority': 'Velocidade de Processamento Prioritária',
    'checkout.feature.api': 'Acesso API Avançado',
    'checkout.feature.support': 'Suporte Prioritário 24/7',
    'checkout.upgradeTitle': 'Atualizar para CompressHub Pro',
    'checkout.unlimitedFeatures': 'Desbloqueie compressão ilimitada com recursos profissionais',
    'checkout.whatsIncluded': 'O que está incluído',
    'checkout.sslSecure': 'SSL Seguro',
    'checkout.cancelAnytime': 'Cancelar a qualquer momento',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4,9/5 de 2.000+ usuários',
    'checkout.createAccountSubscribe': 'Criar conta e assinar',
    'checkout.joinThousands': 'Junte-se a milhares de criadores usando CompressHub Pro',
    'checkout.sslSecured': 'SSL Protegido',
    'checkout.pciCompliant': 'Compatível com PCI',
    'checkout.payment': 'Pagamento Seguro',
    'checkout.completeUpgrade': 'Complete sua atualização',
    'checkout.addPaymentMethod': 'Adicione método de pagamento para desbloquear recursos Pro',
    
    'common.loading': 'Carregando...',
    'compress.title': 'Compressor de Imagens',
    'compress.secure': 'Arquivos processados com segurança',
    'compress.dropFiles': 'Arraste imagens aqui ou clique para navegar',
    'compress.supportedFormats': 'Suporte para JPG, PNG, WebP, HEIC até 50MB cada',
    'compress.selectFiles': 'Selecionar Arquivos',
    'compress.trySample': 'Experimentar Arquivo Exemplo',
    'compress.batchProcessing': 'Processamento em Lote',
    'compress.secureProcessing': 'Processamento Seguro',
    'compress.signUpFeatures': 'Cadastre-se e Obtenha Mais Recursos',
    'compress.unlockFeatures': 'Desbloquear Todos os Recursos',
    'compress.processingStatus': 'Processando...',
    'compress.processingProgress': 'Processando ({completed}/{total})',
    'compress.professionalOptimization': 'Otimização profissional de imagens',
    'compress.qualityPreset': 'Predefinição de Qualidade',
    'compress.qualityBest': 'Melhor',
    'compress.qualityHigh': 'Alta',
    'compress.qualityMedium': 'Média',
    'compress.qualitySmall': 'Pequena',
    'compress.qualityMinimum': 'Mínima',
    'compress.autoRecommended': 'Auto (Recomendado)',
    'compress.showAdvanced': 'Mostrar opções avançadas',
    'compress.hideAdvanced': 'Ocultar opções avançadas',
    'compress.resizeImage': 'Redimensionar imagem',
    'compress.colorFilter': 'Filtro de cor',
    'compress.noFilter': 'Sem filtro',
    'compress.grayscale': 'Escala de cinza',
    'compress.sepia': 'Sépia',
    'compress.vintage': 'Vintage',
    
    // Education Section (Portuguese)
    'education.title': 'Guia Completo de Compressão de Imagens',
    'education.subtitle': 'Aprenda tudo sobre compressão de imagens, desde conceitos básicos até técnicas avançadas.',
    'education.technicalTitle': 'Mergulho Técnico: Como Funciona a Compressão de Imagens',
    'education.lossyVsLossless': 'Compressão com Perda vs Sem Perda',
    'education.lossyDesc': 'A compressão com perda remove alguns dados da imagem para reduzir o tamanho do arquivo.',
    'education.losslessDesc': 'A compressão sem perda preserva todos os dados originais da imagem.',
    'education.whenToUse': 'Quando Usar Cada Tipo',
    'education.lossyUse': 'Com perda: Fotografias, imagens web, redes sociais',
    'education.losslessUse': 'Sem perda: Logotipos, gráficos, imagens médicas',
    'education.webpUse': 'WebP: Sites modernos suportando compressão avançada',
    'education.qualityBalance': 'Equilíbrio Qualidade vs Tamanho de Arquivo',
    'education.balanceDesc': 'Encontrar o equilíbrio ideal entre qualidade de imagem e tamanho de arquivo é crucial para performance web. Nosso algoritmo de compressão analisa cada imagem para determinar as melhores configurações.',
    
    // Ultimate Guide SEO Section (Portuguese)
    'education.ultimateGuideTitle': 'O Guia Definitivo de Compressão de Imagens 2025',
    'education.ultimateGuideDesc': 'Domine a arte da otimização de imagens com nosso guia abrangente. Aprenda com especialistas da indústria e obtenha resultados profissionais.',
    'education.jpegTitle': 'Compressão JPEG',
    'education.jpegDesc': 'Domine técnicas de otimização JPEG para web e impressão. Aprenda configurações de qualidade, codificação progressiva e otimização do espaço de cores.',
    'education.bestForPhotos': 'Melhor para fotos',
    'education.pngTitle': 'Otimização PNG',
    'education.pngDesc': 'Estratégias avançadas de compressão PNG para preservação de transparência. Otimização de paleta e técnicas de compressão sem perdas.',
    'education.bestForGraphics': 'Melhor para gráficos',
    'education.webpTitle': 'Conversão WebP',
    'education.webpDesc': 'Formato WebP de próxima geração para taxas de compressão superiores. Compatibilidade de navegadores e estratégias de fallback incluídas.',
    'education.bestForWeb': 'Melhor para web',
    'education.bulkTitle': 'Processamento em Lote',
    'education.bulkDesc': 'Fluxos de trabalho de compressão em lote de nível empresarial. Integração de API e pipelines de otimização automatizados para escala.',
    'education.bestForEnterprise': 'Melhor para empresas',
    'education.highQuality': 'Alta Qualidade (90-100%)',
    'education.balanced': 'Balanceada (70-85%)',
    'education.aggressive': 'Agressiva (50-70%)',
    'education.largeFiles': 'Arquivos grandes',
    'education.optimalWeb': 'Ótimo para web',
    'education.smallestFiles': 'Arquivos menores',
    'education.algorithmsTitle': 'Algoritmos de Compressão',
    
    // Additional educational content keys (Portuguese)
    'education.guideTitle': 'Guia Completo de Compressão de Imagens',
    'education.guideSubtitle': 'Aprenda tudo que você precisa saber para otimizar suas imagens para web, mobile e impressão.',
    'education.contentCreation': 'Criação de Conteúdo',
    'education.contentDesc': 'Prepare imagens para redes sociais, blogs e materiais de marketing com tamanhos ideais para cada plataforma.',
    'education.webDev': 'Desenvolvimento Web',
    'education.webDevDesc': 'Reduza tempos de carregamento e melhore Core Web Vitals para melhores rankings SEO.',
    'education.compressionTitle': 'Por que Compressão de Imagem é Importante',
    'education.compressionDesc': 'Compressão de imagem é crucial para aplicações web modernas, reduzindo uso de largura de banda e tempos de carregamento.',
    'education.performanceTitle': 'Benefícios de Performance',
    'education.performanceDesc': 'Imagens adequadamente comprimidas melhoram velocidade de carregamento de página e experiência do usuário.',
    'education.fasterLoading': 'Carregamento Mais Rápido',
    'education.reducedBandwidth': 'Uso Reduzido de Largura de Banda',
    'education.betterSeo': 'Melhores Rankings SEO',
    'education.bestPracticesTitle': 'Melhores Práticas de Compressão',
    'education.bestPracticesDesc': 'Siga essas práticas testadas para resultados ótimos mantendo qualidade de imagem.',
    'education.qualityRange': 'Use 80-85% de qualidade para imagens web',
    'education.resizeFirst': 'Redimensione imagens para dimensões de exibição',
    'education.chooseFormat': 'Escolha formato apropriado para conteúdo',
    'education.jpegBest': 'JPEG: Melhor para fotos',
    'education.pngBest': 'PNG: Melhor para gráficos',
    'education.webpBest': 'WebP: Melhor para navegadores modernos',
    
    // Missing education content translations for Portuguese
    'education.storageSavingsTitle': 'Economia de Armazenamento',
    'education.performanceGainsTitle': 'Ganhos de Performance', 
    'education.conversionIncreaseTitle': 'Aumento de Conversão',
    'education.techSupportedFormats': 'Formatos Suportados e Algoritmos',
    
    // Missing landing page keys (Portuguese)
    'landing.readyToCompress': 'Pronto para comprimir suas imagens?',
    'landing.trustMessage': 'Junte-se a milhares de profissionais que confiam no CompressHub para suas necessidades de otimização de imagens.',
    'landing.getStarted': 'Começar Gratuitamente',
    
    // Footer and Educational section missing keys
    'footer.description': 'A plataforma de compressão de imagens mais avançada para profissionais e empresas.',
    'education.applicationsTitle': 'Aplicações no Mundo Real',
    'education.applicationsDesc': 'Descubra como diferentes indústrias se beneficiam de soluções profissionais de compressão de imagens.',
    'education.compressionTips': 'Dicas de Compressão de Imagens Profissionais',
    'education.formatGuide': 'Guia de Comparação de Formatos de Imagem',
    'education.qualityGuide': 'Guia de Qualidade vs Tamanho do Arquivo',
    
    // Educational content keys that match compress page component (Portuguese)
    'education.tipsTitle': 'Dicas de Compressão de Imagens Profissionais',
    'education.tip1Title': 'Escolha o Formato Certo',
    'education.tip1Desc': 'JPEG para fotos, PNG para gráficos com transparência, WebP para navegadores modernos.',
    'education.tip2Title': 'Otimize as Configurações de Qualidade',
    'education.tip2Desc': 'Use qualidade de 80-85% para imagens web para equilibrar tamanho do arquivo e qualidade visual.',
    'education.tip3Title': 'Redimensione Antes de Comprimir',
    'education.tip3Desc': 'Escale imagens para seu tamanho de exibição antes da compressão para máxima redução de tamanho.',
    'education.tip4Title': 'Considere Seu Público',
    'education.tip4Desc': 'Compressão maior para usuários móveis, moderada para visualização desktop.',
    'education.tip5Title': 'Teste e Compare',
    'education.tip5Desc': 'Sempre visualize imagens comprimidas para garantir que a qualidade atenda seus padrões.',
    'education.tip6Title': 'Processamento em Lote',
    'education.tip6Desc': 'Carregue múltiplas imagens de uma vez para economizar tempo e garantir configurações consistentes.',
    'education.formatComparisonTitle': 'Guia de Comparação de Formatos de Imagem',
    'education.formatHeader': 'Formato',
    'education.bestForHeader': 'Melhor Para',
    'education.compressionHeader': 'Compressão',
    'education.transparencyHeader': 'Transparência',
    'education.jpegRow': 'Fotografias, imagens complexas',
    'education.excellentLossy': 'Excelente (lossy)',
    'education.no': 'Não',
    'education.pngRow': 'Gráficos, logos, capturas de tela',
    'education.goodLossless': 'Boa (lossless)',
    'education.yes': 'Sim',
    'education.webpRow': 'Aplicações web modernas',
    'education.superior': 'Superior',
    'education.heifRow': 'Fotografia móvel',
    'education.excellent': 'Excelente',
    'education.qualityGuideTitle': 'Guia de Qualidade vs Tamanho do Arquivo',
    'education.highQualityTitle': 'Alta Qualidade (90-100%)',
    'education.highQualityBest': 'Melhor para: Impressão, arquivo, fotografia profissional',
    'education.highQualityTrade': 'Troca: Arquivos grandes, carregamento lento',
    'education.balancedTitle': 'Equilibrada (70-85%)',
    'education.balancedBest': 'Melhor para: Imagens web, redes sociais, blogs',
    'education.balancedTrade': 'Troca: Boa qualidade, tamanho razoável',
    'education.aggressiveTitle': 'Agressiva (50-70%)',
    'education.aggressiveBest': 'Melhor para: Miniaturas, previews, móvel',
    'education.aggressiveTrade': 'Troca: Arquivos menores, alguma perda de qualidade',
    'education.ecommerce': 'E-commerce',
    'education.ecommerceDesc': 'Reduzir tempos de carregamento de páginas de produtos para melhorar taxas de conversão e experiência do usuário.',
    'education.mobileApps': 'Aplicativos Móveis',
    'education.mobileDesc': 'Minimizar tamanho de aplicativos e melhorar performance reduzindo o tamanho dos assets de imagem.',
    
    // Checkout page missing translations (Portuguese)
    'checkout.firstName': 'Nome',
    'checkout.lastName': 'Sobrenome',
    'checkout.email': 'E-mail',
    'checkout.password': 'Senha',
    'checkout.upgradeTitle': 'Atualizar para Pro',
    'checkout.unlimitedFeatures': 'Recursos Ilimitados',
    'checkout.sslSecure': 'SSL Seguro',
    'checkout.cancelAnytime': 'Cancelar a qualquer momento',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 de 2.000+ usuários',
    'checkout.createAccountSubscribe': 'Criar Conta e Assinar',
    'checkout.joinThousands': 'Junte-se a milhares de criadores usando CompressHub Pro',
    'checkout.sslSecured': 'SSL Protegido',
    'checkout.pciCompliant': 'Compatível com PCI',
    
    // Login Page (Portuguese)
    'login.title': 'Bem-vindo de volta',
    'login.subtitle': 'Faça login em sua conta para continuar',
    'login.formTitle': 'Entrar',
    'login.email': 'Endereço de e-mail',
    'login.emailPlaceholder': 'Digite seu endereço de e-mail',
    'login.password': 'Senha',
    'login.passwordPlaceholder': 'Digite sua senha',
    'login.signingIn': 'Entrando...',
    'login.signIn': 'Entrar',
    'login.noAccount': 'Não tem uma conta?',
    'login.signUp': 'Cadastrar',
    'login.backToHome': '← Voltar para o início',
    'login.errors.failed': 'Falha no login',
    'login.errors.invalid': 'E-mail ou senha inválidos',
    'login.errors.generic': 'Ocorreu um erro. Tente novamente.',
    
    // Signup Page (Portuguese)
    'signup.title': 'Criar conta',
    'signup.subtitle': 'Junte-se ao CompressHub e comece a otimizar suas imagens',
    'signup.formTitle': 'Cadastrar',
    'signup.firstName': 'Nome',
    'signup.firstNamePlaceholder': 'João',
    'signup.lastName': 'Sobrenome',
    'signup.lastNamePlaceholder': 'Silva',
    'signup.email': 'Endereço de e-mail',
    'signup.emailPlaceholder': 'joao@exemplo.com',
    'signup.password': 'Senha',
    'signup.passwordPlaceholder': 'Pelo menos 6 caracteres',
    'signup.confirmPassword': 'Confirmar senha',
    'signup.confirmPasswordPlaceholder': 'Confirme sua senha',
    'signup.creatingAccount': 'Criando conta...',
    'signup.createAccount': 'Criar conta',
    'signup.hasAccount': 'Já tem uma conta?',
    'signup.signIn': 'Entrar',
    'signup.backToHome': '← Voltar para o início',
    'signup.success.title': 'Conta criada',
    'signup.success.message': 'Sua conta foi criada com sucesso!',
    
    // Professional compression tips content (Portuguese)
    'education.tip1.title': 'Escolha o Formato Certo',
    'education.tip1.desc': 'JPEG para fotos, PNG para gráficos com transparência, WebP para navegadores modernos.',
    'education.tip2.title': 'Otimize as Configurações de Qualidade',
    'education.tip2.desc': 'Use qualidade de 80-85% para imagens web para equilibrar tamanho do arquivo e qualidade visual.',
    'education.tip3.title': 'Redimensione Antes de Comprimir',
    'education.tip3.desc': 'Escale imagens para seu tamanho de exibição antes da compressão para máxima redução de tamanho.',
    'education.tip4.title': 'Considere Seu Público',
    'education.tip4.desc': 'Compressão maior para usuários móveis, moderada para visualização desktop.',
    'education.tip5.title': 'Teste e Compare',
    'education.tip5.desc': 'Sempre visualize imagens comprimidas para garantir que a qualidade atenda seus padrões.',
    'education.tip6.title': 'Processamento em Lote',
    'education.tip6.desc': 'Carregue múltiplas imagens de uma vez para economizar tempo e garantir configurações consistentes.',
    
    // Format comparison guide (Portuguese)
    'education.format.jpeg': 'Fotografias, imagens complexas',
    'education.format.png': 'Gráficos, logos, capturas de tela',
    'education.format.webp': 'Aplicações web modernas',
    'education.format.heif': 'Fotografia móvel',
    'education.compression.excellent': 'Excelente (lossy)',
    'education.compression.good': 'Boa (lossless)',
    'education.compression.superior': 'Superior',
    'education.transparency.yes': 'Sim',
    'education.transparency.no': 'Não',
    
    // Quality guide (Portuguese)
    'education.highQuality.desc': 'Melhor para: Impressão, arquivo, fotografia profissional',
    'education.highQuality.tradeoff': 'Troca: Arquivos grandes, carregamento lento',
    'education.balanced.desc': 'Melhor para: Imagens web, redes sociais, blogs',
    'education.balanced.tradeoff': 'Troca: Boa qualidade, tamanho razoável',
    'education.aggressive.desc': 'Melhor para: Miniaturas, previews, móvel',
    'education.aggressive.tradeoff': 'Troca: Arquivos menores, alguma perda de qualidade',
    'education.proTip': 'Dica Pro',
    'education.proTipDesc': 'Comece com qualidade 80% e ajuste com base nas suas necessidades específicas. A maioria dos visualizadores não notará a diferença, mas seu site carregará significativamente mais rápido.',

    // Login and Signup translations (Portuguese)
    'login.title': 'Bem-vindo de volta',
    'login.subtitle': 'Entre na sua conta para continuar',
    'login.formTitle': 'Entrar',
    'login.email': 'Email',
    'login.emailPlaceholder': 'Digite seu email',
    'login.password': 'Senha',
    'login.passwordPlaceholder': 'Digite sua senha',
    'login.signingIn': 'Entrando...',
    'login.signIn': 'Entrar',
    'login.noAccount': 'Não tem uma conta?',
    'login.signUp': 'Cadastre-se',
    'login.backToHome': '← Voltar ao início',
    'login.success.title': 'Login realizado',
    'login.success.message': 'Bem-vindo ao CompressHub!',
    'login.errors.emailInvalid': 'Email inválido',
    'login.errors.passwordShort': 'A senha deve ter pelo menos 6 caracteres',
    'login.errors.failed': 'Login falhou',
    'login.errors.generic': 'Ocorreu um erro. Tente novamente.',
    
    'signup.title': 'Criar Conta',
    'signup.subtitle': 'Junte-se ao CompressHub e comece a otimizar suas imagens',
    'signup.formTitle': 'Cadastrar',
    'signup.firstName': 'Nome',
    'signup.lastName': 'Sobrenome',
    'signup.email': 'Email',
    'signup.password': 'Senha',
    'signup.confirmPassword': 'Confirmar Senha',
    'signup.firstNamePlaceholder': 'Nome',
    'signup.lastNamePlaceholder': 'Sobrenome',
    'signup.emailPlaceholder': 'email@exemplo.com',
    'signup.passwordPlaceholder': 'Pelo menos 6 caracteres',
    'signup.confirmPasswordPlaceholder': 'Confirme sua senha',
    'signup.creatingAccount': 'Criando conta...',
    'signup.createAccount': 'Criar Conta',
    'signup.hasAccount': 'Já tem uma conta?',
    'signup.signIn': 'Entrar',
    'signup.backToHome': '← Voltar ao início',
    'signup.success.title': 'Conta criada',
    'signup.success.message': 'Sua conta foi criada com sucesso!',
    'signup.errors.firstNameShort': 'O nome deve ter pelo menos 2 caracteres',
    'signup.errors.lastNameShort': 'O sobrenome deve ter pelo menos 2 caracteres',
    'signup.errors.emailInvalid': 'Email inválido',
    'signup.errors.passwordShort': 'A senha deve ter pelo menos 6 caracteres',
    'signup.errors.passwordMismatch': 'As senhas não coincidem',
    'signup.errors.failed': 'Cadastro falhou',
    'signup.errors.generic': 'Ocorreu um erro. Tente novamente.',
    
    'education.jpegAlgorithm': 'JPEG usa transformada cosseno discreta (DCT) para compressão de imagens.',
    'education.pngAlgorithm': 'PNG usa compressão DEFLATE com algoritmo LZ77 e codificação Huffman.',
    'education.webpAlgorithm': 'WebP usa compressão preditiva para reduzir dados necessários.',

    'education.ecommerceTitle': 'E-commerce e Varejo',
    'education.mediaTitle': 'Mídia Digital e Publicação',
    'education.mediaDesc': 'Otimize imagens para sites, revistas digitais e redes sociais.',
    'education.mobileTitle': 'Desenvolvimento de Apps Móveis',
    'education.marketingTitle': 'Marketing e Publicidade',
    'education.marketingDesc': 'Garanta carregamento rápido de campanhas publicitárias.',
    // Removed duplicate education keys to fix conflicts
    // Removed duplicate education tip4 keys to fix conflicts
    'education.formatTitle': 'Guia de Comparação de Formatos',
    'education.jpegSpecs': 'JPEG: Ideal para fotografias. Compressão com perda.',
    'education.pngSpecs': 'PNG: Perfeito para gráficos com transparência. Sem perda.',
    'education.webpSpecs': 'WebP: Formato web moderno com compressão superior.',
    'education.heifSpecs': 'HEIF: Formato de alta eficiência da Apple.',
    'education.qualityTitle': 'Guia Qualidade vs Tamanho do Arquivo',
    'education.qualityDesc': 'Entenda o equilíbrio entre qualidade e tamanho.',
    'education.quality100': 'Qualidade 100%: Máxima qualidade, arquivo maior',
    'education.quality80': 'Qualidade 80%: Excelente qualidade, bom equilíbrio',
    'education.quality60': 'Qualidade 60%: Boa qualidade, arquivo menor',
    'education.quality40': 'Qualidade 40%: Qualidade aceitável, arquivo muito menor',
    'education.quality20': 'Qualidade 20%: Baixa qualidade, arquivo mínimo',
    
    // Home page missing translations (Portuguese)
    'home.batchProcessing': 'Processamento em Lote',
    'home.multipleFormats': 'Múltiplos Formatos',
    'home.apiAccess': 'Acesso à API',
    'home.secureProcessing': 'Processamento Seguro',
    'home.qualityBalance': 'Equilíbrio Qualidade vs Tamanho de Arquivo',
    'home.qualityBalanceDesc': 'Encontrar o equilíbrio ideal entre qualidade de imagem e tamanho de arquivo é crucial para performance web. Nosso algoritmo de compressão analisa cada imagem para determinar as melhores configurações.',
    'home.webpModern': 'WebP: Sites modernos suportando compressão avançada',
    'home.webDevelopment': 'Desenvolvimento Web',
    'home.ecommerce': 'E-commerce',
    'home.contentCreation': 'Criação de Conteúdo',
    'home.mobileApps': 'Aplicativos Móveis',
    
    // Compress page missing translations (Portuguese)
    'compress.freeCompressionAvailable': 'Compressão gratuita disponível abaixo • Cadastre-se para acesso ilimitado e histórico',
    'compress.filesProcessedSecurely': 'Arquivos processados com segurança',
    'compress.getUnlimitedAccess': 'Obtenha acesso ilimitado',
    'compress.trackHistory': 'Acompanhe histórico',
    'compress.viewStats': 'Visualize estatísticas',
    'compress.fiftyFreeDaily': '50 compressões gratuitas por dia',
    'compress.premiumPlans': 'Planos premium',
    'compress.createFreeAccount': 'Criar Conta Gratuita',
    
    // Pricing page missing translations (Portuguese)  
    'pricing.proFeatures': 'Recursos Pro',
    'pricing.unlimitedCompressions': 'Compressões Ilimitadas',
    'pricing.filesUpTo100MB': 'Arquivos até 100MB',
    'pricing.batchProcessing100': 'Processamento em Lote 100 Arquivos',
    'pricing.priorityProcessing': 'Processamento Prioritário',
    'pricing.apiAccess': 'Acesso à API',
    'pricing.prioritySupport': 'Suporte Prioritário',
    'compress.unlockFullFeatures': 'Desbloquear Todos os Recursos',
    // Removed duplicate compress keys to fix conflicts
    
    // Removed duplicate pricing keys to fix conflicts
    
    // Enterprise content translations (Portuguese)
    'pricing.enterpriseTitle': 'Soluções Empresariais de Compressão de Imagens',
    'pricing.ecommerceOptimization': 'Otimização de E-commerce',
    'pricing.ecommerceOptDesc': 'Varejistas online usando CompressHub Pro relatam tempos de carregamento 40% mais rápidos e taxas de conversão 25% maiores. Imagens de produtos carregam instantaneamente, reduzindo abandono de carrinho e melhorando a experiência do cliente.',
    'pricing.batchProcess1000s': 'Processar em lote milhares de imagens de produtos',
    'pricing.maintainQuality': 'Manter qualidade consistente em todo o catálogo',
    'pricing.optimizeMobile': 'Otimizar para compradores móveis',
    'pricing.cmsTitle': 'Sistemas de Gerenciamento de Conteúdo',
    'pricing.cmsDesc': 'Editores e blogueiros economizam 60% nos custos de armazenamento enquanto melhoram rankings SEO. Imagens comprimidas carregam mais rápido, reduzindo taxas de rejeição e melhorando performance nos motores de busca.',
    'pricing.apiIntegration': 'Integração API com WordPress, Drupal',
    'pricing.autoCompression': 'Compressão automática no upload',
    'pricing.seoOptimized': 'Tamanhos de arquivo otimizados para SEO',
    'pricing.mobileAppDev': 'Desenvolvimento de Aplicativos Móveis',
    'pricing.mobileDevDesc': 'Desenvolvedores móveis reduzem tamanhos de bundle de app em até 75% mantendo qualidade visual. Apps menores baixam mais rápido e usam menos armazenamento do dispositivo.',
    'pricing.optimizeIosAndroid': 'Otimizar para iOS e Android',
    'pricing.multipleDensity': 'Suporte a múltiplas densidades',
    'pricing.fasterAppStore': 'Aprovação mais rápida na app store',

    // Educational Content - Pricing Page
    'education.enterpriseTitle': 'Soluções de Compressão de Imagens Empresariais',
    'education.ecommerceOptTitle': 'Otimização E-commerce',
    'education.ecommerceOptDesc': 'Varejistas online usando CompressHub Pro relatam tempos de carregamento 40% mais rápidos e taxas de conversão 25% maiores. Imagens de produtos carregam instantaneamente, reduzindo abandono de carrinho e melhorando experiência do cliente.',
    'education.roiTitle': 'Calcule Seu Retorno sobre Investimento',
    'education.storageSavings': 'Economias de Armazenamento',
    'education.storageSavingsDesc': 'Reduza custos de armazenamento em 60-80% em toda sua biblioteca de imagens.',
    'education.savingsAmount': '$500/mês economizados',
    'education.savingsNote': '*Baseado em 10TB de armazenamento de imagens',
    'education.performanceGains': 'Ganhos de Performance',
    'education.performanceGainsDesc': 'Melhore velocidades de carregamento de página e métricas de experiência do usuário.',
    'education.fasterLoadingPercent': '40% mais rápido',
    'education.performanceNote': '*Melhoria média em sites',
    'education.conversionIncrease': 'Aumento de Conversão',
    'education.conversionDesc': 'Taxas de conversão mais altas através de experiência do usuário melhorada.',
    'education.conversionPercent': '+25% conversões',
    'education.conversionNote': '*Média de cliente e-commerce',
    'education.techSpecsTitle': 'Especificações Técnicas e Padrões',
    'education.supportedFormatsTitle': 'Formatos e Algoritmos Suportados',
    'education.jpegOptTitle': 'Otimização JPEG',
    'education.jpegOptDesc': 'Codificação JPEG progressiva, otimização de tabela Huffman, subamostragem croma',
    'education.pngCompTitle': 'Compressão PNG',
    'education.pngCompDesc': 'Otimização do algoritmo DEFLATE, redução de paleta, preservação do canal alfa',
    'education.webpFormatTitle': 'Formato WebP Moderno',
    'education.webpFormatDesc': 'Codificação VP8/VP9, modos com e sem perda, transparência alfa avançada',
    'education.heifTitle': 'Suporte HEIF/HEIC',
    'education.heifDesc': 'Codificação de alta eficiência, suporte HDR, otimização de foto burst',
    'education.enterpriseFeaturesTitle': 'Recursos Empresariais',
    'education.apiIntegrationTitle': 'Integração API',
    'education.apiIntegrationDesc': 'API RESTful, suporte webhook, endpoints de processamento em lote, atualizações de status em tempo real',
    'education.securityTitle': 'Segurança e Conformidade',
    'education.securityDesc': 'SOC 2 Type II, conforme GDPR, criptografia ponta a ponta, exclusão automática de arquivos',
    'education.performanceMonitoringTitle': 'Monitoramento de Performance',
    'education.performanceMonitoringDesc': 'Análises em tempo real, rastreamento de taxa de compressão, relatórios de economia de largura de banda',
    'education.scaleTitle': 'Escala e Confiabilidade',
    'education.scaleDesc': 'SLA de 99,9% de uptime, infraestrutura de auto-scaling, integração CDN global',
    'education.industryBestTitle': 'Melhores Práticas da Indústria para Otimização de Imagens',
    'education.webPerfTitle': 'Padrões de Performance Web',
    'education.webPerfDesc': '• Core Web Vitals: As métricas de performance do Google impactam diretamente os rankings SEO. Imagens otimizadas melhoram pontuações de Largest Contentful Paint (LCP) em até 40%.',
    'education.progressiveLoadingDesc': '• Carregamento Progressivo: Implemente codificação JPEG progressiva para melhor performance percebida. Usuários veem conteúdo da imagem enquanto carrega.',
    'education.responsiveImagesDesc': '• Imagens Responsivas: Use atributos srcset com múltiplos tamanhos de imagem para servir versões apropriadas para diferentes tamanhos de tela e resoluções.',
    'education.lazyLoadingDesc': '• Carregamento Lazy: Combine compressão de imagem com carregamento lazy para reduzir tempo de carregamento inicial da página e uso de largura de banda.',
    'education.mobileOptTitle': 'Estratégia de Otimização Móvel',
    'education.adaptiveQualityDesc': '• Qualidade Adaptativa: Sirva imagens de qualidade menor para usuários em conexões lentas enquanto mantém alta qualidade para redes rápidas.',
    'education.formatSelectionDesc': '• Seleção de Formato: Use WebP para navegadores suportados (95% de cobertura) com fallbacks JPEG para navegadores antigos.',
    'education.bandwidthAwarenessDesc': '• Consciência de Largura de Banda: Considere modos de economia de dados e implemente toggles de qualidade para usuários móveis em planos de dados limitados.',
    'education.appBundleDesc': '• Otimização de Bundle de App: Para apps móveis, comprima imagens empacotadas para reduzir tamanho de download e melhorar taxas de aprovação em app stores.',
    
    // Checkout page enterprise feature translations (Portuguese)
    'education.batchProcess': 'Processar em lote milhares de imagens de produtos',
    'education.consistentQuality': 'Manter qualidade consistente em todo o catálogo',
    'education.optimizeMobile': 'Otimizar para compradores móveis',
    
    // Additional missing checkout page translations (Portuguese)
    'education.supportedFormatsTitle': 'Formatos e Algoritmos Suportados',
    'education.jpegOptTitle': 'Otimização JPEG',
    'education.jpegOptDesc': 'Codificação JPEG progressiva, otimização de tabela Huffman, subamostragem de croma',
    'education.pngCompTitle': 'Compressão PNG',
    'education.pngCompDesc': 'Otimização do algoritmo DEFLATE, redução de paleta, preservação do canal alfa',
    'education.webpFormatTitle': 'Formato Moderno WebP',
    'education.webpFormatDesc': 'Codificação VP8/VP9, modos com e sem perdas, transparência alfa avançada',
    'education.heifTitle': 'Suporte HEIF/HEIC',
    'education.heifDesc': 'Codificação de alta eficiência, suporte HDR, otimização de fotos em rajada',
    'education.enterpriseFeaturesTitle': 'Recursos Empresariais',
    'education.apiIntegrationTitle': 'Integração API',
    'education.apiIntegrationDesc': 'API RESTful, suporte webhook, endpoints de processamento em lote, atualizações de status em tempo real',
    'education.securityTitle': 'Segurança e Conformidade',
    'education.securityDesc': 'SOC 2 Type II, compatível com GDPR, criptografia ponta a ponta, exclusão automática de arquivos',
    'education.performanceMonitoringTitle': 'Monitoramento de Performance',
    'education.performanceMonitoringDesc': 'Analytics em tempo real, rastreamento de taxa de compressão, relatórios de economia de largura de banda',
    'education.scaleTitle': 'Escala e Confiabilidade',
    'education.scaleDesc': 'SLA de 99,9% de uptime, infraestrutura de auto-escalonamento, integração CDN global',
    
    // Industry Best Practices section (Portuguese)
    'education.industryBestTitle': 'Melhores Práticas da Indústria para Otimização de Imagens',
    'education.webPerfTitle': 'Padrões de Performance Web',
    'education.mobileOptTitle': 'Estratégia de Otimização Móvel',
    
    // Checkout page subscription section (Portuguese)
    'checkout.upgradeTitle': 'Atualizar para CompressHub Pro',
    'checkout.unlimitedFeatures': 'Desbloqueie compressão ilimitada com recursos profissionais por $9/mês',
    'checkout.sslSecure': 'SSL Seguro',
    'checkout.sslSecured': 'SSL Protegido',
    'checkout.cancelAnytime': 'Cancele a Qualquer Momento',
    'checkout.pciCompliant': 'Compatível com PCI',
    'checkout.rating': 'Avaliação 4.9/5',
    'checkout.createAccountSubscribe': 'Criar Conta e Assinar',
    'checkout.joinThousands': 'Junte-se a milhares de criadores usando CompressHub Pro',
    'checkout.completeUpgrade': 'Complete Sua Atualização',
    'checkout.addPaymentMethod': 'Adicione método de pagamento para desbloquear recursos Pro',
  },

  // Italian - Complete translations  
  it: {
    'nav.home': 'Home',
    'nav.compress': 'Comprimi',
    'nav.history': 'Cronologia',
    'nav.login': 'Accedi',
    'nav.signup': 'Registrati',
    'nav.logout': 'Esci',
    'nav.pricing': 'Prezzi',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Piano Gratuito',
    'nav.proActive': 'Pro Attivo',
    
    // History Page
    'history.title': 'Cronologia Compressione',
    'history.subtitle': 'Visualizza e scarica tutte le immagini compresse in precedenza.',
    
    'landing.title': 'Compressione Immagini Professionale',
    'landing.subtitle': 'Comprimi le immagini fino al 90% più piccole mantenendo la qualità visiva. Perfetto per ottimizzazione web e archiviazione.',
    'landing.cta': 'Inizia Gratis',
    'landing.getStarted': 'Inizia Gratis',
    'landing.features.title': 'Perché scegliere CompressHub?',
    'landing.features.subtitle': 'Compressione immagini di livello professionale con algoritmi avanzati e funzionalità enterprise.',
    'landing.feature1.title': 'Super Veloce',
    'landing.feature1.desc': 'Elabora centinaia di immagini in secondi con il nostro motore di compressione ottimizzato.',
    'landing.feature2.title': 'Qualità Visiva',
    'landing.feature2.desc': 'Algoritmi avanzati preservano la qualità dell\'immagine massimizzando la compressione.',
    'landing.feature3.title': 'API Sviluppatori',
    'landing.feature3.desc': 'Integra la compressione nel tuo workflow con la nostra potente API REST.',
    'landing.feature4.title': 'Elaborazione Sicura',
    'landing.feature4.desc': 'Garantisce privacy e protezione delle immagini con crittografia end-to-end.',
    'landing.pricing.title': 'Prezzi Semplici',
    'landing.pricing.free': 'Gratuito',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.price': '$9',
    'upgrade.button': 'Aggiorna a Pro - $9/mese',
    'checkout.title': 'Aggiorna a Pro',
    'checkout.subtitle': 'Sblocca compressione illimitata per $9/mese',
    'checkout.upgradeTitle': 'Aggiorna a CompressHub Pro',
    'checkout.unlimitedFeatures': 'Sblocca compressione illimitata con funzionalità professionali',
    'checkout.whatsIncluded': 'Cosa è incluso',
    'checkout.sslSecure': 'SSL Sicuro',
    'checkout.cancelAnytime': 'Annulla in qualsiasi momento',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4,9/5 da 2.000+ utenti',
    'checkout.createAccountSubscribe': 'Crea account e abbonati',
    'checkout.joinThousands': 'Unisciti a migliaia di creatori che usano CompressHub Pro',
    'checkout.sslSecured': 'SSL Protetto',
    'checkout.pciCompliant': 'Conforme PCI',
    'checkout.payment': 'Pagamento Sicuro',
    'checkout.completeUpgrade': 'Completa il tuo aggiornamento',
    'checkout.addPaymentMethod': 'Aggiungi metodo di pagamento per sbloccare funzionalità Pro',
    
    // Missing education content translations for Italian
    'education.storageSavingsTitle': 'Risparmi di Archiviazione',
    'education.performanceGainsTitle': 'Miglioramenti delle Prestazioni', 
    'education.conversionIncreaseTitle': 'Aumento delle Conversioni',
    'education.techSupportedFormats': 'Formati Supportati e Algoritmi',
    'common.loading': 'Caricamento...',
    'compress.title': 'Compressore di Immagini',
    'compress.secure': 'File processati in sicurezza',
    'compress.dropFiles': 'Trascina immagini qui o clicca per sfogliare',
    'compress.supportedFormats': 'Supporto per JPG, PNG, WebP, HEIC fino a 50MB ciascuno',
    'compress.selectFiles': 'Seleziona File',
    'compress.trySample': 'Prova File Campione',
    'compress.batchProcessing': 'Elaborazione Batch',
    'compress.secureProcessing': 'Elaborazione Sicura',
    'compress.signUpFeatures': 'Registrati e Ottieni Più Funzionalità',
    'compress.freeCompressionAvailable': 'Compressione gratuita disponibile',
    'compress.getUnlimitedAccess': 'Ottieni accesso illimitato',
    'compress.trackHistory': 'Traccia la cronologia',
    'compress.viewStats': 'Visualizza statistiche',
    'compress.fiftyFreeDaily': '50 compressioni gratuite al giorno',
    'compress.premiumPlans': 'Piani premium',
    'compress.createFreeAccount': 'Crea Account Gratuito',
    
    // Enterprise pricing section missing translations (Italian)
    'pricing.enterpriseTitle': 'Soluzioni Enterprise di Compressione Immagini',
    'pricing.ecommerceTitle': 'Ottimizzazione E-commerce',
    'pricing.ecommerceDesc': 'I rivenditori online che utilizzano CompressHub Pro riportano tempi di caricamento più veloci del 40% e tassi di conversione superiori del 25%. Le immagini dei prodotti si caricano istantaneamente, riducendo l\'abbandono del carrello e migliorando l\'esperienza del cliente.',
    'pricing.batchProcess1000s': 'Elabora in batch migliaia di immagini di prodotti',
    'pricing.maintainQuality': 'Mantieni qualità costante in tutto il catalogo',
    'pricing.optimizeMobile': 'Ottimizza per acquirenti mobili',
    'pricing.cmsTitle': 'Sistemi di Gestione Contenuti',
    'pricing.cmsDesc': 'Editori e blogger risparmiano il 60% sui costi di archiviazione migliorando al contempo i ranking SEO. Le immagini compresse si caricano più velocemente, riducendo i tassi di rimbalzo e migliorando le prestazioni nei motori di ricerca.',
    'pricing.apiIntegration': 'Integrazione API con WordPress, Drupal',
    'pricing.autoCompression': 'Compressione automatica al caricamento',
    'pricing.seoOptimized': 'Dimensioni file ottimizzate per SEO',
    'pricing.mobileDevTitle': 'Sviluppo App Mobili',
    'pricing.mobileDevDesc': 'Gli sviluppatori mobile riducono le dimensioni dei bundle delle app fino al 75% mantenendo la qualità visiva. Le app più piccole si scaricano più velocemente e utilizzano meno spazio di archiviazione del dispositivo.',
    'pricing.optimizeIosAndroid': 'Ottimizza per iOS e Android',
    'pricing.multipleDensity': 'Supporto densità multiple',
    'pricing.fasterAppStore': 'Approvazione più rapida nell\'app store',
    
    // Pricing page missing translations (Italian)
    'pricing.proFeatures': 'Funzionalità Pro',
    'pricing.unlimitedCompressions': 'Compressioni Illimitate',
    'pricing.filesUpTo100MB': 'File fino a 100MB',
    'pricing.batchProcessing100': 'Elaborazione Batch 100 File',
    'pricing.priorityProcessing': 'Elaborazione Prioritaria',
    'pricing.apiAccess': 'Accesso API',
    'pricing.prioritySupport': 'Supporto Prioritario',
    
    // Home page features
    'home.title': 'Compressione Immagini Professionale',
    'home.subtitle': 'Comprimi immagini fino al 90% più piccole mantenendo la qualità visiva.',
    'home.batchProcessing': 'Elaborazione Batch',
    'home.multipleFormats': 'Formati Multipli',
    'home.apiAccess': 'Accesso API',
    'home.secureProcessing': 'Elaborazione Sicura',
    'home.feature1.title': 'Elaborazione Batch',
    'home.feature1.desc': 'Elabora centinaia di immagini contemporaneamente con il nostro sistema di compressione ad alte prestazioni.',
    'home.feature2.title': 'Formati Multipli',
    'home.feature2.desc': 'Supporta JPG, PNG, WebP, HEIC e molti altri formati con conversione automatica.',
    'home.feature3.title': 'Accesso API',
    'home.feature3.desc': 'Integra la compressione nel tuo workflow con la nostra potente API REST.',
    'home.feature4.title': 'Elaborazione Sicura',
    'home.feature4.desc': 'Tutte le immagini vengono elaborate localmente e cancellate automaticamente per la massima sicurezza.',
    'compress.unlockFeatures': 'Sblocca Tutte le Funzionalità',
    'compress.processingStatus': 'Elaborazione...',
    'compress.processingProgress': 'Elaborazione ({completed}/{total})',
    'compress.qualityPreset': 'Preimpostazione Qualità',
    'compress.qualityBest': 'Migliore Qualità',
    'compress.qualityHigh': 'Alta Qualità',
    'compress.qualityMedium': 'Qualità Media',
    'compress.qualitySmall': 'File Piccolo',
    'compress.qualityMinimum': 'Qualità Minima',
    'compress.outputFormat': 'Formato di Output',
    'compress.autoRecommended': 'Auto (Consigliato)',
    'compress.qualityLevel': 'Livello di Qualità',
    'compress.showAdvanced': 'Mostra Opzioni Avanzate',
    'compress.hideAdvanced': 'Nascondi Opzioni Avanzate',
    
    // Educational Content - Italian
    'education.title': 'Guida Completa alla Compressione delle Immagini',
    'education.subtitle': 'Impara tutto sulla compressione delle immagini, dai concetti base alle tecniche avanzate.',
    'education.technicalTitle': 'Approfondimento Tecnico: Come Funziona la Compressione delle Immagini',
    'education.lossyVsLossless': 'Compressione Lossy vs Lossless',
    'education.lossyDesc': 'La compressione lossy rimuove alcuni dati dell\'immagine per ridurre la dimensione del file.',
    'education.losslessDesc': 'La compressione lossless preserva tutti i dati originali dell\'immagine.',
    'education.whenToUse': 'Quando Usare Ogni Tipo',
    'education.lossyUse': 'Lossy: Fotografie, immagini web, social media',
    'education.losslessUse': 'Lossless: Loghi, grafica, immagini mediche',
    'education.webpUse': 'WebP: Siti web moderni che supportano compressione avanzata',
    'education.qualityBalance': 'Equilibrio Qualità vs Dimensione File',
    'education.balanceDesc': 'Trovare l\'equilibrio ottimale tra qualità dell\'immagine e dimensione del file è cruciale per le prestazioni web. Il nostro algoritmo di compressione analizza ogni immagine per determinare le migliori impostazioni.',
    'education.highQuality': 'Alta Qualità (90-100%)',
    'education.balanced': 'Bilanciata (70-85%)',
    'education.aggressive': 'Aggressiva (50-70%)',
    'education.largeFiles': 'File grandi',
    'education.optimalWeb': 'Ottimale per web',
    'education.smallestFiles': 'File più piccoli',
    'education.algorithmsTitle': 'Algoritmi di Compressione',
    
    // Additional educational content keys (Italian)
    'education.guideTitle': 'Guida Completa alla Compressione delle Immagini',
    'education.guideSubtitle': 'Impara tutto quello che devi sapere per ottimizzare le tue immagini per web, mobile e stampa.',
    'education.contentCreation': 'Creazione di Contenuti',
    'education.contentDesc': 'Prepara immagini per social media, blog e materiali di marketing con dimensioni ottimali per ogni piattaforma.',
    'education.webDev': 'Sviluppo Web',
    'education.webDevDesc': 'Riduci i tempi di caricamento e migliora i Core Web Vitals per migliori classifiche SEO.',
    'education.ecommerce': 'E-commerce',
    'education.ecommerceDesc': 'Riduci le dimensioni delle immagini dei prodotti senza perdere qualità per checkout più veloci e tassi di conversione più alti.',
    'education.mobileApps': 'App Mobile',
    'education.mobileDesc': 'Riduci le dimensioni dei bundle delle app attraverso la compressione ottimizzata delle immagini.',
    'education.compressionTitle': 'Perché la Compressione delle Immagini è Importante',
    'education.compressionDesc': 'La compressione delle immagini è cruciale per le applicazioni web moderne, riducendo l\'uso della banda e i tempi di caricamento.',
    'education.performanceTitle': 'Benefici delle Prestazioni',
    'education.performanceDesc': 'Le immagini adeguatamente compresse migliorano la velocità di caricamento delle pagine e l\'esperienza utente.',
    'education.fasterLoading': 'Caricamento Più Veloce',
    'education.reducedBandwidth': 'Uso Ridotto della Banda',
    'education.betterSeo': 'Migliori Classifiche SEO',
    'education.bestPracticesTitle': 'Migliori Pratiche di Compressione',
    'education.bestPracticesDesc': 'Segui queste pratiche collaudate per risultati ottimali mantenendo la qualità dell\'immagine.',
    'education.qualityRange': 'Usa 80-85% di qualità per immagini web',
    'education.resizeFirst': 'Ridimensiona le immagini alle dimensioni di visualizzazione',
    'education.chooseFormat': 'Scegli il formato appropriato per il contenuto',
    'education.jpegBest': 'JPEG: Migliore per le foto',
    'education.pngBest': 'PNG: Migliore per la grafica',
    'education.webpBest': 'WebP: Migliore per browser moderni',
    
    // Real-World Applications section
    'applications.title': 'Applicazioni nel Mondo Reale',
    'applications.subtitle': 'Scopri come diversi settori traggono beneficio dalle soluzioni di compressione immagini professionali.',
    'applications.ecommerce.title': 'E-commerce',
    'applications.ecommerce.desc': 'Migliora i tempi di caricamento delle pagine prodotto e aumenta le conversioni.',
    'applications.webdev.title': 'Sviluppo Web',
    'applications.webdev.desc': 'Ottimizza le prestazioni del sito web e il punteggio SEO con immagini più piccole.',
    'applications.marketing.title': 'Marketing',
    'applications.marketing.desc': 'Gestisci assets di campagne pubblicitarie su varie piattaforme digitali.',
    'applications.storage.title': 'Archiviazione',
    'applications.storage.desc': 'Riduci i costi di archiviazione cloud mantenendo la qualità delle immagini.',
    
    // Missing landing page keys (Italian)
    'landing.readyToCompress': 'Pronto a comprimere le tue immagini?',
    'landing.trustMessage': 'Unisciti a migliaia di professionisti che si fidano di CompressHub per le loro esigenze di ottimizzazione delle immagini.',
    
    // Footer and Educational section missing keys
    'footer.description': 'La piattaforma di compressione immagini più avanzata per professionisti e aziende.',
    'education.applicationsTitle': 'Applicazioni nel Mondo Reale',
    'education.applicationsDesc': 'Scopri come diversi settori traggono beneficio dalle soluzioni di compressione immagini professionali.',
    
    // Educational sections missing from Italian
    'education.compressionTips': 'Consigli per la Compressione Immagini Professionale',
    'education.formatGuide': 'Guida al Confronto dei Formati Immagine',
    'education.qualityGuide': 'Guida alla Qualità vs Dimensione del File',
    
    // Educational content keys that match compress page component (Italian)
    'education.tipsTitle': 'Consigli per la Compressione Immagini Professionale',
    'education.tip1Title': 'Scegli il Formato Giusto',
    'education.tip1Desc': 'JPEG per foto, PNG per grafica con trasparenza, WebP per browser moderni.',
    'education.tip2Title': 'Ottimizza le Impostazioni di Qualità',
    'education.tip2Desc': 'Usa qualità 80-85% per immagini web per bilanciare dimensione file e qualità visiva.',
    'education.tip3Title': 'Ridimensiona Prima di Comprimere',
    'education.tip3Desc': 'Scala le immagini alla loro dimensione di visualizzazione prima della compressione per massima riduzione.',
    'education.tip4Title': 'Considera il Tuo Pubblico',
    'education.tip4Desc': 'Compressione maggiore per utenti mobile, moderata per visualizzazione desktop.',
    'education.tip5Title': 'Testa e Confronta',
    'education.tip5Desc': 'Sempre anteprima delle immagini compresse per assicurare che la qualità soddisfi i tuoi standard.',
    'education.tip6Title': 'Elaborazione Batch',
    'education.tip6Desc': 'Carica più immagini contemporaneamente per risparmiare tempo e garantire impostazioni coerenti.',
    'education.formatComparisonTitle': 'Guida al Confronto dei Formati Immagine',
    'education.formatHeader': 'Formato',
    'education.bestForHeader': 'Meglio Per',
    'education.compressionHeader': 'Compressione',
    'education.transparencyHeader': 'Trasparenza',
    'education.jpegRow': 'Fotografie, immagini complesse',
    'education.excellentLossy': 'Eccellente (lossy)',
    'education.no': 'No',
    'education.pngRow': 'Grafica, loghi, screenshot',
    'education.goodLossless': 'Buona (lossless)',
    'education.yes': 'Sì',
    'education.webpRow': 'Applicazioni web moderne',
    'education.superior': 'Superiore',
    'education.heifRow': 'Fotografia mobile',
    'education.excellent': 'Eccellente',
    'education.qualityGuideTitle': 'Guida alla Qualità vs Dimensione del File',
    'education.highQualityTitle': 'Alta Qualità (90-100%)',
    'education.highQualityBest': 'Meglio per: Stampa, archivio, fotografia professionale',
    'education.highQualityTrade': 'Compromesso: File grandi, caricamento lento',
    'education.balancedTitle': 'Bilanciata (70-85%)',
    'education.balancedBest': 'Meglio per: Immagini web, social media, blog',
    'education.balancedTrade': 'Compromesso: Buona qualità, dimensione ragionevole',
    'education.aggressiveTitle': 'Aggressiva (50-70%)',
    'education.aggressiveBest': 'Meglio per: Miniature, anteprime, mobile',
    'education.aggressiveTrade': 'Compromesso: File più piccoli, perdita di qualità',
    
    // Ultimate Guide SEO Section (Italian)
    'education.ultimateGuideTitle': 'La Guida Definitiva alla Compressione delle Immagini 2025',
    'education.ultimateGuideDesc': 'Padroneggia l\'arte dell\'ottimizzazione delle immagini con la nostra guida completa. Impara dagli esperti del settore e ottieni risultati professionali.',
    'education.jpegTitle': 'Compressione JPEG',
    'education.jpegDesc': 'Padroneggia le tecniche di ottimizzazione JPEG per web e stampa. Impara le impostazioni di qualità, la codifica progressiva e l\'ottimizzazione dello spazio colore.',
    'education.bestForPhotos': 'Ideale per foto',
    'education.pngTitle': 'Ottimizzazione PNG',
    'education.pngDesc': 'Strategie avanzate di compressione PNG per la conservazione della trasparenza. Ottimizzazione della palette e tecniche di compressione lossless.',
    'education.bestForGraphics': 'Ideale per grafici',
    'education.webpTitle': 'Conversione WebP',
    'education.webpDesc': 'Formato WebP di nuova generazione per rapporti di compressione superiori. Compatibilità browser e strategie di fallback incluse.',
    'education.bestForWeb': 'Ideale per web',
    'education.bulkTitle': 'Elaborazione in Lotto',
    'education.bulkDesc': 'Flussi di lavoro di compressione batch di livello enterprise. Integrazione API e pipeline di ottimizzazione automatizzate per la scalabilità.',
    'education.bestForEnterprise': 'Ideale per aziende',
    
    // Professional compression tips content
    'education.tip1.title': 'Scegli il Formato Giusto',
    'education.tip1.desc': 'JPEG per foto, PNG per grafica con trasparenza, WebP per browser moderni.',
    'education.tip2.title': 'Ottimizza le Impostazioni di Qualità',
    'education.tip2.desc': 'Usa qualità 80-85% per immagini web per bilanciare dimensione file e qualità visiva.',
    'education.tip3.title': 'Ridimensiona Prima di Comprimere',
    'education.tip3.desc': 'Scala le immagini alla loro dimensione di visualizzazione prima della compressione per massima riduzione.',
    'education.tip4.title': 'Considera il Tuo Pubblico',
    'education.tip4.desc': 'Compressione maggiore per utenti mobile, moderata per visualizzazione desktop.',
    'education.tip5.title': 'Testa e Confronta',
    'education.tip5.desc': 'Sempre anteprima delle immagini compresse per assicurare che la qualità soddisfi i tuoi standard.',
    'education.tip6.title': 'Elaborazione Batch',
    'education.tip6.desc': 'Carica più immagini contemporaneamente per risparmiare tempo e garantire impostazioni coerenti.',
    
    // Format comparison guide
    'education.format.jpeg': 'Fotografie, immagini complesse',
    'education.format.png': 'Grafica, loghi, screenshot',
    'education.format.webp': 'Applicazioni web moderne',
    'education.format.heif': 'Fotografia mobile',
    'education.compression.excellent': 'Eccellente (lossy)',
    'education.compression.good': 'Buona (lossless)',
    'education.compression.superior': 'Superiore',
    'education.transparency.yes': 'Sì',
    'education.transparency.no': 'No',
    
    // Quality guide
    'education.highQuality.desc': 'Meglio per: Stampa, archivio, fotografia professionale',
    'education.highQuality.tradeoff': 'Compromesso: File grandi, caricamento lento',
    'education.balanced.desc': 'Meglio per: Immagini web, social media, blog',
    'education.balanced.tradeoff': 'Compromesso: Buona qualità, dimensione ragionevole',
    'education.aggressive.desc': 'Meglio per: Miniature, anteprime, mobile',
    'education.aggressive.tradeoff': 'Compromesso: File più piccoli, perdita di qualità',
    'education.proTip': 'Consiglio Pro',
    'education.proTipDesc': 'Inizia con una qualità dell\'80% e regola in base alle tue esigenze specifiche. La maggior parte degli utenti non noterà la differenza, ma il tuo sito web si caricherà significativamente più velocemente.',

    // Login and Signup translations (Italian)
    'login.title': 'Bentornato',
    'login.subtitle': 'Accedi al tuo account per continuare',
    'login.formTitle': 'Accedi',
    'login.email': 'Email',
    'login.emailPlaceholder': 'Inserisci la tua email',
    'login.password': 'Password',
    'login.passwordPlaceholder': 'Inserisci la tua password',
    'login.signingIn': 'Accesso in corso...',
    'login.signIn': 'Accedi',
    'login.noAccount': 'Non hai un account?',
    'login.signUp': 'Registrati',
    'login.backToHome': '← Torna alla home',
    'login.success.title': 'Accesso riuscito',
    'login.success.message': 'Benvenuto in CompressHub!',
    'login.errors.emailInvalid': 'Email non valida',
    'login.errors.passwordShort': 'La password deve essere di almeno 6 caratteri',
    'login.errors.failed': 'Accesso fallito',
    'login.errors.generic': 'Si è verificato un errore. Riprova.',
    
    'signup.title': 'Crea Account',
    'signup.subtitle': 'Unisciti a CompressHub e inizia a ottimizzare le tue immagini',
    'signup.formTitle': 'Registrati',
    'signup.firstName': 'Nome',
    'signup.lastName': 'Cognome',
    'signup.email': 'Email',
    'signup.password': 'Password',
    'signup.confirmPassword': 'Conferma Password',
    'signup.firstNamePlaceholder': 'Nome',
    'signup.lastNamePlaceholder': 'Cognome',
    'signup.emailPlaceholder': 'email@esempio.com',
    'signup.passwordPlaceholder': 'Almeno 6 caratteri',
    'signup.confirmPasswordPlaceholder': 'Conferma la tua password',
    'signup.creatingAccount': 'Creazione account...',
    'signup.createAccount': 'Crea Account',
    'signup.hasAccount': 'Hai già un account?',
    'signup.signIn': 'Accedi',
    'signup.backToHome': '← Torna alla home',
    'signup.success.title': 'Account creato',
    'signup.success.message': 'Il tuo account è stato creato con successo!',
    'signup.errors.firstNameShort': 'Il nome deve essere di almeno 2 caratteri',
    'signup.errors.lastNameShort': 'Il cognome deve essere di almeno 2 caratteri',
    'signup.errors.emailInvalid': 'Email non valida',
    'signup.errors.passwordShort': 'La password deve essere di almeno 6 caratteri',
    'signup.errors.passwordMismatch': 'Le password non corrispondono',
    'signup.errors.failed': 'Registrazione fallita',
    'signup.errors.generic': 'Si è verificato un errore. Riprova.',
    
    // Pricing page educational content (Italian)
    'education.webPerfTitle': 'Standard di Performance Web',
    'education.webPerfDesc': '• Core Web Vitals: Le metriche di performance di Google impattano direttamente le classifiche SEO. Le immagini ottimizzate migliorano i punteggi Largest Contentful Paint (LCP) fino al 40%.',
    'education.progressiveLoadingDesc': '• Caricamento Progressivo: Implementa la codifica JPEG progressiva per migliori performance percepite. Gli utenti vedono il contenuto dell\'immagine mentre si carica.',
    'education.responsiveImagesDesc': '• Immagini Responsive: Usa attributi srcset con dimensioni multiple per servire versioni appropriate per diverse dimensioni di schermo e risoluzioni.',
    'education.lazyLoadingDesc': '• Lazy Loading: Combina la compressione delle immagini con il caricamento lazy per ridurre il tempo di caricamento iniziale della pagina e l\'uso della banda.',
    'education.mobileOptTitle': 'Strategia di Ottimizzazione Mobile',
    'education.adaptiveQualityDesc': '• Qualità Adattiva: Servi immagini di qualità inferiore agli utenti su connessioni lente mantenendo alta qualità per reti veloci.',
    'education.formatSelectionDesc': '• Selezione Formato: Usa WebP per browser supportati (95% copertura) con fallback JPEG per browser più vecchi.',
    'education.bandwidthAwarenessDesc': '• Consapevolezza Banda: Considera modalità di risparmio dati e implementa toggle qualità per utenti mobile su piani dati limitati.',
    'education.appBundleDesc': '• Ottimizzazione Bundle App: Per app mobile, comprimi immagini in bundle per ridurre dimensione download e migliorare tassi approvazione app store.',
    
    // Enterprise content translations (Italian)
    'education.enterpriseTitle': 'Soluzioni di Compressione Immagini Aziendali',
    'education.ecommerceOptTitle': 'Ottimizzazione E-commerce',
    'education.ecommerceOptDesc': 'I rivenditori online che utilizzano CompressHub Pro riportano tempi di caricamento delle pagine del 40% più veloci e tassi di conversione del 25% più alti. Le immagini dei prodotti si caricano istantaneamente, riducendo l\'abbandono del carrello e migliorando l\'esperienza del cliente.',
    'education.batchProcess1000s': 'Elabora in batch migliaia di immagini prodotti',
    'education.maintainQuality': 'Mantieni qualità coerente in tutto il catalogo',
    'education.optimizeMobile': 'Ottimizza per acquirenti mobile',
    'education.cmsTitle': 'Sistemi di Gestione Contenuti',
    'education.cmsDesc': 'Editori e blogger risparmiano il 60% sui costi di archiviazione mentre migliorano le classifiche SEO. Le immagini compresse si caricano più velocemente, riducendo i tassi di rimbalzo e migliorando le prestazioni sui motori di ricerca.',
    'education.apiIntegration': 'Integrazione API con WordPress, Drupal',
    'education.autoCompression': 'Compressione automatica al caricamento',
    'education.seoOptimized': 'Dimensioni file ottimizzate SEO',
    'education.mobileAppDev': 'Sviluppo App Mobile',
    'education.mobileDevDesc': 'Gli sviluppatori mobile riducono le dimensioni del bundle dell\'app fino al 75% mantenendo la qualità visiva. Le app più piccole si scaricano più velocemente e utilizzano meno spazio di archiviazione del dispositivo.',
    'education.optimizeIosAndroid': 'Ottimizza per iOS e Android',
    'education.multipleDensity': 'Supporto densità multiple',
    'education.fasterAppStore': 'Approvazione app store più veloce',
    'education.roiTitle': 'Calcola il Tuo Ritorno sull\'Investimento',
    'education.storageSavings': 'Risparmi di Archiviazione',
    'education.storageSavingsDesc': 'Riduci i costi di archiviazione del 60-80% in tutta la tua libreria di immagini',
    'education.performanceGains': 'Miglioramenti delle Prestazioni',
    'education.performanceGainsDesc': 'Migliora la velocità di caricamento delle pagine e le metriche dell\'esperienza utente',
    'education.conversionIncrease': 'Aumento delle Conversioni',
    
    // ROI Calculator translations for checkout page (Italian)
    'education.savingsAmount': '$500/mese risparmiati',
    'education.savingsNote': '*Basato su 10TB di archiviazione immagini',
    'education.fasterLoadingPercent': '40% caricamento più veloce',
    'education.performanceNote': '*Miglioramento medio tra i siti',
    'education.conversionDesc': 'Tassi di conversione più alti grazie a una migliore esperienza utente',
    'education.conversionPercent': '+25% conversioni',
    'education.conversionNote': '*Media clienti e-commerce',
    
    // Enterprise feature translations (Italian)
    'pricing.batchProcess1000s': 'Elabora in batch migliaia di immagini di prodotti',
    'pricing.maintainQuality': 'Mantieni qualità coerente in tutto il catalogo',
    'pricing.optimizeMobile': 'Ottimizza per acquirenti mobili',
    'pricing.apiIntegration': 'Integrazione API con WordPress, Drupal',
    'pricing.autoCompression': 'Compressione automatica al caricamento',
    'pricing.seoOptimized': 'Dimensioni file ottimizzate per SEO',
    'pricing.optimizeIosAndroid': 'Ottimizza per iOS e Android',
    'pricing.multipleDensity': 'Supporto densità multiple',
    'pricing.fasterAppStore': 'Approvazione app store più veloce',
    
    // Checkout page enterprise feature translations (Italian)
    'education.batchProcess': 'Elabora in batch migliaia di immagini di prodotti',
    'education.consistentQuality': 'Mantieni qualità coerente in tutto il catalogo',
    
    // Technical Specifications (Italian) - Using unique key names to avoid conflicts
    'education.techSpecsTitle': 'Specifiche Tecniche e Standard',
    'education.techSupportedFormats': 'Formati e Algoritmi Supportati',
    'education.techJpegOptimization': 'Ottimizzazione JPEG',
    'education.techJpegDesc': 'Codifica JPEG progressiva, ottimizzazione tabella Huffman, sottocampionamento croma',
    'education.techPngCompression': 'Compressione PNG',
    'education.techPngDesc': 'Ottimizzazione algoritmo DEFLATE, riduzione palette, conservazione canale alfa',
    'education.techWebpModernFormat': 'Formato Moderno WebP',
    'education.techWebpDesc': 'Codifica VP8/VP9, modalità lossy e lossless, trasparenza alfa avanzata',
    'education.techHeifSupport': 'Supporto HEIF/HEIC',
    'education.techHeifDesc': 'Codifica ad alta efficienza, supporto HDR, ottimizzazione foto burst',
    'education.techEnterpriseFeatures': 'Funzionalità Enterprise',
    'education.techApiIntegration': 'Integrazione API',
    'education.techApiDesc': 'API RESTful, supporto webhook, endpoint elaborazione batch, aggiornamenti stato real-time',
    'education.techSecurityCompliance': 'Sicurezza e Conformità',
    'education.techSecurityDesc': 'SOC 2 Type II, conforme GDPR, crittografia end-to-end, eliminazione automatica file',
    'education.techPerformanceMonitoring': 'Monitoraggio Prestazioni',
    'education.techMonitoringDesc': 'Analytics real-time, tracciamento rapporto compressione, report risparmio banda',
    'education.techScaleReliability': 'Scala e Affidabilità',
    'education.techReliabilityDesc': 'SLA uptime 99.9%, infrastruttura auto-scaling, integrazione CDN globale',
    
    // Additional missing checkout page translations (Italian)
    'education.supportedFormatsTitle': 'Formati e Algoritmi Supportati',
    'education.jpegOptTitle': 'Ottimizzazione JPEG',
    'education.jpegOptDesc': 'Codifica JPEG progressiva, ottimizzazione tabella Huffman, sottocampionamento cromatico',
    'education.pngCompTitle': 'Compressione PNG',
    'education.pngCompDesc': 'Ottimizzazione algoritmo DEFLATE, riduzione palette, conservazione canale alfa',
    'education.webpFormatTitle': 'Formato Moderno WebP',
    'education.webpFormatDesc': 'Codifica VP8/VP9, modalità lossy e lossless, trasparenza alfa avanzata',
    'education.heifTitle': 'Supporto HEIF/HEIC',
    'education.heifDesc': 'Codifica ad alta efficienza, supporto HDR, ottimizzazione foto burst',
    'education.enterpriseFeaturesTitle': 'Funzionalità Enterprise',
    'education.apiIntegrationTitle': 'Integrazione API',
    'education.apiIntegrationDesc': 'API RESTful, supporto webhook, endpoint elaborazione batch, aggiornamenti stato real-time',
    'education.securityTitle': 'Sicurezza e Conformità',
    'education.securityDesc': 'SOC 2 Type II, conforme GDPR, crittografia end-to-end, eliminazione automatica file',
    'education.performanceMonitoringTitle': 'Monitoraggio Prestazioni',
    'education.performanceMonitoringDesc': 'Analytics real-time, tracciamento rapporto compressione, report risparmio banda',
    'education.scaleTitle': 'Scala e Affidabilità',
    'education.scaleDesc': 'SLA uptime 99.9%, infrastruttura auto-scaling, integrazione CDN globale',
    
    // Industry Best Practices section (Italian)
    'education.industryBestTitle': 'Migliori Pratiche del Settore per l\'Ottimizzazione delle Immagini',
    'education.webPerfTitle': 'Standard di Prestazioni Web',
    'education.mobileOptTitle': 'Strategia di Ottimizzazione Mobile',
    
    // Checkout page subscription section (Italian)
    'checkout.upgradeTitle': 'Aggiorna a CompressHub Pro',
    'checkout.unlimitedFeatures': 'Sblocca compressione illimitata con funzionalità professionali per $9/mese',
    'checkout.sslSecure': 'SSL Sicuro',
    'checkout.sslSecured': 'SSL Protetto',
    'checkout.cancelAnytime': 'Annulla in Qualsiasi Momento',
    'checkout.pciCompliant': 'Conforme PCI',
    'checkout.rating': 'Valutazione 4.9/5',
    'checkout.createAccountSubscribe': 'Crea Account e Abbonati',
    'checkout.joinThousands': 'Unisciti a migliaia di creatori che usano CompressHub Pro',
    'checkout.completeUpgrade': 'Completa il Tuo Aggiornamento',
    'checkout.addPaymentMethod': 'Aggiungi metodo di pagamento per sbloccare le funzionalità Pro',
    'checkout.firstName': 'Nome',
    'checkout.lastName': 'Cognome',
    'checkout.email': 'Indirizzo Email',
    'checkout.password': 'Password',
    'checkout.firstNamePlaceholder': 'Giovanni',
    'checkout.lastNamePlaceholder': 'Rossi',
    'checkout.emailPlaceholder': 'giovanni@esempio.it',
    'checkout.passwordPlaceholder': 'La tua password',
    'checkout.promoCode': 'Hai un codice promozionale?',
    'checkout.promoCodePlaceholder': 'Inserisci il codice promozionale',
  },

  // Russian - Complete translations
  ru: {
    'nav.home': 'Главная',
    'nav.compress': 'Сжать',
    'nav.history': 'История',
    'nav.login': 'Войти',
    'nav.signup': 'Регистрация',
    'nav.logout': 'Выйти',
    'nav.pricing': 'Цены',
    'nav.pro': 'Pro',
    'nav.freePlan': 'Бесплатный План',
    'nav.proActive': 'Pro Активен',
    
    // History Page
    'history.title': 'История Сжатия',
    'history.subtitle': 'Просматривайте и загружайте все ваши ранее сжатые изображения.',
    
    'landing.title': 'Профессиональное Сжатие Изображений',
    'landing.subtitle': 'Сжимайте изображения до 90% меньше, сохраняя визуальное качество. Идеально для веб-оптимизации и хранения.',
    'landing.cta': 'Начать Бесплатно',
    'landing.features.title': 'Почему выбирают CompressHub?',
    'landing.features.subtitle': 'Профессиональное сжатие изображений с продвинутыми алгоритмами и корпоративными функциями.',
    'landing.feature1.title': 'Супер Быстро',
    'landing.feature1.desc': 'Обрабатывайте сотни изображений за секунды с нашим оптимизированным движком сжатия.',
    'landing.feature2.title': 'Визуальное Качество',
    'landing.feature2.desc': 'Продвинутые алгоритмы сохраняют качество изображения, максимизируя сжатие.',
    'landing.pricing.title': 'Простые Цены',
    'landing.pricing.free': 'Бесплатно',
    'landing.pricing.pro': 'Про',
    'landing.pricing.pro.price': '$9',
    'upgrade.button': 'Обновить до Pro - $9/месяц',
    'checkout.title': 'Обновить до Pro',
    'checkout.subtitle': 'Разблокируйте неограниченное сжатие за $9/месяц',
    'common.loading': 'Загрузка...',
    'compress.title': 'Компрессор Изображений',
    'compress.secure': 'Файлы обрабатываются безопасно',
    'compress.dropFiles': 'Перетащите изображения сюда или нажмите для просмотра',
    'compress.supportedFormats': 'Поддержка JPG, PNG, WebP, HEIC до 50МБ каждый',
    'compress.selectFiles': 'Выбрать Файлы',
    'compress.trySample': 'Попробовать Образец',
    'compress.batchProcessing': 'Пакетная Обработка',
    'compress.secureProcessing': 'Безопасная Обработка', 
    'compress.signUpFeatures': 'Зарегистрируйтесь и Получите Больше Функций',
    'compress.unlockFeatures': 'Разблокировать Все Функции',
    'compress.processingStatus': 'Обработка...',
    'compress.processingProgress': 'Обработка ({completed}/{total})',
    'compress.qualityPreset': 'Предустановка качества',
    'compress.qualityBest': 'Лучшее качество',
    'compress.qualityHigh': 'Высокое качество',
    'compress.qualityMedium': 'Среднее качество',
    'compress.qualitySmall': 'Маленький файл',
    'compress.qualityMinimum': 'Минимальное качество',
    'compress.outputFormat': 'Формат вывода',
    'compress.autoRecommended': 'Авто (Рекомендуется)',
    'compress.qualityLevel': 'Уровень качества',
    'compress.outputFormatLabel': 'Формат вывода',
    'compress.qualityLevelLabel': 'Уровень качества',
    'compress.format': 'Формат вывода',
    'compress.quality': 'Уровень качества',
    'compress.showAdvanced': 'Показать дополнительные настройки',
    'compress.hideAdvanced': 'Скрыть дополнительные настройки',
    'compress.professionalOptimization': 'Профессиональная оптимизация изображений',
    'compress.resizeImage': 'Изменить размер изображения',
    'compress.colorFilter': 'Цветовой фильтр',
    'compress.noFilter': 'Без фильтра',
    'compress.grayscale': 'Черно-белый',
    'compress.sepia': 'Сепия',
    'compress.vintage': 'Винтажный',
    
    // Home page features (Russian)
    'home.title': 'Профессиональное сжатие изображений',
    'home.subtitle': 'Сжимайте изображения до 90% меньше, сохраняя визуальное качество. Идеально для веб-оптимизации и хранения.',
    'home.batchProcessing': 'Пакетная обработка',
    'home.multipleFormats': 'Множественные форматы',
    'home.apiAccess': 'API доступ',
    'home.secureProcessing': 'Безопасная обработка',
    'home.feature1.title': 'Пакетная обработка',
    'home.feature1.desc': 'Обрабатывайте сотни изображений одновременно с нашей высокопроизводительной системой сжатия.',
    'home.feature2.title': 'Множественные форматы',
    'home.feature2.desc': 'Поддержка JPG, PNG, WebP, HEIC и многих других форматов с автоматическим преобразованием.',
    'home.feature3.title': 'API доступ',
    'home.feature3.desc': 'Интегрируйте сжатие в ваш рабочий процесс с нашим мощным REST API.',
    'home.feature4.title': 'Безопасная обработка',
    'home.feature4.desc': 'Все изображения обрабатываются локально и автоматически удаляются для максимальной безопасности.',
    
    // Educational Content - Russian
    'education.title': 'Полное Руководство по Сжатию Изображений',
    'education.subtitle': 'Изучите все о сжатии изображений, от основных концепций до продвинутых техник.',
    'education.technicalTitle': 'Техническое Погружение: Как Работает Сжатие Изображений',
    'education.lossyVsLossless': 'Сжатие с Потерями vs Без Потерь',
    'education.lossyDesc': 'Сжатие с потерями удаляет некоторые данные изображения для уменьшения размера файла.',
    'education.losslessDesc': 'Сжатие без потерь сохраняет все исходные данные изображения.',
    'education.whenToUse': 'Когда Использовать Каждый Тип',
    'education.lossyUse': 'С потерями: Фотографии, веб-изображения, социальные сети',
    'education.losslessUse': 'Без потерь: Логотипы, графика, медицинские изображения',
    'education.webpUse': 'WebP: Современные веб-сайты, поддерживающие продвинутое сжатие',
    'education.qualityBalance': 'Баланс Качества и Размера Файла',
    'education.balanceDesc': 'Поиск оптимального баланса между качеством изображения и размером файла критически важен для веб-производительности. Наш алгоритм сжатия анализирует каждое изображение для определения лучших настроек.',
    'education.highQuality': 'Высокое Качество (90-100%)',
    'education.balanced': 'Сбалансированное (70-85%)',
    'education.aggressive': 'Агрессивное (50-70%)',
    'education.largeFiles': 'Большие файлы',
    'education.optimalWeb': 'Оптимально для веб',
    'education.smallestFiles': 'Наименьшие файлы',
    'education.algorithmsTitle': 'Алгоритмы Сжатия',
    
    // Additional educational content keys (Russian)
    'education.guideTitle': 'Полное Руководство по Сжатию Изображений',
    'education.guideSubtitle': 'Изучите все, что нужно знать для оптимизации изображений для веб, мобильных устройств и печати.',
    'education.contentCreation': 'Создание Контента',
    'education.contentDesc': 'Подготовьте изображения для социальных сетей, блогов и маркетинговых материалов с оптимальными размерами файлов для каждой платформы.',
    'education.webDev': 'Веб-Разработка',
    'education.webDevDesc': 'Сократите время загрузки и улучшите Core Web Vitals для лучших SEO-рейтингов.',
    'education.ecommerce': 'Электронная Коммерция',
    'education.ecommerceDesc': 'Уменьшите размеры изображений товаров без потери качества для более быстрого оформления заказов и выших коэффициентов конверсии.',
    'education.mobileApps': 'Мобильные Приложения',
    'education.mobileDesc': 'Сократите размеры пакетов приложений с помощью оптимизированного сжатия изображений.',
    'education.compressionTitle': 'Почему Важно Сжатие Изображений',
    'education.compressionDesc': 'Сжатие изображений критически важно для современных веб-приложений, уменьшая использование полосы пропускания и время загрузки.',
    'education.performanceTitle': 'Преимущества Производительности',
    'education.performanceDesc': 'Правильно сжатые изображения улучшают скорость загрузки страниц и пользовательский опыт.',
    'education.fasterLoading': 'Быстрая Загрузка',
    'education.reducedBandwidth': 'Сниженное Использование Полосы Пропускания',
    'education.betterSeo': 'Лучшие SEO-Рейтинги',
    'education.bestPracticesTitle': 'Лучшие Практики Сжатия',
    'education.bestPracticesDesc': 'Следуйте этим проверенным практикам для оптимальных результатов при сохранении качества изображений.',
    'education.qualityRange': 'Используйте 80-85% качества для веб-изображений',
    'education.resizeFirst': 'Изменяйте размеры изображений до размеров отображения',
    'education.chooseFormat': 'Выберите подходящий формат для контента',
    'education.jpegBest': 'JPEG: Лучший для фотографий',
    'education.pngBest': 'PNG: Лучший для графики',
    'education.webpBest': 'WebP: Лучший для современных браузеров',
    
    // Missing landing page keys (Russian)
    'landing.readyToCompress': 'Готовы сжать ваши изображения?',
    'landing.trustMessage': 'Присоединяйтесь к тысячам профессионалов, которые доверяют CompressHub для своих потребностей в оптимизации изображений.',
    'landing.getStarted': 'Начать бесплатно',
    
    // Footer and Educational section missing keys
    'footer.description': 'Самая продвинутая платформа сжатия изображений для профессионалов и бизнеса.',
    'education.applicationsTitle': 'Применение в реальном мире',
    'education.applicationsDesc': 'Узнайте, как разные отрасли получают выгоду от профессиональных решений сжатия изображений.',
    'education.compressionTips': 'Советы по профессиональному сжатию изображений',
    'education.formatGuide': 'Руководство по сравнению форматов изображений',
    'education.qualityGuide': 'Руководство по качеству против размера файла',
    
    // Educational content keys that match compress page component (Russian)
    'education.tipsTitle': 'Советы по профессиональному сжатию изображений',
    'education.tip1Title': 'Выберите правильный формат',
    'education.tip1Desc': 'JPEG для фотографий, PNG для графики с прозрачностью, WebP для современных браузеров.',
    'education.tip2Title': 'Оптимизируйте настройки качества',
    'education.tip2Desc': 'Используйте качество 80-85% для веб-изображений для баланса размера файла и визуального качества.',
    'education.tip3Title': 'Изменяйте размер перед сжатием',
    'education.tip3Desc': 'Масштабируйте изображения до размера отображения перед сжатием для максимального уменьшения размера файла.',
    'education.tip4Title': 'Учитывайте вашу аудиторию',
    'education.tip4Desc': 'Большее сжатие для мобильных пользователей, умеренное для просмотра на рабочем столе.',
    'education.tip5Title': 'Тестируйте и сравнивайте',
    'education.tip5Desc': 'Всегда предварительно просматривайте сжатые изображения, чтобы убедиться, что качество соответствует вашим стандартам.',
    'education.tip6Title': 'Пакетная обработка',
    'education.tip6Desc': 'Загружайте несколько изображений одновременно для экономии времени и обеспечения согласованных настроек.',
    'education.formatComparisonTitle': 'Руководство по сравнению форматов изображений',
    'education.formatHeader': 'Формат',
    'education.bestForHeader': 'Лучше для',
    'education.compressionHeader': 'Сжатие',
    'education.transparencyHeader': 'Прозрачность',
    'education.jpegRow': 'Фотографии, сложные изображения',
    'education.excellentLossy': 'Отличное (с потерями)',
    'education.no': 'Нет',
    'education.pngRow': 'Графика, логотипы, скриншоты',
    'education.goodLossless': 'Хорошее (без потерь)',
    'education.yes': 'Да',
    'education.webpRow': 'Современные веб-приложения',
    'education.superior': 'Превосходное',
    'education.heifRow': 'Мобильная фотография',
    'education.excellent': 'Отличное',
    'education.limited': 'Ограниченная',
    'education.qualityGuideTitle': 'Руководство по качеству против размера файла',
    'education.highQualityTitle': 'Высокое качество (90-100%)',
    'education.balancedTitle': 'Сбалансированное (70-85%)', 
    'education.aggressiveTitle': 'Агрессивное (50-70%)',
    'education.highQualityBest': 'Лучше для: Печать, архив, профессиональная фотография',
    'education.highQualityTrade': 'Компромисс: Большие размеры файлов, медленная загрузка',
    'education.balancedBest': 'Лучше для: Веб-изображения, социальные сети, блоги',
    'education.balancedTrade': 'Компромисс: Хорошее качество, разумный размер',
    'education.aggressiveBest': 'Лучше для: Миниатюры, превью, мобильные',
    'education.aggressiveTrade': 'Компромисс: Меньшие файлы, некоторая потеря качества',
    'education.proTipDesc': 'Начните с качества 80% и регулируйте в зависимости от ваших конкретных потребностей. Большинство зрителей не заметят разницы, но ваш веб-сайт будет загружаться значительно быстрее.',
    
    // Ultimate Guide SEO Section (Russian)
    'education.ultimateGuideTitle': 'Полное Руководство по Сжатию Изображений 2025',
    'education.ultimateGuideDesc': 'Освойте искусство оптимизации изображений с нашим подробным руководством. Учитесь у экспертов индустрии и достигайте профессиональных результатов.',
    'education.jpegTitle': 'Сжатие JPEG',
    'education.jpegDesc': 'Освойте техники оптимизации JPEG для веба и печати. Изучите настройки качества, прогрессивное кодирование и оптимизацию цветового пространства.',
    'education.bestForPhotos': 'Лучше всего для фото',
    'education.pngTitle': 'Оптимизация PNG',
    'education.pngDesc': 'Продвинутые стратегии сжатия PNG для сохранения прозрачности. Оптимизация палитры и техники сжатия без потерь.',
    'education.bestForGraphics': 'Лучше всего для графики',
    'education.webpTitle': 'Конвертация WebP',
    'education.webpDesc': 'Формат WebP нового поколения для превосходных коэффициентов сжатия. Совместимость браузеров и стратегии резервных вариантов включены.',
    'education.bestForWeb': 'Лучше всего для веба',
    'education.bulkTitle': 'Массовая Обработка',
    'education.bulkDesc': 'Рабочие процессы пакетного сжатия корпоративного уровня. Интеграция API и автоматизированные конвейеры оптимизации для масштабирования.',
    'education.bestForEnterprise': 'Лучше всего для предприятий',
    
    // Professional compression tips content (Russian)
    'education.tip1.title': 'Выберите правильный формат',
    'education.tip1.desc': 'JPEG для фотографий, PNG для графики с прозрачностью, WebP для современных браузеров.',
    'education.tip2.title': 'Оптимизируйте настройки качества',
    'education.tip2.desc': 'Используйте качество 80-85% для веб-изображений для баланса размера файла и визуального качества.',
    'education.tip3.title': 'Изменяйте размер перед сжатием',
    'education.tip3.desc': 'Масштабируйте изображения до размера отображения перед сжатием для максимального уменьшения размера файла.',
    'education.tip4.title': 'Учитывайте вашу аудиторию',
    'education.tip4.desc': 'Большее сжатие для мобильных пользователей, умеренное для просмотра на рабочем столе.',
    'education.tip5.title': 'Тестируйте и сравнивайте',
    'education.tip5.desc': 'Всегда предварительно просматривайте сжатые изображения, чтобы убедиться, что качество соответствует вашим стандартам.',
    'education.tip6.title': 'Пакетная обработка',
    'education.tip6.desc': 'Загружайте несколько изображений одновременно для экономии времени и обеспечения согласованных настроек.',
    
    // Format comparison guide (Russian)
    'education.format.jpeg': 'Фотографии, сложные изображения',
    'education.format.png': 'Графика, логотипы, скриншоты',
    'education.format.webp': 'Современные веб-приложения',
    'education.format.heif': 'Мобильная фотография',
    'education.compression.excellent': 'Отличное (lossy)',
    'education.compression.good': 'Хорошее (lossless)',
    'education.compression.superior': 'Превосходное',
    'education.transparency.yes': 'Да',
    'education.transparency.no': 'Нет',
    

    
    // Upgrade/Pricing section (Russian)
    'upgrade.title': 'Обновить до Pro',
    'upgrade.desc': 'Разблокируйте неограниченные сжатия, большие файлы, пакетную обработку и приоритетную поддержку.',
    'upgrade.feature1': 'Неограниченные сжатия в день',
    'upgrade.feature2': 'Обработка файлов до 100МБ каждый',
    'upgrade.feature3': 'Пакетная загрузка до 100 файлов',
    'upgrade.feature4': 'Приоритетная скорость обработки',
    'upgrade.feature5': 'Расширенный доступ к API',
    'upgrade.feature6': 'Приоритетная поддержка 24/7',
    'pricing.unlimitedCompressions': 'Неограниченные сжатия в день',
    'pricing.filesUpTo100MB': 'Обработка файлов до 100МБ каждый',
    'pricing.batchUpload100': 'Пакетная загрузка до 100 файлов',
    'pricing.priorityProcessing': 'Приоритетная скорость обработки',
    'pricing.advancedApi': 'Расширенный доступ к API',
    'pricing.prioritySupport': 'Приоритетная поддержка 24/7',
    
    // Mobile optimization section (Russian)
    'pricing.optimizeIosAndroid': 'Оптимизация для iOS и Android',
    'pricing.multipleDensity': 'Поддержка множественной плотности',
    'pricing.fasterAppStore': 'Быстрое одобрение в App Store',

    // Login and Signup translations (Russian)
    'login.title': 'Добро пожаловать обратно',
    'login.subtitle': 'Войдите в свой аккаунт, чтобы продолжить',
    'login.formTitle': 'Войти',
    'login.email': 'Email',
    'login.emailPlaceholder': 'Введите ваш email',
    'login.password': 'Пароль',
    'login.passwordPlaceholder': 'Введите ваш пароль',
    'login.signingIn': 'Вход...',
    'login.signIn': 'Войти',
    'login.noAccount': 'Нет аккаунта?',
    'login.signUp': 'Зарегистрироваться',
    'login.backToHome': '← Вернуться на главную',
    'login.success.title': 'Вход выполнен',
    'login.success.message': 'Добро пожаловать в CompressHub!',
    'login.errors.emailInvalid': 'Недействительный email',
    'login.errors.passwordShort': 'Пароль должен содержать не менее 6 символов',
    'login.errors.failed': 'Вход не удался',
    'login.errors.generic': 'Произошла ошибка. Попробуйте снова.',
    
    'signup.title': 'Создать аккаунт',
    'signup.subtitle': 'Присоединяйтесь к CompressHub и начните оптимизировать ваши изображения',
    'signup.formTitle': 'Зарегистрироваться',
    'signup.firstName': 'Имя',
    'signup.lastName': 'Фамилия',
    'signup.email': 'Email',
    'signup.password': 'Пароль',
    'signup.confirmPassword': 'Подтвердить пароль',
    'signup.firstNamePlaceholder': 'Имя',
    'signup.lastNamePlaceholder': 'Фамилия',
    'signup.emailPlaceholder': 'email@пример.com',
    'signup.passwordPlaceholder': 'Минимум 6 символов',
    'signup.confirmPasswordPlaceholder': 'Подтвердите ваш пароль',
    'signup.creatingAccount': 'Создание аккаунта...',
    'signup.createAccount': 'Создать аккаунт',
    'signup.hasAccount': 'Уже есть аккаунт?',
    'signup.signIn': 'Войти',
    'signup.backToHome': '← Вернуться на главную',
    'signup.success.title': 'Аккаунт создан',
    'signup.success.message': 'Ваш аккаунт был успешно создан!',
    'signup.errors.firstNameShort': 'Имя должно содержать не менее 2 символов',
    'signup.errors.lastNameShort': 'Фамилия должна содержать не менее 2 символов',
    'signup.errors.emailInvalid': 'Недействительный email',
    'signup.errors.passwordShort': 'Пароль должен содержать не менее 6 символов',
    'signup.errors.passwordMismatch': 'Пароли не совпадают',
    'signup.errors.failed': 'Регистрация не удалась',
    'signup.errors.generic': 'Произошла ошибка. Попробуйте снова.',
    
    // Missing checkout/pricing keys for Russian
    'checkout.upgradeTitle': 'Обновиться до CompressHub Pro',
    'checkout.unlimitedFeatures': 'Разблокируйте неограниченное сжатие с профессиональными возможностями',
    'checkout.whatsIncluded': 'Что входит',
    'checkout.sslSecure': 'SSL Безопасность',
    'checkout.cancelAnytime': 'Отменить в любое время',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 от 2,000+ пользователей',
    'checkout.createAccountSubscribe': 'Создать аккаунт и подписаться',
    'checkout.joinThousands': 'Присоединяйтесь к тысячам создателей, использующих CompressHub Pro',
    'checkout.sslSecured': 'SSL Защищено',
    'checkout.pciCompliant': 'Соответствует PCI',
    'checkout.completeUpgrade': 'Завершите ваше обновление',
    'checkout.addPaymentMethod': 'Добавьте способ оплаты для разблокировки Pro возможностей',
    
    // Missing compress page radio button and interface translations (Russian)
    'compress.qualityBest': 'Лучшее качество',
    'compress.qualityHigh': 'Высокое качество',
    'compress.qualityMedium': 'Среднее качество',
    'compress.qualitySmall': 'Малый файл',
    'compress.qualityMinimum': 'Минимальный файл',
    'compress.resizeImage': 'Изменить размер изображения',
    'compress.colorFilter': 'Цветовой фильтр',
    'compress.noFilter': 'Без фильтра',
    'compress.grayscale': 'Черно-белый',
    'compress.sepia': 'Сепия',
    'compress.vintage': 'Винтаж',
    'compress.outputFormat': 'Выходной формат',
    'compress.batchProcessing': 'Пакетная обработка',
    'compress.multipleFormats': 'Множественные форматы',
    'compress.apiAccess': 'Доступ к API',
    'compress.secureProcessing': 'Безопасная обработка',
    'compress.signUpFeatures': 'Зарегистрироваться и получить больше функций',
    'compress.unlockFeatures': 'Разблокировать функции',
    
    // Compress page missing translations
    'compress.freeCompressionAvailable': 'Доступно бесплатное сжатие',
    'compress.getUnlimitedAccess': 'Получите неограниченный доступ',
    'compress.trackHistory': 'Отслеживать историю',
    'compress.viewStats': 'Просмотр статистики',
    'compress.fiftyFreeDaily': '50 бесплатных сжатий в день',
    'compress.premiumPlans': 'Премиум планы',
    'compress.createFreeAccount': 'Создать бесплатный аккаунт',
    
    // Pricing page missing translations (Russian)
    'pricing.proFeatures': 'Функции Pro',
    'pricing.unlimitedCompressions': 'Неограниченные сжатия',
    'pricing.filesUpTo100MB': 'Файлы до 100MB',
    'pricing.batchProcessing100': 'Пакетная обработка 100 файлов',
    'pricing.priorityProcessing': 'Приоритетная обработка',
    'pricing.apiAccess': 'Доступ к API',
    'pricing.prioritySupport': 'Приоритетная поддержка',
    
    // Enterprise pricing section missing translations (Russian)
    'pricing.enterpriseTitle': 'Корпоративные Решения Сжатия Изображений',
    'pricing.ecommerceTitle': 'Оптимизация Электронной Коммерции',
    'pricing.ecommerceDesc': 'Интернет-ритейлеры, использующие CompressHub Pro, сообщают о времени загрузки на 40% быстрее и коэффициентах конверсии на 25% выше. Изображения товаров загружаются мгновенно, уменьшая отказы от корзины и улучшая клиентский опыт.',
    'pricing.cmsTitle': 'Системы Управления Контентом',
    'pricing.cmsDesc': 'Издатели и блогеры экономят 60% расходов на хранение, улучшая SEO-рейтинги. Сжатые изображения загружаются быстрее, снижая показатели отказов и улучшая производительность поисковых систем.',
    'pricing.mobileDevTitle': 'Разработка Мобильных Приложений',
    'pricing.mobileDevDesc': 'Мобильные разработчики уменьшают размеры пакетов приложений до 75%, сохраняя визуальное качество. Меньшие приложения скачиваются быстрее и используют меньше памяти устройства.',
    
    // Pricing page educational content (Russian)
    'education.webPerfTitle': 'Стандарты Веб-Производительности',
    'education.webPerfDesc': '• Core Web Vitals: Метрики производительности Google напрямую влияют на SEO-рейтинги. Оптимизированные изображения улучшают показатели Largest Contentful Paint (LCP) до 40%.',
    'education.progressiveLoadingDesc': '• Прогрессивная Загрузка: Реализуйте прогрессивное кодирование JPEG для лучшей воспринимаемой производительности. Пользователи видят содержимое изображения во время загрузки.',
    'education.responsiveImagesDesc': '• Адаптивные Изображения: Используйте атрибуты srcset с несколькими размерами изображений для подходящих версий под разные размеры экрана и разрешения.',
    'education.lazyLoadingDesc': '• Ленивая Загрузка: Комбинируйте сжатие изображений с ленивой загрузкой для уменьшения времени первоначальной загрузки страницы и использования пропускной способности.',
    'education.mobileOptTitle': 'Стратегия Мобильной Оптимизации',
    'education.adaptiveQualityDesc': '• Адаптивное Качество: Подавайте изображения низкого качества пользователям на медленных соединениях, сохраняя высокое качество для быстрых сетей.',
    'education.formatSelectionDesc': '• Выбор Формата: Используйте WebP для поддерживаемых браузеров (95% покрытие) с JPEG fallback для старых браузеров.',
    'education.bandwidthAwarenessDesc': '• Осведомленность о Пропускной Способности: Учитывайте режимы экономии данных и реализуйте переключатели качества для мобильных пользователей с ограниченными тарифными планами.',
    'education.appBundleDesc': '• Оптимизация Пакета Приложения: Для мобильных приложений сжимайте пакетированные изображения для уменьшения размера загрузки и улучшения показателей одобрения в app store.',
    
    // Enterprise content translations (Russian)
    'education.enterpriseTitle': 'Корпоративные Решения Сжатия Изображений',
    'education.ecommerceOptTitle': 'Оптимизация Электронной Коммерции',
    'education.ecommerceOptDesc': 'Интернет-ритейлеры, использующие CompressHub Pro, сообщают о времени загрузки страниц на 40% быстрее и коэффициентах конверсии на 25% выше. Изображения товаров загружаются мгновенно, уменьшая отказы от корзины и улучшая клиентский опыт.',
    'education.batchProcess1000s': 'Пакетная обработка тысяч изображений товаров',
    'education.maintainQuality': 'Поддержание стабильного качества по всему каталогу',
    'education.optimizeMobile': 'Оптимизация для мобильных покупателей',
    'education.cmsTitle': 'Системы Управления Контентом',
    'education.cmsDesc': 'Издатели и блогеры экономят 60% на расходах на хранение, улучшая SEO-рейтинги. Сжатые изображения загружаются быстрее, снижая показатели отказов и улучшая производительность поисковых систем.',
    'education.apiIntegration': 'API интеграция с WordPress, Drupal',
    'education.autoCompression': 'Автоматическое сжатие при загрузке',
    'education.seoOptimized': 'SEO-оптимизированные размеры файлов',
    'education.mobileAppDev': 'Разработка Мобильных Приложений',
    'education.mobileDevDesc': 'Мобильные разработчики уменьшают размеры пакетов приложений до 75%, сохраняя визуальное качество. Меньшие приложения скачиваются быстрее и используют меньше памяти устройства.',
    'education.optimizeIosAndroid': 'Оптимизация для iOS и Android',
    'education.multipleDensity': 'Поддержка множественной плотности',
    'education.fasterAppStore': 'Более быстрое одобрение в app store',
    'education.roiTitle': 'Рассчитайте Вашу Окупаемость Инвестиций',
    'education.storageSavings': 'Экономия Хранилища',
    'education.storageSavingsDesc': 'Сократите расходы на хранение на 60-80% по всей вашей библиотеке изображений',
    'education.performanceGains': 'Прирост Производительности',
    'education.performanceGainsDesc': 'Улучшите скорость загрузки страниц и метрики пользовательского опыта',
    'education.conversionIncrease': 'Увеличение Конверсий',
    
    // Technical Specifications (Russian) - Using unique key names to avoid conflicts
    'education.techSpecsTitle': 'Технические Характеристики и Стандарты',
    'education.techSupportedFormats': 'Поддерживаемые Форматы и Алгоритмы',
    'education.techJpegOptimization': 'Оптимизация JPEG',
    'education.techJpegDesc': 'Прогрессивная кодировка JPEG, оптимизация таблицы Хаффмана, подвыборка цветности',
    'education.techPngCompression': 'Сжатие PNG',
    'education.techPngDesc': 'Оптимизация алгоритма DEFLATE, уменьшение палитры, сохранение альфа-канала',
    'education.techWebpModernFormat': 'Современный Формат WebP',
    'education.techWebpDesc': 'Кодировка VP8/VP9, режимы с потерями и без потерь, продвинутая альфа-прозрачность',
    'education.techHeifSupport': 'Поддержка HEIF/HEIC',
    'education.techHeifDesc': 'Высокоэффективная кодировка, поддержка HDR, оптимизация серийной съемки',
    'education.techEnterpriseFeatures': 'Корпоративные Функции',
    'education.techApiIntegration': 'Интеграция API',
    'education.techApiDesc': 'RESTful API, поддержка webhook, конечные точки пакетной обработки, обновления статуса в реальном времени',
    'education.techSecurityCompliance': 'Безопасность и Соответствие',
    'education.techSecurityDesc': 'SOC 2 Type II, соответствие GDPR, сквозное шифрование, автоматическое удаление файлов',
    'education.techPerformanceMonitoring': 'Мониторинг Производительности',
    'education.techMonitoringDesc': 'Аналитика в реальном времени, отслеживание коэффициента сжатия, отчеты экономии полосы пропускания',
    'education.techScaleReliability': 'Масштаб и Надежность',
    'education.techReliabilityDesc': 'SLA безотказности 99.9%, автомасштабируемая инфраструктура, интеграция глобального CDN',
    
    // ROI Calculator translations for checkout page (Russian)
    'education.savingsAmount': '$500/мес экономии',
    'education.savingsNote': '*На основе хранения изображений 10ТБ',
    'education.fasterLoadingPercent': '40% быстрая загрузка',
    'education.performanceNote': '*Среднее улучшение по сайтам',
    'education.conversionDesc': 'Более высокие коэффициенты конверсии от улучшенного пользовательского опыта',
    'education.conversionPercent': '+25% конверсии',
    'education.conversionNote': '*Среднее значение для клиентов электронной коммерции',
    
    // Enterprise feature translations (Russian)
    'pricing.batchProcess1000s': 'Пакетная обработка тысяч изображений продуктов',
    'pricing.maintainQuality': 'Поддержание стабильного качества в каталоге',
    'pricing.optimizeMobile': 'Оптимизация для мобильных покупателей',
    'pricing.apiIntegration': 'Интеграция API с WordPress, Drupal',
    'pricing.autoCompression': 'Автоматическое сжатие при загрузке',
    'pricing.seoOptimized': 'Размеры файлов, оптимизированные для SEO',
    'pricing.optimizeIosAndroid': 'Оптимизация для iOS и Android',
    'pricing.multipleDensity': 'Поддержка множественной плотности',
    'pricing.fasterAppStore': 'Более быстрое одобрение в app store',
    
    // Checkout page enterprise feature translations (Russian)
    'education.batchProcess': 'Пакетная обработка тысяч изображений продуктов',
    'education.consistentQuality': 'Поддержание стабильного качества в каталоге',
    
    // Additional missing checkout page translations (Russian)
    'education.supportedFormatsTitle': 'Поддерживаемые Форматы и Алгоритмы',
    'education.jpegOptTitle': 'Оптимизация JPEG',
    'education.jpegOptDesc': 'Прогрессивная кодировка JPEG, оптимизация таблицы Хаффмана, подвыборка цветности',
    'education.pngCompTitle': 'Сжатие PNG',
    'education.pngCompDesc': 'Оптимизация алгоритма DEFLATE, уменьшение палитры, сохранение альфа-канала',
    'education.webpFormatTitle': 'Современный Формат WebP',
    'education.webpFormatDesc': 'Кодировка VP8/VP9, режимы с потерями и без потерь, продвинутая альфа-прозрачность',
    'education.heifTitle': 'Поддержка HEIF/HEIC',
    'education.heifDesc': 'Высокоэффективная кодировка, поддержка HDR, оптимизация серийных фото',
    'education.enterpriseFeaturesTitle': 'Корпоративные Функции',
    'education.apiIntegrationTitle': 'Интеграция API',
    'education.apiIntegrationDesc': 'RESTful API, поддержка webhook, endpoints пакетной обработки, обновления статуса в реальном времени',
    'education.securityTitle': 'Безопасность и Соответствие',
    'education.securityDesc': 'SOC 2 Type II, соответствие GDPR, сквозное шифрование, автоматическое удаление файлов',
    'education.performanceMonitoringTitle': 'Мониторинг Производительности',
    'education.performanceMonitoringDesc': 'Аналитика в реальном времени, отслеживание коэффициента сжатия, отчеты экономии пропускной способности',
    'education.scaleTitle': 'Масштаб и Надежность',
    'education.scaleDesc': 'SLA безотказности 99.9%, автомасштабируемая инфраструктура, интеграция глобального CDN',
    
    // Industry Best Practices section (Russian)
    'education.industryBestTitle': 'Лучшие Отраслевые Практики Оптимизации Изображений',
    'education.webPerfTitle': 'Стандарты Веб-Производительности',
    'education.mobileOptTitle': 'Стратегия Мобильной Оптимизации',
    
    // Checkout page subscription section (Russian)
    'checkout.upgradeTitle': 'Обновить до CompressHub Pro',
    'checkout.unlimitedFeatures': 'Разблокируйте неограниченное сжатие с профессиональными функциями за $9/месяц',
    'checkout.sslSecure': 'SSL Безопасность',
    'checkout.sslSecured': 'SSL Защищено',
    'checkout.cancelAnytime': 'Отмена в Любое Время',
    'checkout.pciCompliant': 'Соответствие PCI',
    'checkout.rating': 'Рейтинг 4.9/5',
    'checkout.createAccountSubscribe': 'Создать Аккаунт и Подписаться',
    'checkout.joinThousands': 'Присоединяйтесь к тысячам создателей, использующих CompressHub Pro',
    'checkout.completeUpgrade': 'Завершите Ваше Обновление',
    'checkout.addPaymentMethod': 'Добавьте способ оплаты для разблокировки Pro функций',
    'checkout.firstName': 'Имя',
    'checkout.lastName': 'Фамилия',
    'checkout.email': 'Адрес электронной почты',
    'checkout.password': 'Пароль',
    'checkout.firstNamePlaceholder': 'Иван',
    'checkout.lastNamePlaceholder': 'Иванов',
    'checkout.emailPlaceholder': 'ivan@example.ru',
    'checkout.passwordPlaceholder': 'Создайте надежный пароль',
    'checkout.promoCode': 'Есть промокод?',
    'checkout.promoCodePlaceholder': 'Введите промокод',
    'checkout.securePayment': 'Безопасная оплата',
  },

  // Korean - Complete translations
  ko: {
    // Navigation
    'nav.home': '홈',
    'nav.compress': '압축',
    'nav.history': '기록',
    'nav.login': '로그인',
    'nav.signup': '회원가입',
    'nav.logout': '로그아웃',
    
    // Landing Page
    'landing.title': '전문적인 이미지 압축',
    'landing.subtitle': '시각적 품질을 유지하면서 이미지를 최대 90%까지 작게 압축하세요. 웹 최적화와 저장에 완벽합니다.',
    'landing.cta': '무료로 시작',
    'landing.features.title': '왜 CompressHub를 선택해야 할까요?',
    'landing.features.subtitle': '고급 알고리즘과 엔터프라이즈 기능을 갖춘 전문 수준의 이미지 압축.',
    'landing.feature1.title': '초고속',
    'landing.feature1.desc': '최적화된 압축 엔진으로 수백 개의 이미지를 몇 초 안에 처리하세요.',
    'landing.feature2.title': '시각적 품질',
    'landing.feature2.desc': '고급 알고리즘이 압축을 최대화하면서 이미지 품질을 보존합니다.',
    'landing.feature3.title': '개발자 API',
    'landing.feature3.desc': '강력한 REST API로 워크플로에 압축을 통합하세요.',
    'landing.feature4.title': '보안 처리',
    'landing.feature4.desc': '엔드투엔드 암호화로 이미지의 개인정보와 보안을 보장합니다.',
    'landing.getStarted': '무료로 시작',
    'landing.pricing.title': '간단한 가격',
    'landing.pricing.free': '무료',
    'landing.pricing.free.desc': '하루 50회 압축',
    'landing.pricing.pro': '프로',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': '무제한 압축',
    'landing.pricing.upgrade': '프로로 업그레이드',
    
    // Home Page
    'home.welcome': 'CompressHub에 오신 것을 환영합니다',
    'home.subtitle': '전문 이미지 압축 도구',
    'home.startCompressing': '압축 시작',
    
    // Compress Page
    'compress.title': '이미지 압축',
    'compress.dragDrop': '여기에 이미지를 끌어다 놓거나 클릭하여 찾아보기',
    'compress.selectFiles': '파일 선택',
    'compress.processing': '처리 중...',
    'compress.completed': '완료',
    'compress.download': '다운로드',
    'compress.downloadAll': '모두 다운로드',
    'compress.quality': '품질',
    'compress.format': '형식',
    'compress.stats.files': '개 파일 처리됨',
    'compress.stats.saved': '공간 절약',
    
    // Upgrade Card
    'upgrade.title': '프로로 업그레이드',
    'upgrade.desc': '무제한 압축, API 액세스, 우선 처리.',
    'upgrade.feature1': '무제한 압축',
    'upgrade.feature2': '배치당 최대 100개 파일',
    'upgrade.feature3': 'API 액세스 및 웹훅',
    'upgrade.button': '프로로 업그레이드 - $9/월',
    
    // Checkout
    'checkout.title': '프로로 업그레이드',
    'checkout.subtitle': '월 $9로 무제한 압축 잠금 해제',
    'checkout.features': '프리미엄 기능',
    'checkout.feature.unlimited': '무제한 사용',
    'checkout.feature.large': '100MB 파일',
    'checkout.feature.batch': '배치 처리',
    'checkout.feature.priority': '우선 속도',
    'checkout.firstName': '이름',
    'checkout.lastName': '성',
    'checkout.email': '이메일',
    'checkout.password': '비밀번호',
    'checkout.promoCode': '프로모 코드가 있으신가요?',
    'checkout.hidePromo': '프로모 코드 숨기기',
    'checkout.payment': '결제 정보',
    'checkout.startPro': '프로 시작 - $9/월',
    'checkout.subscribePro': '프로 구독 - $9/월',
    'checkout.perMonth': '월간 • 언제든지 취소',
    
    // Common
    'common.loading': '로딩 중...',
    'common.cancel': '취소',
    'common.save': '저장',
    'common.close': '닫기',
    'common.back': '뒤로',
    'common.next': '다음',
    'common.submit': '제출',
    'common.upload': '업로드',
    'common.download': '다운로드',
    
    // Educational Content - Korean
    'education.title': '이미지 압축 완벽 가이드',
    'education.subtitle': '기본 개념부터 고급 기술까지 이미지 압축에 대한 모든 것을 배우세요.',
    'education.technicalTitle': '기술적 심화: 이미지 압축 작동 원리',
    'education.lossyVsLossless': '손실 압축 vs 무손실 압축',
    'education.lossyDesc': '손실 압축은 파일 크기를 줄이기 위해 일부 이미지 데이터를 제거합니다.',
    'education.losslessDesc': '무손실 압축은 모든 원본 이미지 데이터를 보존합니다.',
    'education.whenToUse': '언제 각 유형을 사용할지',
    'education.lossyUse': '손실 압축: 사진, 웹 이미지, 소셜 미디어',
    'education.losslessUse': '무손실 압축: 로고, 그래픽, 의료 이미지',
    'education.webpUse': 'WebP: 고급 압축을 지원하는 현대적인 웹사이트',
    'education.qualityBalance': '품질 vs 파일 크기 균형',
    'education.balanceDesc': '이미지 품질과 파일 크기 간의 최적 균형을 찾는 것은 웹 성능에 중요합니다. 우리의 압축 알고리즘은 각 이미지를 분석하여 최상의 설정을 결정합니다.',
    'education.largeFiles': '큰 파일',
    'education.optimalWeb': '웹 최적',
    'education.smallestFiles': '가장 작은 파일',
    'education.algorithmsTitle': '압축 알고리즘',
    
    // Additional educational content keys (Korean)
    'education.guideTitle': '이미지 압축 완전 가이드',
    'education.guideSubtitle': '웹, 모바일, 인쇄용 이미지 최적화에 대해 알아야 할 모든 것을 배워보세요.',
    'education.contentCreation': '콘텐츠 제작',
    'education.contentDesc': '각 플랫폼에 최적화된 파일 크기로 소셜 미디어, 블로그, 마케팅 자료용 이미지를 준비하세요.',
    'education.webDev': '웹 개발',
    'education.webDevDesc': '로딩 시간을 줄이고 Core Web Vitals를 개선하여 더 나은 SEO 순위를 얻으세요.',
    'education.ecommerce': '전자상거래',
    'education.ecommerceDesc': '품질 손실 없이 제품 이미지 크기를 줄여 더 빠른 체크아웃과 높은 전환율을 달성하세요.',
    'education.mobileApps': '모바일 앱',
    'education.mobileDesc': '최적화된 이미지 압축을 통해 앱 번들 크기를 줄이세요.',
    'education.compressionTitle': '이미지 압축이 중요한 이유',
    'education.compressionDesc': '이미지 압축은 현대 웹 애플리케이션에 중요하며, 대역폭 사용량과 로딩 시간을 줄입니다.',
    'education.performanceTitle': '성능 이점',
    'education.performanceDesc': '적절히 압축된 이미지는 페이지 로딩 속도와 사용자 경험을 개선합니다.',
    'education.fasterLoading': '빠른 로딩',
    'education.reducedBandwidth': '대역폭 사용량 감소',
    'education.betterSeo': '더 나은 SEO 순위',
    'education.bestPracticesTitle': '압축 모범 사례',
    'education.bestPracticesDesc': '이미지 품질을 유지하면서 최적의 결과를 얻기 위해 검증된 관행을 따르세요.',
    'education.qualityRange': '웹 이미지에는 80-85% 품질 사용',
    'education.resizeFirst': '이미지를 표시 크기로 리사이즈',
    'education.chooseFormat': '콘텐츠에 적합한 형식 선택',
    'education.jpegBest': 'JPEG: 사진에 최적',
    'education.pngBest': 'PNG: 그래픽에 최적',
    'education.webpBest': 'WebP: 현대 브라우저에 최적',
    
    // Ultimate Guide SEO Section (Korean)
    'education.ultimateGuideTitle': '2025년 궁극의 이미지 압축 가이드',
    'education.ultimateGuideDesc': '포괄적인 가이드로 이미지 최적화 기술을 마스터하세요. 업계 전문가로부터 배우고 전문적인 결과를 달성하세요.',
    'education.jpegTitle': 'JPEG 압축',
    'education.jpegDesc': '웹과 인쇄용 JPEG 최적화 기술을 마스터하세요. 품질 설정, 프로그레시브 인코딩, 색상 공간 최적화를 학습합니다.',
    'education.bestForPhotos': '사진에 최적',
    'education.pngTitle': 'PNG 최적화',
    'education.pngDesc': '투명도 보존을 위한 고급 PNG 압축 전략. 팔레트 최적화 및 무손실 압축 기술.',
    'education.bestForGraphics': '그래픽에 최적',
    'education.webpTitle': 'WebP 변환',
    'education.webpDesc': '우수한 압축비를 제공하는 차세대 WebP 형식. 브라우저 호환성 및 폴백 전략이 포함됩니다.',
    'education.bestForWeb': '웹에 최적',
    'education.bulkTitle': '대량 처리',
    'education.bulkDesc': '엔터프라이즈급 배치 압축 워크플로우. 확장을 위한 API 통합 및 자동화된 최적화 파이프라인.',
    'education.bestForEnterprise': '기업에 최적',
    
    // Missing landing page keys (Korean)
    'landing.readyToCompress': '이미지를 압축할 준비가 되셨나요?',
    'landing.trustMessage': '이미지 최적화 요구사항을 위해 CompressHub를 신뢰하는 수천 명의 전문가들과 함께하세요.',
    
    // Enterprise pricing section missing translations (Korean)
    'pricing.enterpriseTitle': '기업용 이미지 압축 솔루션',
    'pricing.ecommerceTitle': '전자상거래 최적화',
    'pricing.ecommerceDesc': 'CompressHub Pro를 사용하는 온라인 소매업체들은 40% 빠른 로딩 시간과 25% 높은 전환율을 보고합니다. 제품 이미지가 즉시 로드되어 장바구니 이탈률을 줄이고 고객 경험을 개선합니다.',
    'pricing.batchProcess1000s': '수천 개의 제품 이미지를 일괄 처리',
    'pricing.maintainQuality': '전체 카탈로그에서 일관된 품질 유지',
    'pricing.optimizeMobile': '모바일 구매자를 위한 최적화',
    'pricing.cmsTitle': '콘텐츠 관리 시스템',
    'pricing.cmsDesc': '편집자와 블로거들은 저장소 비용을 60% 절약하면서 SEO 순위를 개선합니다. 압축된 이미지는 더 빠르게 로드되어 이탈률을 줄이고 검색 엔진 성능을 개선합니다.',
    'pricing.apiIntegration': 'WordPress, Drupal과 API 통합',
    'pricing.autoCompression': '업로드 시 자동 압축',
    'pricing.seoOptimized': 'SEO 최적화된 파일 크기',
    'pricing.mobileDevTitle': '모바일 앱 개발',
    'pricing.mobileDevDesc': '모바일 개발자들은 시각적 품질을 유지하면서 앱 번들 크기를 75%까지 줄입니다. 작은 앱은 더 빠르게 다운로드되고 더 적은 디바이스 저장소를 사용합니다.',
    'pricing.optimizeIosAndroid': 'iOS와 Android 최적화',
    'pricing.multipleDensity': '다중 밀도 지원',
    'pricing.fasterAppStore': '빠른 앱 스토어 승인',
    
    // Missing checkout/pricing keys for Korean
    'checkout.upgradeTitle': 'CompressHub Pro로 업그레이드',
    'checkout.unlimitedFeatures': '전문적인 기능으로 무제한 압축을 잠금 해제하세요',
    'checkout.whatsIncluded': '포함된 기능',
    'checkout.sslSecure': 'SSL 보안',
    'checkout.cancelAnytime': '언제든지 취소',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 (2,000+ 사용자)',
    'checkout.createAccountSubscribe': '계정 생성 및 구독',
    'checkout.joinThousands': 'CompressHub Pro를 사용하는 수천 명의 크리에이터와 함께하세요',
    'checkout.sslSecured': 'SSL 보안',
    'checkout.pciCompliant': 'PCI 준수',
    'checkout.completeUpgrade': '업그레이드 완료',
    'checkout.addPaymentMethod': 'Pro 기능을 잠금 해제하기 위해 결제 방법 추가',
    
    // Missing compress page radio button and interface translations (Korean)
    'compress.qualityBest': '최고 품질',
    'compress.qualityHigh': '고품질',
    'compress.qualityMedium': '중간 품질',
    'compress.qualitySmall': '작은 파일',
    'compress.qualityMinimum': '최소 파일',
    'compress.resizeImage': '이미지 크기 조정',
    'compress.colorFilter': '색상 필터',
    'compress.noFilter': '필터 없음',
    'compress.grayscale': '회색조',
    'compress.sepia': '세피아',
    'compress.vintage': '빈티지',
    'compress.outputFormat': '출력 형식',
    'compress.batchProcessing': '배치 처리',
    'compress.multipleFormats': '다중 형식',
    'compress.apiAccess': 'API 액세스',
    'compress.secureProcessing': '보안 처리',
    'compress.signUpFeatures': '가입하고 더 많은 기능 얻기',
    'compress.unlockFeatures': '기능 잠금 해제',
  },

  // Arabic - Complete translations
  ar: {
    // Ultimate Guide SEO Section (Arabic)
    'education.ultimateGuideTitle': 'الدليل النهائي لضغط الصور 2025',
    'education.ultimateGuideDesc': 'اتقن فن تحسين الصور من خلال دليلنا الشامل. تعلم من خبراء الصناعة واحصل على نتائج احترافية.',
    'education.jpegTitle': 'ضغط JPEG',
    'education.jpegDesc': 'اتقن تقنيات تحسين JPEG للويب والطباعة. تعلم إعدادات الجودة والترميز التدريجي وتحسين المساحة اللونية.',
    'education.bestForPhotos': 'الأفضل للصور',
    'education.pngTitle': 'تحسين PNG',
    'education.pngDesc': 'استراتيجيات ضغط PNG المتقدمة للحفاظ على الشفافية. تحسين اللوحة وتقنيات الضغط بدون فقدان.',
    'education.bestForGraphics': 'الأفضل للرسوميات',
    'education.webpTitle': 'تحويل WebP',
    'education.webpDesc': 'تنسيق WebP من الجيل التالي لنسب ضغط فائقة. يشمل توافق المتصفحات واستراتيجيات الاحتياط.',
    'education.bestForWeb': 'الأفضل للويب',
    'education.bulkTitle': 'المعالجة المجمعة',
    'education.bulkDesc': 'سير عمل ضغط المجموعات على مستوى المؤسسات. تكامل API وخطوط أنابيب التحسين الآلي للقابلية للتوسع.',
    'education.bestForEnterprise': 'الأفضل للمؤسسات',
    
    // Navigation
    'nav.home': 'الرئيسية',
    'nav.compress': 'ضغط',
    'nav.history': 'التاريخ',
    'nav.login': 'تسجيل الدخول',
    'nav.signup': 'إنشاء حساب',
    'nav.logout': 'تسجيل الخروج',
    
    // Landing Page
    'landing.title': 'ضغط الصور الاحترافي',
    'landing.subtitle': 'اضغط الصور حتى 90% أصغر مع الحفاظ على الجودة البصرية. مثالي لتحسين الويب والتخزين.',
    'landing.cta': 'ابدأ مجاناً',
    'landing.features.title': 'لماذا تختار CompressHub؟',
    'landing.features.subtitle': 'ضغط الصور بمستوى احترافي مع خوارزميات متقدمة وميزات للمؤسسات.',
    'landing.feature1.title': 'سرعة فائقة',
    'landing.feature1.desc': 'عالج مئات الصور في ثوانٍ بمحرك الضغط المحسن لدينا.',
    'landing.feature2.title': 'الجودة البصرية',
    'landing.feature2.desc': 'الخوارزميات المتقدمة تحافظ على جودة الصورة مع تعظيم الضغط.',
    'landing.feature3.title': 'واجهة برمجة التطبيقات للمطورين',
    'landing.feature3.desc': 'ادمج الضغط في سير عملك مع واجهة برمجة التطبيقات REST القوية.',
    'landing.feature4.title': 'معالجة آمنة',
    'landing.feature4.desc': 'التشفير من النهاية إلى النهاية يضمن بقاء صورك خاصة ومحمية.',
    'landing.getStarted': 'ابدأ مجاناً',
    'landing.pricing.title': 'أسعار بسيطة',
    'landing.pricing.free': 'مجاني',
    'landing.pricing.free.desc': '50 ضغطة يومياً',
    'landing.pricing.pro': 'برو',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': 'ضغط غير محدود',
    'landing.pricing.upgrade': 'الترقية إلى برو',
    
    // Home Page
    'home.welcome': 'مرحباً بك في CompressHub',
    'home.subtitle': 'أداة ضغط الصور الاحترافية',
    'home.startCompressing': 'ابدأ الضغط',
    
    // Compress Page
    'compress.title': 'ضغط الصور',
    'compress.unlockFeatures': 'فتح جميع الميزات',
    'compress.getUnlimitedAccess': 'احصل على وصول غير محدود لجميع الميزات',
    'compress.trackHistory': 'تتبع تاريخ الضغط الخاص بك',
    'compress.viewStats': 'عرض إحصائيات الضغط التفصيلية',
    'compress.fiftyFreeDaily': '50 ضغطة مجانية يومياً',
    'compress.premiumPlans': 'خطط متميزة متاحة',
    'compress.createFreeAccount': 'إنشاء حساب مجاني',
    'compress.dragDrop': 'اسحب صورك هنا أو انقر للتصفح',
    'compress.selectFiles': 'اختر الملفات',
    'compress.processing': 'جاري المعالجة...',
    'compress.completed': 'مكتمل',
    'compress.download': 'تحميل',
    'compress.downloadAll': 'تحميل الكل',
    'compress.quality': 'الجودة',
    'compress.format': 'التنسيق',
    'compress.stats.files': 'ملف تم معالجته',
    'compress.stats.saved': 'مساحة موفرة',
    'compress.batchProcessing': 'معالجة مجمعة',
    'compress.multipleFormats': 'تنسيقات متعددة',
    'compress.apiAccess': 'الوصول للواجهة البرمجية',
    'compress.secureProcessing': 'معالجة آمنة',
    'compress.signUpFeatures': 'سجل واحصل على المزيد من الميزات',
    'compress.freeCompressionAvailable': 'ضغط مجاني متاح - لا يتطلب تسجيل',
    'compress.professionalOptimization': 'تحسين الصور الاحترافي',
    'compress.filesProcessedSecurely': 'تتم معالجة الملفات بأمان',
    'compress.noFileChosen': 'لم يتم اختيار ملف',
    'compress.dropImagesHere': 'اسحب الصور هنا أو انقر للتصفح',
    'compress.supportFormats': 'يدعم JPG, PNG, WebP, HEIC حتى 50 ميجابايت لكل ملف',
    'compress.trySampleFile': 'جرب ملف عينة',
    'compress.qualityPreset': 'إعداد الجودة المسبق',
    'compress.bestQuality': 'أفضل جودة',
    'compress.highQuality': 'جودة عالية',
    'compress.mediumQuality': 'جودة متوسطة',
    'compress.smallFile': 'ملف صغير',
    'compress.smallestFile': 'أصغر ملف',
    'compress.autoRecommended': 'تلقائي (موصى به)',
    'compress.qualityPercent': 'الجودة (85%)',
    'compress.best': 'الأفضل',
    'compress.showAdvancedOptions': 'إظهار الخيارات المتقدمة',
    'compress.hideAdvancedOptions': 'إخفاء الخيارات المتقدمة',
    
    // Upgrade Card
    'upgrade.title': 'الترقية إلى برو',
    'upgrade.desc': 'ضغط غير محدود، وصول للواجهة البرمجية، ومعالجة بأولوية.',
    'upgrade.feature1': 'ضغط غير محدود',
    'upgrade.feature2': 'معالجة دفعية حتى 100 ملف',
    'upgrade.feature3': 'وصول للواجهة البرمجية والويب هوك',
    'upgrade.feature4': 'سرعة معالجة ذات أولوية',
    'upgrade.feature5': 'وصول متقدم للواجهة البرمجية',
    'upgrade.feature6': 'دعم ذو أولوية على مدار الساعة',
    'upgrade.button': 'الترقية إلى برو - $9/شهر',
    
    // Checkout & Pricing Page
    'checkout.title': 'الترقية إلى برو',
    'checkout.subtitle': 'افتح الضغط غير المحدود مقابل $9/شهر',
    'checkout.features': 'الميزات المميزة',
    'checkout.feature.unlimited': 'استخدام غير محدود',
    'checkout.feature.large': 'ملفات 100 ميجابايت',
    'checkout.feature.batch': 'معالجة دفعية',
    'checkout.feature.priority': 'سرعة بأولوية',
    'checkout.firstName': 'الاسم الأول',
    'checkout.lastName': 'اسم العائلة',
    'checkout.email': 'البريد الإلكتروني',
    'checkout.password': 'كلمة المرور',
    'checkout.promoCode': 'هل لديك رمز ترويجي؟',
    'checkout.hidePromo': 'إخفاء الرمز الترويجي',
    'checkout.payment': 'معلومات الدفع',
    'checkout.startPro': 'ابدأ برو - $9/شهر',
    'checkout.subscribePro': 'اشترك في برو - $9/شهر',
    'checkout.perMonth': 'شهرياً • إلغاء في أي وقت',
    'checkout.upgradeTitle': 'ترقية إلى CompressHub Pro',
    'checkout.unlimitedFeatures': 'افتح الضغط غير المحدود مع الميزات الاحترافية',
    'checkout.whatsIncluded': 'ما هو مشمول',
    'checkout.sslSecure': 'حماية SSL',
    'checkout.cancelAnytime': 'الإلغاء في أي وقت',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 من أكثر من 2000 مستخدم',
    'checkout.createAccountSubscribe': 'إنشاء حساب والاشتراك',
    'checkout.joinThousands': 'انضم إلى الآلاف من المبدعين الذين يستخدمون CompressHub Pro',
    'checkout.sslSecured': 'حماية SSL',
    'checkout.pciCompliant': 'متوافق مع PCI',
    'checkout.completeUpgrade': 'أكمل ترقيتك',
    'checkout.addPaymentMethod': 'أضف طريقة دفع لفتح ميزات Pro',
    
    // Pricing page sections
    'pricing.upgradeTitle': 'الترقية إلى CompressHub Pro',
    'pricing.unlimitedFeatures': 'افتح الضغط غير المحدود مع الميزات الاحترافية مقابل $9/شهر',
    'pricing.sslSecure': 'حماية SSL',
    'pricing.cancelAnytime': 'الإلغاء في أي وقت',
    'pricing.rating': 'تقييم 4.9/5',
    'pricing.proFeatures': 'ميزات برو',
    'pricing.unlimitedCompressions': 'ضغط غير محدود',
    'pricing.filesUpTo100MB': 'ملفات حتى 100 ميجابايت',
    'pricing.batchProcessing100': 'معالجة دفعية (100 ملف)',
    'pricing.priorityProcessing': 'معالجة ذات أولوية',
    'pricing.apiAccess': 'وصول API',
    'pricing.prioritySupport': 'دعم ذي أولوية',
    'pricing.createAccountSubscribe': 'إنشاء حساب والاشتراك',
    'pricing.joinThousands': 'انضم إلى آلاف المبدعين الذين يستخدمون CompressHub Pro',
    'pricing.sslSecured': 'حماية SSL',
    'pricing.pciCompliant': 'متوافق مع PCI',
    
    // Enterprise sections
    'pricing.enterpriseTitle': 'حلول ضغط الصور للمؤسسات',
    'pricing.ecommerceTitle': 'تحسين التجارة الإلكترونية',
    'pricing.ecommerceDesc': 'تجار التجزئة الذين يستخدمون CompressHub Pro يحققون أوقات تحميل أسرع بنسبة 40% ومعدلات تحويل أعلى بنسبة 25%. صور المنتجات تحمل فوراً، مما يقلل من ترك العربة ويحسن تجربة العملاء.',
    'pricing.batchProcess1000s': 'معالجة دفعية لآلاف صور المنتجات',
    'pricing.maintainQuality': 'الحفاظ على جودة متسقة عبر الكتالوج',
    'pricing.optimizeMobile': 'تحسين للمتسوقين على الهاتف المحمول',
    'pricing.cmsTitle': 'أنظمة إدارة المحتوى',
    'pricing.cmsDesc': 'الناشرون والمدونون يوفرون 60% من تكاليف التخزين مع تحسين تصنيفات SEO. الصور المضغوطة تحمل بشكل أسرع، مما يقلل معدلات الارتداد ويحسن أداء محركات البحث.',
    'pricing.apiIntegration': 'تكامل API مع WordPress، Drupal',
    'pricing.autoCompression': 'ضغط تلقائي عند الرفع',
    'pricing.seoOptimized': 'أحجام ملفات محسنة لـ SEO',
    'pricing.mobileDevTitle': 'تطوير تطبيقات الهاتف المحمول',
    'pricing.mobileDevDesc': 'مطورو الهاتف المحمول يقللون أحجام حزم التطبيقات بنسبة تصل إلى 75% مع الحفاظ على الجودة البصرية. التطبيقات الأصغر تنزل بشكل أسرع وتستخدم مساحة تخزين أقل على الجهاز.',
    'pricing.optimizeIosAndroid': 'تحسين لـ iOS و Android',
    'pricing.multipleDensity': 'دعم كثافات متعددة',
    'pricing.fasterAppStore': 'موافقة أسرع من متجر التطبيقات',

    
    // Common
    'common.loading': 'جاري التحميل...',
    'common.cancel': 'إلغاء',
    'common.save': 'حفظ',
    'common.close': 'إغلاق',
    'common.back': 'رجوع',
    'common.next': 'التالي',
    'common.submit': 'إرسال',
    'common.upload': 'رفع',
    'common.download': 'تحميل',
    
    // Educational Content - Arabic
    'education.title': 'دليل شامل لضغط الصور',
    'education.subtitle': 'تعلم كل شيء عن ضغط الصور، من المفاهيم الأساسية إلى التقنيات المتقدمة.',
    'education.technicalTitle': 'غوص تقني: كيف يعمل ضغط الصور',
    'education.lossyVsLossless': 'الضغط مع الفقدان مقابل بدون فقدان',
    'education.lossyDesc': 'الضغط مع الفقدان يزيل بعض بيانات الصورة لتقليل حجم الملف.',
    'education.losslessDesc': 'الضغط بدون فقدان يحافظ على جميع بيانات الصورة الأصلية.',
    'education.whenToUse': 'متى تستخدم كل نوع',
    'education.lossyUse': 'مع الفقدان: الصور الفوتوغرافية، صور الويب، وسائل التواصل',
    'education.losslessUse': 'بدون فقدان: الشعارات، الرسوميات، الصور الطبية',
    'education.webpUse': 'WebP: المواقع الحديثة التي تدعم الضغط المتقدم',
    'education.qualityBalance': 'توازن الجودة مقابل حجم الملف',
    'education.balanceDesc': 'العثور على التوازن الأمثل بين جودة الصورة وحجم الملف أمر بالغ الأهمية لأداء الويب. خوارزمية الضغط لدينا تحلل كل صورة لتحديد أفضل الإعدادات.',
    'education.largeFiles': 'ملفات كبيرة',
    'education.optimalWeb': 'مثالي للويب',
    'education.smallestFiles': 'أصغر ملفات',
    'education.algorithmsTitle': 'خوارزميات الضغط',
    
    // Additional educational content keys (Arabic)
    'education.guideTitle': 'دليل شامل لضغط الصور',
    'education.guideSubtitle': 'تعلم كل ما تحتاج لمعرفته لتحسين صورك للويب والهاتف المحمول والطباعة.',
    'education.contentCreation': 'إنشاء المحتوى',
    'education.contentDesc': 'جهز الصور لوسائل التواصل الاجتماعي والمدونات والمواد التسويقية بأحجام ملفات مثالية لكل منصة.',
    'education.webDev': 'تطوير الويب',
    'education.webDevDesc': 'قلل أوقات التحميل وحسن Core Web Vitals للحصول على ترتيب أفضل في محركات البحث.',
    'education.ecommerce': 'التجارة الإلكترونية',
    'education.ecommerceDesc': 'قلل أحجام صور المنتجات دون فقدان الجودة للحصول على دفع أسرع ومعدلات تحويل أعلى.',
    'education.mobileApps': 'تطبيقات الهاتف المحمول',
    'education.mobileDesc': 'قلل أحجام حزم التطبيقات من خلال ضغط الصور المحسن.',
    'education.compressionTitle': 'لماذا ضغط الصور مهم',
    'education.compressionDesc': 'ضغط الصور أمر بالغ الأهمية لتطبيقات الويب الحديثة، مما يقلل من استخدام النطاق الترددي وأوقات التحميل.',
    'education.performanceTitle': 'فوائد الأداء',
    'education.performanceDesc': 'الصور المضغوطة بشكل صحيح تحسن سرعة تحميل الصفحات وتجربة المستخدم.',
    'education.fasterLoading': 'تحميل أسرع',
    'education.reducedBandwidth': 'انخفاض استخدام النطاق الترددي',
    'education.betterSeo': 'ترتيب أفضل في محركات البحث',
    'education.bestPracticesTitle': 'أفضل الممارسات',
    'education.bestPracticesDesc': 'اتبع هذه المبادئ التوجيهية للحصول على أفضل النتائج.',
    'education.qualityRange': 'استخدم جودة 80-85% للصور المعدة للويب',
    'education.resizeFirst': 'قم بتغيير حجم الصور قبل الضغط',
    'education.chooseFormat': 'اختر التنسيق المناسب لحالة الاستخدام',
    'education.jpegBest': 'JPEG أفضل للصور الفوتوغرافية',
    'education.pngBest': 'PNG أفضل للرسوميات والشعارات',
    'education.webpBest': 'WebP أفضل للمواقع الحديثة',
    
    // Professional Image Compression Tips (Arabic)
    'education.tipsTitle': 'نصائح ضغط الصور الاحترافية',
    'education.tip1Title': 'اختر التنسيق الصحيح',
    'education.tip1Desc': 'JPEG للصور، PNG للرسوميات مع الشفافية، WebP للمتصفحات الحديثة.',
    'education.tip2Title': 'تحسين إعدادات الجودة',
    'education.tip2Desc': 'استخدم جودة 80-85% لصور الويب لتوازن حجم الملف والجودة البصرية.',
    'education.tip3Title': 'تغيير الحجم قبل الضغط',
    'education.tip3Desc': 'قم بتحجيم الصور إلى حجم العرض قبل الضغط لتقليل حجم الملف إلى أقصى حد.',
    'education.tip4Title': 'اعتبر جمهورك',
    'education.tip4Desc': 'ضغط أعلى لمستخدمي الهاتف المحمول، ضغط معتدل لعرض سطح المكتب.',
    'education.tip5Title': 'اختبر وقارن',
    'education.tip5Desc': 'قم دائماً بمعاينة الصور المضغوطة للتأكد من أن الجودة تلبي معاييرك.',
    'education.tip6Title': 'المعالجة المجمعة',
    'education.tip6Desc': 'ارفع عدة صور في المرة الواحدة لتوفير الوقت وضمان الإعدادات المتسقة.',
    
    // Format Comparison Guide (Arabic)
    'education.formatComparisonTitle': 'دليل مقارنة تنسيقات الصور',
    'education.formatHeader': 'التنسيق',
    'education.bestForHeader': 'الأفضل لـ',
    'education.compressionHeader': 'الضغط',
    'education.transparencyHeader': 'الشفافية',
    'education.jpegPhotographs': 'الصور الفوتوغرافية، الصور المعقدة',
    'education.jpegExcellent': 'ممتاز (مع فقدان)',
    'education.jpegNo': 'لا',
    'education.pngGraphics': 'الرسوميات، الشعارات، لقطات الشاشة',
    'education.pngGood': 'جيد (بدون فقدان)',
    'education.pngYes': 'نعم',
    'education.webpModern': 'تطبيقات الويب الحديثة',
    'education.webpSuperior': 'متفوق',
    'education.webpYes': 'نعم',
    'education.heifMobile': 'التصوير بالهاتف المحمول',
    'education.heifExcellent': 'ممتاز',
    'education.heifYes': 'نعم',
    
    // Quality vs File Size Guide (Arabic)
    'education.qualityGuideTitle': 'دليل الجودة مقابل حجم الملف',
    'education.highQualityTitle': 'جودة عالية',
    'education.highQuality': 'الأفضل لـ: الطباعة، الأرشفة، التصوير الاحترافي\n\nالمقايضة: أحجام ملفات كبيرة، تحميل أبطأ',
    'education.balancedTitle': 'جودة متوازنة',
    'education.balanced': 'الأفضل لـ: صور الويب، وسائل التواصل الاجتماعي، المدونات\n\nالمقايضة: جودة جيدة، حجم ملف معقول',
    'education.aggressiveTitle': 'ضغط قوي',
    'education.aggressive': 'الأفضل لـ: المصغرات، المعاينات، الهاتف المحمول\n\nالمقايضة: ملفات أصغر، بعض فقدان الجودة',
    
    // Pro Tip (Arabic)
    'education.proTip': 'نصيحة احترافية',
    'education.proTipDesc': 'ابدأ بجودة 80% واضبط حسب احتياجاتك المحددة. معظم المشاهدين لن يلاحظوا الفرق، لكن موقعك سيحمل بشكل أسرع بكثير.',

    
    // Missing landing page keys (Arabic)
    'landing.readyToCompress': 'هل أنت مستعد لضغط صورك؟',
    'landing.trustMessage': 'انضم إلى آلاف المحترفين الذين يثقون في CompressHub لاحتياجات تحسين الصور الخاصة بهم.',
  },

  // Hindi - Complete translations
  hi: {
    // Navigation
    'nav.home': 'मुख्य',
    'nav.compress': 'संपीड़ित करें',
    'nav.history': 'इतिहास',
    'nav.login': 'लॉग इन',
    'nav.signup': 'साइन अप',
    'nav.logout': 'लॉग आउट',
    
    // Ultimate Guide SEO Section (Hindi)
    'education.ultimateGuideTitle': '2025 की परम छवि संपीड़न गाइड',
    'education.ultimateGuideDesc': 'हमारी व्यापक गाइड के साथ छवि अनुकूलन की कला में महारत हासिल करें। उद्योग विशेषज्ञों से सीखें और पेशेवर परिणाम प्राप्त करें।',
    'education.jpegTitle': 'JPEG संपीड़न',
    'education.jpegDesc': 'वेब और प्रिंट के लिए JPEG अनुकूलन तकनीकों में महारत हासिल करें। गुणवत्ता सेटिंग्स, प्रगतिशील एन्कोडिंग और रंग स्थान अनुकूलन सीखें।',
    'education.bestForPhotos': 'फोटो के लिए सर्वोत्तम',
    'education.pngTitle': 'PNG अनुकूलन',
    'education.pngDesc': 'पारदर्शिता संरक्षण के लिए उन्नत PNG संपीड़न रणनीतियां। पैलेट अनुकूलन और हानिरहित संपीड़न तकनीकें।',
    'education.bestForGraphics': 'ग्राफिक्स के लिए सर्वोत्तम',
    'education.webpTitle': 'WebP रूपांतरण',
    'education.webpDesc': 'बेहतर संपीड़न अनुपात के लिए अगली पीढ़ी का WebP प्रारूप। ब्राउज़र संगतता और फॉलबैक रणनीतियां शामिल हैं।',
    'education.bestForWeb': 'वेब के लिए सर्वोत्तम',
    'education.bulkTitle': 'बल्क प्रोसेसिंग',
    'education.bulkDesc': 'एंटरप्राइज़-ग्रेड बैच संपीड़न वर्कफ़्लो। स्केलेबिलिटी के लिए API एकीकरण और स्वचालित अनुकूलन पाइपलाइन।',
    'education.bestForEnterprise': 'एंटरप्राइज़ के लिए सर्वोत्तम',
    
    // Landing Page
    'landing.title': 'व्यावसायिक छवि संपीड़न',
    'landing.subtitle': 'दृश्य गुणवत्ता बनाए रखते हुए छवियों को 90% तक छोटा करें। वेब अनुकूलन और भंडारण के लिए आदर्श।',
    'landing.cta': 'मुफ्त शुरू करें',
    'landing.features.title': 'CompressHub क्यों चुनें?',
    'landing.features.subtitle': 'उन्नत एल्गोरिदम और एंटरप्राइज़ सुविधाओं के साथ व्यावसायिक स्तर की छवि संपीड़न।',
    'landing.feature1.title': 'अति तीव्र',
    'landing.feature1.desc': 'हमारे अनुकूलित संपीड़न इंजन के साथ सेकंडों में सैकड़ों छवियों को प्रोसेस करें।',
    'landing.feature2.title': 'दृश्य गुणवत्ता',
    'landing.feature2.desc': 'उन्नत एल्गोरिदम संपीड़न को अधिकतम करते हुए छवि गुणवत्ता को संरक्षित करते हैं।',
    'landing.feature3.title': 'डेवलपर API',
    'landing.feature3.desc': 'शक्तिशाली REST API के साथ अपने वर्कफ़्लो में संपीड़न को एकीकृत करें।',
    'landing.feature4.title': 'सुरक्षित प्रसंस्करण',
    'landing.feature4.desc': 'एंड-टू-एंड एन्क्रिप्शन सुनिश्चित करता है कि आपकी छवियां निजी और सुरक्षित रहें।',
    'landing.getStarted': 'मुफ्त शुरू करें',
    'landing.pricing.title': 'सरल मूल्य निर्धारण',
    'landing.pricing.free': 'मुफ्त',
    'landing.pricing.free.desc': 'दैनिक 50 संपीड़न',
    'landing.pricing.pro': 'प्रो',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': 'असीमित संपीड़न',
    'landing.pricing.upgrade': 'प्रो में अपग्रेड करें',
    
    // Home Page
    'home.welcome': 'CompressHub में आपका स्वागत है',
    'home.subtitle': 'आपका व्यावसायिक छवि संपीड़न उपकरण',
    'home.startCompressing': 'संपीड़न शुरू करें',
    
    // Compress Page
    'compress.title': 'छवि संपीड़न',
    'compress.dragDrop': 'अपनी छवियों को यहां खींचें या ब्राउज़ करने के लिए क्लिक करें',
    'compress.selectFiles': 'फाइलें चुनें',
    'compress.processing': 'प्रसंस्करण...',
    'compress.completed': 'पूर्ण',
    'compress.download': 'डाउनलोड',
    'compress.downloadAll': 'सभी डाउनलोड करें',
    'compress.quality': 'गुणवत्ता',
    'compress.format': 'प्रारूप',
    'compress.stats.files': 'फाइलें प्रसंस्कृत',
    'compress.stats.saved': 'स्थान बचाया गया',
    
    // Upgrade Card
    'upgrade.title': 'प्रो में अपग्रेड करें',
    'upgrade.desc': 'असीमित संपीड़न, API पहुंच, और प्राथमिकता प्रसंस्करण।',
    'upgrade.feature1': 'असीमित संपीड़न',
    'upgrade.feature2': 'बैच में 100 फाइलों तक',
    'upgrade.feature3': 'API पहुंच और वेबहुक',
    'upgrade.button': 'प्रो में अपग्रेड - $9/महीना',
    
    // Checkout
    'checkout.title': 'प्रो में अपग्रेड करें',
    'checkout.subtitle': '$9/महीने में असीमित संपीड़न अनलॉक करें',
    'checkout.features': 'प्रीमियम सुविधाएं',
    'checkout.feature.unlimited': 'असीमित उपयोग',
    'checkout.feature.large': '100MB फाइलें',
    'checkout.feature.batch': 'बैच प्रसंस्करण',
    'checkout.feature.priority': 'प्राथमिकता गति',
    'checkout.firstName': 'पहला नाम',
    'checkout.lastName': 'अंतिम नाम',
    'checkout.email': 'ईमेल',
    'checkout.password': 'पासवर्ड',
    'checkout.promoCode': 'क्या आपके पास प्रोमो कोड है?',
    'checkout.hidePromo': 'प्रोमो कोड छुपाएं',
    'checkout.payment': 'भुगतान जानकारी',
    'checkout.startPro': 'प्रो शुरू करें - $9/महीना',
    'checkout.subscribePro': 'प्रो की सदस्यता लें - $9/महीना',
    'checkout.perMonth': 'मासिक • कभी भी रद्द करें',
    'checkout.upgradeTitle': 'CompressHub Pro में अपग्रेड करें',
    'checkout.unlimitedFeatures': 'असीमित संपीड़न को पेशेवर सुविधाओं के साथ अनलॉक करें',
    'checkout.whatsIncluded': 'क्या शामिल है',
    'checkout.sslSecure': 'SSL सुरक्षित',
    'checkout.cancelAnytime': 'कभी भी रद्द करें',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4.9/5 2,000+ उपयोगकर्ताओं से',
    'checkout.createAccountSubscribe': 'खाता बनाएं और सब्सक्राइब करें',
    'checkout.joinThousands': 'CompressHub Pro का उपयोग करने वाले हजारों निर्माताओं से जुड़ें',
    'checkout.sslSecured': 'SSL सुरक्षित',
    'checkout.pciCompliant': 'PCI अनुपालित',
    'checkout.completeUpgrade': 'अपना अपग्रेड पूरा करें',
    'checkout.addPaymentMethod': 'Pro सुविधाओं को अनलॉक करने के लिए भुगतान विधि जोड़ें',
    
    // Common
    'common.loading': 'लोड हो रहा है...',
    'common.cancel': 'रद्द करें',
    'common.save': 'सहेजें',
    'common.close': 'बंद करें',
    'common.back': 'वापस',
    'common.next': 'अगला',
    'common.submit': 'जमा करें',
    'common.upload': 'अपलोड',
    'common.download': 'डाउनलोड',
    
    // Educational Content - Hindi
    'education.title': 'छवि संपीड़न की संपूर्ण गाइड',
    'education.subtitle': 'बुनियादी अवधारणाओं से लेकर उन्नत तकनीकों तक छवि संपीड़न के बारे में सब कुछ सीखें।',
    'education.technicalTitle': 'तकनीकी गहराई: छवि संपीड़न कैसे काम करता है',
    'education.lossyVsLossless': 'हानिकारक बनाम हानिरहित संपीड़न',
    'education.lossyDesc': 'हानिकारक संपीड़न फ़ाइल आकार कम करने के लिए कुछ छवि डेटा को हटा देता है।',
    'education.losslessDesc': 'हानिरहित संपीड़न सभी मूल छवि डेटा को संरक्षित करता है।',
    'education.whenToUse': 'प्रत्येक प्रकार का उपयोग कब करें',
    'education.lossyUse': 'हानिकारक: तस्वीरें, वेब छवियां, सामाजिक मीडिया',
    'education.losslessUse': 'हानिरहित: लोगो, ग्राफिक्स, चिकित्सा छवियां',
    'education.webpUse': 'WebP: उन्नत संपीड़न का समर्थन करने वाली आधुनिक वेबसाइटें',
    'education.qualityBalance': 'गुणवत्ता बनाम फ़ाइल आकार संतुलन',
    'education.balanceDesc': 'छवि गुणवत्ता और फ़ाइल आकार के बीच इष्टतम संतुलन खोजना वेब प्रदर्शन के लिए महत्वपूर्ण है। हमारा संपीड़न एल्गोरिदम सर्वोत्तम सेटिंग्स निर्धारित करने के लिए प्रत्येक छवि का विश्लेषण करता है।',
    'education.largeFiles': 'बड़ी फाइलें',
    'education.optimalWeb': 'वेब के लिए इष्टतम',
    'education.smallestFiles': 'सबसे छोटी फाइलें',
    'education.algorithmsTitle': 'संपीड़न एल्गोरिदम',
    
    // Additional educational content keys (Hindi)
    'education.guideTitle': 'इमेज कम्प्रेशन की संपूर्ण गाइड',
    'education.guideSubtitle': 'वेब, मोबाइल और प्रिंट के लिए अपनी इमेज को ऑप्टिमाइज़ करने के लिए जो कुछ भी जानना चाहिए, वह सब सीखें।',
    'education.contentCreation': 'कंटेंट क्रिएशन',
    'education.contentDesc': 'हर प्लेटफॉर्म के लिए ऑप्टिमल फाइल साइज़ के साथ सोशल मीडिया, ब्लॉग और मार्केटिंग मटेरियल के लिए इमेज तैयार करें।',
    'education.webDev': 'वेब डेवलपमेंट',
    'education.webDevDesc': 'लोडिंग टाइम कम करें और बेहतर SEO रैंकिंग के लिए Core Web Vitals में सुधार करें।',
    'education.ecommerce': 'ई-कॉमर्स',
    'education.ecommerceDesc': 'गुणवत्ता खोए बिना प्रोडक्ट इमेज का साइज़ कम करें तेज़ चेकआउट और उच्च कन्वर्जन रेट के लिए।',
    'education.mobileApps': 'मोबाइल ऐप्स',
    'education.mobileDesc': 'ऑप्टिमाइज़्ड इमेज कम्प्रेशन के जरिए ऐप बंडल साइज़ कम करें।',
    'education.compressionTitle': 'इमेज कम्प्रेशन क्यों जरूरी है',
    'education.compressionDesc': 'इमेज कम्प्रेशन आधुनिक वेब एप्लिकेशन के लिए महत्वपूर्ण है, जो बैंडविड्थ उपयोग और लोडिंग टाइम कम करता है।',
    'education.performanceTitle': 'परफॉर्मेंस बेनिफिट्स',
    'education.performanceDesc': 'सही तरीके से कम्प्रेस्ड इमेज पेज लोडिंग स्पीड और यूजर एक्सपीरियंस में सुधार करती हैं।',
    'education.fasterLoading': 'तेज़ लोडिंग',
    'education.reducedBandwidth': 'कम बैंडविड्थ उपयोग',
    'education.betterSeo': 'बेहतर SEO रैंकिंग',
    'education.bestPracticesTitle': 'कम्प्रेशन बेस्ट प्रैक्टिसेज',
    'education.bestPracticesDesc': 'इमेज की गुणवत्ता बनाए रखते हुए ऑप्टिमल रिजल्ट के लिए इन सिद्ध प्रैक्टिसेज का पालन करें।',
    'education.qualityRange': 'वेब इमेज के लिए 80-85% गुणवत्ता का उपयोग करें',
    'education.resizeFirst': 'इमेज को डिस्प्ले डाइमेंशन के लिए रीसाइज़ करें',
    'education.chooseFormat': 'कंटेंट के लिए उपयुक्त फॉर्मेट चुनें',
    'education.jpegBest': 'JPEG: फोटो के लिए बेस्ट',
    'education.pngBest': 'PNG: ग्राफिक्स के लिए बेस्ट',
    'education.webpBest': 'WebP: आधुनिक ब्राउज़र के लिए बेस्ट',
    
    // Missing landing page keys (Hindi)
    'landing.readyToCompress': 'क्या आप अपनी इमेज को कम्प्रेस करने के लिए तैयार हैं?',
    'landing.trustMessage': 'हजारों प्रोफेशनल्स के साथ जुड़ें जो अपनी इमेज ऑप्टिमाइज़ेशन जरूरतों के लिए CompressHub पर भरोसा करते हैं।',
    
    // Enterprise pricing section missing translations (Hindi)
    'pricing.enterpriseTitle': 'एंटरप्राइज़ छवि संपीड़न समाधान',
    'pricing.ecommerceTitle': 'ई-कॉमर्स अनुकूलन',
    'pricing.ecommerceDesc': 'CompressHub Pro का उपयोग करने वाले ऑनलाइन खुदरा विक्रेता 40% तेज़ लोडिंग समय और 25% बेहतर कन्वर्जन दर की रिपोर्ट करते हैं। उत्पाद छवियां तुरंत लोड होती हैं, कार्ट छोड़ने की दर कम करती हैं और ग्राहक अनुभव में सुधार करती हैं।',
    'pricing.batchProcess1000s': 'हजारों उत्पाद छवियों को बैच में संसाधित करें',
    'pricing.maintainQuality': 'पूरी कैटलॉग में लगातार गुणवत्ता बनाए रखें',
    'pricing.optimizeMobile': 'मोबाइल खरीदारों के लिए अनुकूलित करें',
    'pricing.cmsTitle': 'सामग्री प्रबंधन प्रणाली',
    'pricing.cmsDesc': 'संपादक और ब्लॉगर भंडारण लागत में 60% की बचत करते हैं जबकि SEO रैंकिंग में सुधार करते हैं। संपीड़ित छवियां तेज़ी से लोड होती हैं, बाउंस दर कम करती हैं और खोज इंजन प्रदर्शन में सुधार करती हैं।',
    'pricing.apiIntegration': 'WordPress, Drupal के साथ API एकीकरण',
    'pricing.autoCompression': 'अपलोड पर स्वचालित संपीड़न',
    'pricing.seoOptimized': 'SEO के लिए अनुकूलित फ़ाइल आकार',
    'pricing.mobileDevTitle': 'मोबाइल ऐप विकास',
    'pricing.mobileDevDesc': 'मोबाइल डेवलपर्स दृश्य गुणवत्ता बनाए रखते हुए ऐप बंडल आकार को 75% तक कम करते हैं। छोटे ऐप तेज़ी से डाउनलोड होते हैं और कम डिवाइस स्टोरेज का उपयोग करते हैं।',
    'pricing.optimizeIosAndroid': 'iOS और Android के लिए अनुकूलित करें',
    'pricing.multipleDensity': 'मल्टी-डेंसिटी समर्थन',
    'pricing.fasterAppStore': 'तेज़ ऐप स्टोर अनुमोदन',
  },

  // Dutch - Complete translations
  nl: {
    // Navigation
    'nav.home': 'Home',
    'nav.compress': 'Comprimeren',
    'nav.history': 'Geschiedenis',
    'nav.login': 'Inloggen',
    'nav.signup': 'Aanmelden',
    'nav.logout': 'Uitloggen',
    
    // Landing Page
    'landing.title': 'Professionele Beeldcompressie',
    'landing.subtitle': 'Comprimeer afbeeldingen tot 90% kleiner terwijl de visuele kwaliteit behouden blijft. Perfect voor web optimalisatie en opslag.',
    'landing.cta': 'Gratis Beginnen',
    'landing.features.title': 'Waarom CompressHub kiezen?',
    'landing.features.subtitle': 'Professionele beeldcompressie met geavanceerde algoritmen en enterprise functies.',
    'landing.feature1.title': 'Super Snel',
    'landing.feature1.desc': 'Verwerk honderden afbeeldingen in seconden met onze geoptimaliseerde compressie-engine.',
    'landing.feature2.title': 'Visuele Kwaliteit',
    'landing.feature2.desc': 'Geavanceerde algoritmen behouden de beeldkwaliteit terwijl compressie wordt gemaximaliseerd.',
    'landing.feature3.title': 'Ontwikkelaar API',
    'landing.feature3.desc': 'Integreer compressie in je workflow met onze krachtige REST API.',
    'landing.feature4.title': 'Veilige Verwerking',
    'landing.feature4.desc': 'End-to-end encryptie zorgt ervoor dat je afbeeldingen privé en beschermd blijven.',
    'landing.getStarted': 'Gratis Beginnen',
    'landing.pricing.title': 'Eenvoudige Prijzen',
    'landing.pricing.free': 'Gratis',
    'landing.pricing.free.desc': '50 compressies per dag',
    'landing.pricing.pro': 'Pro',
    'landing.pricing.pro.price': '$9',
    'landing.pricing.pro.desc': 'Onbeperkte compressie',
    'landing.pricing.upgrade': 'Upgrade naar Pro',
    
    // Home Page
    'home.welcome': 'Welkom bij CompressHub',
    'home.subtitle': 'Je professionele beeldcompressie tool',
    'home.startCompressing': 'Begin met Comprimeren',
    
    // Compress Page
    'compress.title': 'Afbeeldingen Comprimeren',
    
    // Missing checkout/pricing keys for Dutch
    'checkout.upgradeTitle': 'Upgrade naar CompressHub Pro',
    'checkout.unlimitedFeatures': 'Ontgrendel onbeperkte compressie met professionele functies',
    'checkout.whatsIncluded': 'Wat is inbegrepen',
    'checkout.sslSecure': 'SSL Beveiligd',
    'checkout.cancelAnytime': 'Altijd opzegbaar',
    'checkout.rating': '⭐⭐⭐⭐⭐ 4,9/5 van 2.000+ gebruikers',
    'checkout.createAccountSubscribe': 'Account aanmaken en abonneren',
    'checkout.joinThousands': 'Sluit je aan bij duizenden makers die CompressHub Pro gebruiken',
    'checkout.sslSecured': 'SSL Beveiligd',
    'checkout.pciCompliant': 'PCI Compliant',
    'checkout.completeUpgrade': 'Voltooi je upgrade',
    'checkout.addPaymentMethod': 'Voeg betaalmethode toe om Pro functies te ontgrendelen',
    
    // Missing compress page radio button and interface translations (Dutch)
    'compress.qualityBest': 'Beste kwaliteit',
    'compress.qualityHigh': 'Hoge kwaliteit',
    'compress.qualityMedium': 'Gemiddelde kwaliteit',
    'compress.qualitySmall': 'Klein bestand',
    'compress.qualityMinimum': 'Minimaal bestand',
    'compress.resizeImage': 'Afbeelding vergroten/verkleinen',
    'compress.colorFilter': 'Kleurfilter',
    'compress.noFilter': 'Geen filter',
    'compress.grayscale': 'Grijsschaal',
    'compress.sepia': 'Sepia',
    'compress.vintage': 'Vintage',
    'compress.outputFormat': 'Uitvoerformaat',
    'compress.batchProcessing': 'Batch verwerking',
    'compress.multipleFormats': 'Meerdere formaten',
    'compress.apiAccess': 'API toegang',
    'compress.secureProcessing': 'Veilige verwerking',
    'compress.signUpFeatures': 'Registreer en krijg meer functies',
    'compress.unlockFeatures': 'Functies ontgrendelen',
    'compress.dragDrop': 'Sleep je afbeeldingen hier naartoe of klik om te bladeren',
    'compress.selectFiles': 'Bestanden Selecteren',
    'compress.processing': 'Verwerken...',
    'compress.completed': 'Voltooid',
    'compress.download': 'Download',
    'compress.downloadAll': 'Alles Downloaden',
    'compress.quality': 'Kwaliteit',
    'compress.format': 'Formaat',
    'compress.stats.files': 'bestanden verwerkt',
    'compress.stats.saved': 'ruimte bespaard',
    
    // Upgrade Card
    'upgrade.title': 'Upgrade naar Pro',
    'upgrade.desc': 'Ontgrendel onbeperkte compressie, grotere bestanden, batch verwerking en prioriteitsondersteuning.',
    'upgrade.feature1': 'Onbeperkte compressie per dag',
    'upgrade.feature2': 'Verwerk bestanden tot 100MB elk',
    'upgrade.feature3': 'Batch upload tot 100 bestanden',
    'upgrade.feature4': 'Prioriteitsverwerkingssnelheid',
    'upgrade.feature5': 'Geavanceerde API toegang',
    'upgrade.feature6': '24/7 prioriteitsondersteuning',
    'upgrade.button': 'Upgrade naar Pro - $9/maand',
    
    // Checkout
    'checkout.title': 'Upgrade naar Pro',
    'checkout.subtitle': 'Ontgrendel onbeperkte compressie en premium functies voor $9/maand',
    'checkout.features': 'Premium Functies',
    'checkout.feature.unlimited': 'Onbeperkt Dagelijks Gebruik',
    'checkout.feature.large': 'Bestanden tot 100MB',
    'checkout.feature.batch': 'Batch Verwerking 100 Bestanden',
    'checkout.feature.priority': 'Prioriteitsverwerkingssnelheid',
    'checkout.feature.api': 'Geavanceerde API Toegang',
    'checkout.feature.support': '24/7 Prioriteitsondersteuning',
    'checkout.firstName': 'Voornaam',
    'checkout.lastName': 'Achternaam',
    'checkout.email': 'E-mail',
    'checkout.password': 'Wachtwoord',
    'checkout.promoCode': 'Heb je een promocode?',
    'checkout.hidePromo': 'Promocode verbergen',
    'checkout.payment': 'Betalingsinformatie',
    'checkout.startPro': 'Start Pro - $9/maand',
    'checkout.subscribePro': 'Abonneer op Pro - $9/maand',
    'checkout.perMonth': 'per maand • altijd opzegbaar',
    
    // Common
    'common.loading': 'Laden...',
    'common.cancel': 'Annuleren',
    'common.save': 'Opslaan',
    'common.close': 'Sluiten',
    'common.back': 'Terug',
    'common.next': 'Volgende',
    'common.submit': 'Versturen',
    'common.upload': 'Uploaden',
    'common.download': 'Downloaden',
    
    // Educational Content - Dutch
    'education.title': 'Volledige Gids voor Beeldcompressie',
    'education.subtitle': 'Leer alles over beeldcompressie, van basisconcepten tot geavanceerde technieken.',
    'education.technicalTitle': 'Technische Diepgang: Hoe Beeldcompressie Werkt',
    'education.lossyVsLossless': 'Lossy vs Lossless Compressie',
    'education.lossyDesc': 'Lossy compressie verwijdert sommige beeldgegevens om de bestandsgrootte te verminderen.',
    'education.losslessDesc': 'Lossless compressie behoudt alle originele beeldgegevens.',
    'education.whenToUse': 'Wanneer Elk Type te Gebruiken',
    'education.lossyUse': 'Lossy: Foto\'s, webafbeeldingen, sociale media',
    'education.losslessUse': 'Lossless: Logo\'s, graphics, medische beelden',
    'education.webpUse': 'WebP: Moderne websites die geavanceerde compressie ondersteunen',
    'education.qualityBalance': 'Kwaliteit vs Bestandsgrootte Balans',
    'education.balanceDesc': 'Het vinden van de optimale balans tussen beeldkwaliteit en bestandsgrootte is cruciaal voor webprestaties. Ons compressie-algoritme analyseert elke afbeelding om de beste instellingen te bepalen.',
    'education.largeFiles': 'Grote bestanden',
    'education.optimalWeb': 'Optimaal voor web',
    'education.smallestFiles': 'Kleinste bestanden',
    'education.algorithmsTitle': 'Compressie Algoritmen',
    
    // Additional educational content keys (Dutch)
    'education.guideTitle': 'Volledige Gids voor Beeldcompressie',
    'education.guideSubtitle': 'Leer alles wat je moet weten om je afbeeldingen te optimaliseren voor web, mobiel en print.',
    'education.contentCreation': 'Content Creatie',
    'education.contentDesc': 'Bereid afbeeldingen voor social media, blogs en marketingmateriaal voor met optimale bestandsgroottes voor elk platform.',
    'education.webDev': 'Webontwikkeling',
    'education.webDevDesc': 'Verminder laadtijden en verbeter Core Web Vitals voor betere SEO-rankings.',
    'education.ecommerce': 'E-commerce',
    'education.ecommerceDesc': 'Verkleen productafbeeldingen zonder kwaliteitsverlies voor snellere checkout en hogere conversieratio\'s.',
    'education.mobileApps': 'Mobiele Apps',
    'education.mobileDesc': 'Reduceer app-bundel groottes door geoptimaliseerde beeldcompressie.',
    'education.compressionTitle': 'Waarom Beeldcompressie Belangrijk Is',
    'education.compressionDesc': 'Beeldcompressie is cruciaal voor moderne webapplicaties, het vermindert bandbreedtegebruik en laadtijden.',
    'education.performanceTitle': 'Prestatievoordelen',
    'education.performanceDesc': 'Goed gecomprimeerde afbeeldingen verbeteren pagina-laadsnelheid en gebruikerservaring.',
    'education.fasterLoading': 'Sneller Laden',
    'education.reducedBandwidth': 'Verminderd Bandbreedtegebruik',
    'education.betterSeo': 'Betere SEO-Rankings',
    'education.bestPracticesTitle': 'Beste Compressie Praktijken',
    'education.bestPracticesDesc': 'Volg deze bewezen praktijken voor optimale resultaten terwijl je beeldkwaliteit behoudt.',
    'education.qualityRange': 'Gebruik 80-85% kwaliteit voor webafbeeldingen',
    'education.resizeFirst': 'Verander afbeeldingsgrootte naar weergaveafmetingen',
    'education.chooseFormat': 'Kies het juiste formaat voor content',
    'education.jpegBest': 'JPEG: Beste voor foto\'s',
    'education.pngBest': 'PNG: Beste voor graphics',
    'education.webpBest': 'WebP: Beste voor moderne browsers',
    
    // Missing landing page keys (Dutch)
    'landing.readyToCompress': 'Klaar om je afbeeldingen te comprimeren?',
    'landing.trustMessage': 'Sluit je aan bij duizenden professionals die CompressHub vertrouwen voor hun beeldoptimalisatiebehoeften.',
  },
};